/* node_modules/@angular/material/prebuilt-themes/indigo-pink.css */
.mat-ripple {
  overflow: hidden;
  position: relative;
}
.mat-ripple:not(:empty) {
  transform: translateZ(0);
}
.mat-ripple.mat-ripple-unbounded {
  overflow: visible;
}
.mat-ripple-element {
  position: absolute;
  border-radius: 50%;
  pointer-events: none;
  transition: opacity, transform 0ms cubic-bezier(0, 0, 0.2, 1);
  transform: scale3d(0, 0, 0);
  background-color: var(--mat-ripple-color, rgba(0, 0, 0, 0.1));
}
.cdk-high-contrast-active .mat-ripple-element {
  display: none;
}
.cdk-visually-hidden {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px;
  white-space: nowrap;
  outline: 0;
  -webkit-appearance: none;
  -moz-appearance: none;
  left: 0;
}
[dir=rtl] .cdk-visually-hidden {
  left: auto;
  right: 0;
}
.cdk-overlay-container,
.cdk-global-overlay-wrapper {
  pointer-events: none;
  top: 0;
  left: 0;
  height: 100%;
  width: 100%;
}
.cdk-overlay-container {
  position: fixed;
  z-index: 1000;
}
.cdk-overlay-container:empty {
  display: none;
}
.cdk-global-overlay-wrapper {
  display: flex;
  position: absolute;
  z-index: 1000;
}
.cdk-overlay-pane {
  position: absolute;
  pointer-events: auto;
  box-sizing: border-box;
  z-index: 1000;
  display: flex;
  max-width: 100%;
  max-height: 100%;
}
.cdk-overlay-backdrop {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  z-index: 1000;
  pointer-events: auto;
  -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
  transition: opacity 400ms cubic-bezier(0.25, 0.8, 0.25, 1);
  opacity: 0;
}
.cdk-overlay-backdrop.cdk-overlay-backdrop-showing {
  opacity: 1;
}
.cdk-high-contrast-active .cdk-overlay-backdrop.cdk-overlay-backdrop-showing {
  opacity: .6;
}
.cdk-overlay-dark-backdrop {
  background: rgba(0, 0, 0, .32);
}
.cdk-overlay-transparent-backdrop {
  transition: visibility 1ms linear, opacity 1ms linear;
  visibility: hidden;
  opacity: 1;
}
.cdk-overlay-transparent-backdrop.cdk-overlay-backdrop-showing {
  opacity: 0;
  visibility: visible;
}
.cdk-overlay-backdrop-noop-animation {
  transition: none;
}
.cdk-overlay-connected-position-bounding-box {
  position: absolute;
  z-index: 1000;
  display: flex;
  flex-direction: column;
  min-width: 1px;
  min-height: 1px;
}
.cdk-global-scrollblock {
  position: fixed;
  width: 100%;
  overflow-y: scroll;
}
textarea.cdk-textarea-autosize {
  resize: none;
}
textarea.cdk-textarea-autosize-measuring {
  padding: 2px 0 !important;
  box-sizing: content-box !important;
  height: auto !important;
  overflow: hidden !important;
}
textarea.cdk-textarea-autosize-measuring-firefox {
  padding: 2px 0 !important;
  box-sizing: content-box !important;
  height: 0 !important;
}
@keyframes cdk-text-field-autofill-start {
}
@keyframes cdk-text-field-autofill-end {
}
.cdk-text-field-autofill-monitored:-webkit-autofill {
  animation: cdk-text-field-autofill-start 0s 1ms;
}
.cdk-text-field-autofill-monitored:not(:-webkit-autofill) {
  animation: cdk-text-field-autofill-end 0s 1ms;
}
.mat-focus-indicator {
  position: relative;
}
.mat-focus-indicator::before {
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  position: absolute;
  box-sizing: border-box;
  pointer-events: none;
  display: var(--mat-focus-indicator-display, none);
  border: var(--mat-focus-indicator-border-width, 3px) var(--mat-focus-indicator-border-style, solid) var(--mat-focus-indicator-border-color, transparent);
  border-radius: var(--mat-focus-indicator-border-radius, 4px);
}
.mat-focus-indicator:focus::before {
  content: "";
}
.cdk-high-contrast-active {
  --mat-focus-indicator-display: block;
}
.mat-mdc-focus-indicator {
  position: relative;
}
.mat-mdc-focus-indicator::before {
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  position: absolute;
  box-sizing: border-box;
  pointer-events: none;
  display: var(--mat-mdc-focus-indicator-display, none);
  border: var(--mat-mdc-focus-indicator-border-width, 3px) var(--mat-mdc-focus-indicator-border-style, solid) var(--mat-mdc-focus-indicator-border-color, transparent);
  border-radius: var(--mat-mdc-focus-indicator-border-radius, 4px);
}
.mat-mdc-focus-indicator:focus::before {
  content: "";
}
.cdk-high-contrast-active {
  --mat-mdc-focus-indicator-display: block;
}
.mat-app-background {
  background-color: var(--mat-app-background-color, transparent);
  color: var(--mat-app-text-color, inherit);
}
html {
  --mat-ripple-color:rgba(0, 0, 0, 0.1);
}
html {
  --mat-option-selected-state-label-text-color:#3f51b5;
  --mat-option-label-text-color:rgba(0, 0, 0, 0.87);
  --mat-option-hover-state-layer-color:rgba(0, 0, 0, 0.04);
  --mat-option-focus-state-layer-color:rgba(0, 0, 0, 0.04);
  --mat-option-selected-state-layer-color:rgba(0, 0, 0, 0.04);
}
.mat-accent {
  --mat-option-selected-state-label-text-color:#ff4081;
  --mat-option-label-text-color:rgba(0, 0, 0, 0.87);
  --mat-option-hover-state-layer-color:rgba(0, 0, 0, 0.04);
  --mat-option-focus-state-layer-color:rgba(0, 0, 0, 0.04);
  --mat-option-selected-state-layer-color:rgba(0, 0, 0, 0.04);
}
.mat-warn {
  --mat-option-selected-state-label-text-color:#f44336;
  --mat-option-label-text-color:rgba(0, 0, 0, 0.87);
  --mat-option-hover-state-layer-color:rgba(0, 0, 0, 0.04);
  --mat-option-focus-state-layer-color:rgba(0, 0, 0, 0.04);
  --mat-option-selected-state-layer-color:rgba(0, 0, 0, 0.04);
}
html {
  --mat-optgroup-label-text-color:rgba(0, 0, 0, 0.87);
}
.mat-primary {
  --mat-full-pseudo-checkbox-selected-icon-color:#3f51b5;
  --mat-full-pseudo-checkbox-selected-checkmark-color:#fafafa;
  --mat-full-pseudo-checkbox-unselected-icon-color:rgba(0, 0, 0, 0.54);
  --mat-full-pseudo-checkbox-disabled-selected-checkmark-color:#fafafa;
  --mat-full-pseudo-checkbox-disabled-unselected-icon-color:#b0b0b0;
  --mat-full-pseudo-checkbox-disabled-selected-icon-color:#b0b0b0;
  --mat-minimal-pseudo-checkbox-selected-checkmark-color:#3f51b5;
  --mat-minimal-pseudo-checkbox-disabled-selected-checkmark-color:#b0b0b0;
}
html {
  --mat-full-pseudo-checkbox-selected-icon-color:#ff4081;
  --mat-full-pseudo-checkbox-selected-checkmark-color:#fafafa;
  --mat-full-pseudo-checkbox-unselected-icon-color:rgba(0, 0, 0, 0.54);
  --mat-full-pseudo-checkbox-disabled-selected-checkmark-color:#fafafa;
  --mat-full-pseudo-checkbox-disabled-unselected-icon-color:#b0b0b0;
  --mat-full-pseudo-checkbox-disabled-selected-icon-color:#b0b0b0;
  --mat-minimal-pseudo-checkbox-selected-checkmark-color:#ff4081;
  --mat-minimal-pseudo-checkbox-disabled-selected-checkmark-color:#b0b0b0;
}
.mat-accent {
  --mat-full-pseudo-checkbox-selected-icon-color:#ff4081;
  --mat-full-pseudo-checkbox-selected-checkmark-color:#fafafa;
  --mat-full-pseudo-checkbox-unselected-icon-color:rgba(0, 0, 0, 0.54);
  --mat-full-pseudo-checkbox-disabled-selected-checkmark-color:#fafafa;
  --mat-full-pseudo-checkbox-disabled-unselected-icon-color:#b0b0b0;
  --mat-full-pseudo-checkbox-disabled-selected-icon-color:#b0b0b0;
  --mat-minimal-pseudo-checkbox-selected-checkmark-color:#ff4081;
  --mat-minimal-pseudo-checkbox-disabled-selected-checkmark-color:#b0b0b0;
}
.mat-warn {
  --mat-full-pseudo-checkbox-selected-icon-color:#f44336;
  --mat-full-pseudo-checkbox-selected-checkmark-color:#fafafa;
  --mat-full-pseudo-checkbox-unselected-icon-color:rgba(0, 0, 0, 0.54);
  --mat-full-pseudo-checkbox-disabled-selected-checkmark-color:#fafafa;
  --mat-full-pseudo-checkbox-disabled-unselected-icon-color:#b0b0b0;
  --mat-full-pseudo-checkbox-disabled-selected-icon-color:#b0b0b0;
  --mat-minimal-pseudo-checkbox-selected-checkmark-color:#f44336;
  --mat-minimal-pseudo-checkbox-disabled-selected-checkmark-color:#b0b0b0;
}
html {
  --mat-app-background-color:#fafafa;
  --mat-app-text-color:rgba(0, 0, 0, 0.87);
}
.mat-elevation-z0,
.mat-mdc-elevation-specific.mat-elevation-z0 {
  box-shadow:
    0px 0px 0px 0px rgba(0, 0, 0, 0.2),
    0px 0px 0px 0px rgba(0, 0, 0, 0.14),
    0px 0px 0px 0px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z1,
.mat-mdc-elevation-specific.mat-elevation-z1 {
  box-shadow:
    0px 2px 1px -1px rgba(0, 0, 0, 0.2),
    0px 1px 1px 0px rgba(0, 0, 0, 0.14),
    0px 1px 3px 0px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z2,
.mat-mdc-elevation-specific.mat-elevation-z2 {
  box-shadow:
    0px 3px 1px -2px rgba(0, 0, 0, 0.2),
    0px 2px 2px 0px rgba(0, 0, 0, 0.14),
    0px 1px 5px 0px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z3,
.mat-mdc-elevation-specific.mat-elevation-z3 {
  box-shadow:
    0px 3px 3px -2px rgba(0, 0, 0, 0.2),
    0px 3px 4px 0px rgba(0, 0, 0, 0.14),
    0px 1px 8px 0px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z4,
.mat-mdc-elevation-specific.mat-elevation-z4 {
  box-shadow:
    0px 2px 4px -1px rgba(0, 0, 0, 0.2),
    0px 4px 5px 0px rgba(0, 0, 0, 0.14),
    0px 1px 10px 0px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z5,
.mat-mdc-elevation-specific.mat-elevation-z5 {
  box-shadow:
    0px 3px 5px -1px rgba(0, 0, 0, 0.2),
    0px 5px 8px 0px rgba(0, 0, 0, 0.14),
    0px 1px 14px 0px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z6,
.mat-mdc-elevation-specific.mat-elevation-z6 {
  box-shadow:
    0px 3px 5px -1px rgba(0, 0, 0, 0.2),
    0px 6px 10px 0px rgba(0, 0, 0, 0.14),
    0px 1px 18px 0px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z7,
.mat-mdc-elevation-specific.mat-elevation-z7 {
  box-shadow:
    0px 4px 5px -2px rgba(0, 0, 0, 0.2),
    0px 7px 10px 1px rgba(0, 0, 0, 0.14),
    0px 2px 16px 1px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z8,
.mat-mdc-elevation-specific.mat-elevation-z8 {
  box-shadow:
    0px 5px 5px -3px rgba(0, 0, 0, 0.2),
    0px 8px 10px 1px rgba(0, 0, 0, 0.14),
    0px 3px 14px 2px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z9,
.mat-mdc-elevation-specific.mat-elevation-z9 {
  box-shadow:
    0px 5px 6px -3px rgba(0, 0, 0, 0.2),
    0px 9px 12px 1px rgba(0, 0, 0, 0.14),
    0px 3px 16px 2px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z10,
.mat-mdc-elevation-specific.mat-elevation-z10 {
  box-shadow:
    0px 6px 6px -3px rgba(0, 0, 0, 0.2),
    0px 10px 14px 1px rgba(0, 0, 0, 0.14),
    0px 4px 18px 3px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z11,
.mat-mdc-elevation-specific.mat-elevation-z11 {
  box-shadow:
    0px 6px 7px -4px rgba(0, 0, 0, 0.2),
    0px 11px 15px 1px rgba(0, 0, 0, 0.14),
    0px 4px 20px 3px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z12,
.mat-mdc-elevation-specific.mat-elevation-z12 {
  box-shadow:
    0px 7px 8px -4px rgba(0, 0, 0, 0.2),
    0px 12px 17px 2px rgba(0, 0, 0, 0.14),
    0px 5px 22px 4px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z13,
.mat-mdc-elevation-specific.mat-elevation-z13 {
  box-shadow:
    0px 7px 8px -4px rgba(0, 0, 0, 0.2),
    0px 13px 19px 2px rgba(0, 0, 0, 0.14),
    0px 5px 24px 4px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z14,
.mat-mdc-elevation-specific.mat-elevation-z14 {
  box-shadow:
    0px 7px 9px -4px rgba(0, 0, 0, 0.2),
    0px 14px 21px 2px rgba(0, 0, 0, 0.14),
    0px 5px 26px 4px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z15,
.mat-mdc-elevation-specific.mat-elevation-z15 {
  box-shadow:
    0px 8px 9px -5px rgba(0, 0, 0, 0.2),
    0px 15px 22px 2px rgba(0, 0, 0, 0.14),
    0px 6px 28px 5px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z16,
.mat-mdc-elevation-specific.mat-elevation-z16 {
  box-shadow:
    0px 8px 10px -5px rgba(0, 0, 0, 0.2),
    0px 16px 24px 2px rgba(0, 0, 0, 0.14),
    0px 6px 30px 5px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z17,
.mat-mdc-elevation-specific.mat-elevation-z17 {
  box-shadow:
    0px 8px 11px -5px rgba(0, 0, 0, 0.2),
    0px 17px 26px 2px rgba(0, 0, 0, 0.14),
    0px 6px 32px 5px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z18,
.mat-mdc-elevation-specific.mat-elevation-z18 {
  box-shadow:
    0px 9px 11px -5px rgba(0, 0, 0, 0.2),
    0px 18px 28px 2px rgba(0, 0, 0, 0.14),
    0px 7px 34px 6px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z19,
.mat-mdc-elevation-specific.mat-elevation-z19 {
  box-shadow:
    0px 9px 12px -6px rgba(0, 0, 0, 0.2),
    0px 19px 29px 2px rgba(0, 0, 0, 0.14),
    0px 7px 36px 6px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z20,
.mat-mdc-elevation-specific.mat-elevation-z20 {
  box-shadow:
    0px 10px 13px -6px rgba(0, 0, 0, 0.2),
    0px 20px 31px 3px rgba(0, 0, 0, 0.14),
    0px 8px 38px 7px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z21,
.mat-mdc-elevation-specific.mat-elevation-z21 {
  box-shadow:
    0px 10px 13px -6px rgba(0, 0, 0, 0.2),
    0px 21px 33px 3px rgba(0, 0, 0, 0.14),
    0px 8px 40px 7px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z22,
.mat-mdc-elevation-specific.mat-elevation-z22 {
  box-shadow:
    0px 10px 14px -6px rgba(0, 0, 0, 0.2),
    0px 22px 35px 3px rgba(0, 0, 0, 0.14),
    0px 8px 42px 7px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z23,
.mat-mdc-elevation-specific.mat-elevation-z23 {
  box-shadow:
    0px 11px 14px -7px rgba(0, 0, 0, 0.2),
    0px 23px 36px 3px rgba(0, 0, 0, 0.14),
    0px 9px 44px 8px rgba(0, 0, 0, 0.12);
}
.mat-elevation-z24,
.mat-mdc-elevation-specific.mat-elevation-z24 {
  box-shadow:
    0px 11px 15px -7px rgba(0, 0, 0, 0.2),
    0px 24px 38px 3px rgba(0, 0, 0, 0.14),
    0px 9px 46px 8px rgba(0, 0, 0, 0.12);
}
.mat-theme-loaded-marker {
  display: none;
}
html {
  --mat-option-label-text-font:Roboto, sans-serif;
  --mat-option-label-text-line-height:24px;
  --mat-option-label-text-size:16px;
  --mat-option-label-text-tracking:0.03125em;
  --mat-option-label-text-weight:400;
}
html {
  --mat-optgroup-label-text-font:Roboto, sans-serif;
  --mat-optgroup-label-text-line-height:24px;
  --mat-optgroup-label-text-size:16px;
  --mat-optgroup-label-text-tracking:0.03125em;
  --mat-optgroup-label-text-weight:400;
}
html {
  --mdc-elevated-card-container-shape:4px;
  --mdc-outlined-card-container-shape:4px;
  --mdc-outlined-card-outline-width:1px;
}
html {
  --mdc-elevated-card-container-color:white;
  --mdc-elevated-card-container-elevation:0px 2px 1px -1px rgba(0, 0, 0, 0.2),
    0px 1px 1px 0px rgba(0, 0, 0, 0.14),
    0px 1px 3px 0px rgba(0, 0, 0, 0.12);
  --mdc-outlined-card-container-color:white;
  --mdc-outlined-card-outline-color:rgba(0, 0, 0, 0.12);
  --mdc-outlined-card-container-elevation:0px 0px 0px 0px rgba(0, 0, 0, 0.2),
    0px 0px 0px 0px rgba(0, 0, 0, 0.14),
    0px 0px 0px 0px rgba(0, 0, 0, 0.12);
  --mat-card-subtitle-text-color:rgba(0, 0, 0, 0.54);
}
html {
  --mat-card-title-text-font:Roboto, sans-serif;
  --mat-card-title-text-line-height:32px;
  --mat-card-title-text-size:20px;
  --mat-card-title-text-tracking:0.0125em;
  --mat-card-title-text-weight:500;
  --mat-card-subtitle-text-font:Roboto, sans-serif;
  --mat-card-subtitle-text-line-height:22px;
  --mat-card-subtitle-text-size:14px;
  --mat-card-subtitle-text-tracking:0.0071428571em;
  --mat-card-subtitle-text-weight:500;
}
html {
  --mdc-linear-progress-active-indicator-height:4px;
  --mdc-linear-progress-track-height:4px;
  --mdc-linear-progress-track-shape:0;
}
.mat-mdc-progress-bar {
  --mdc-linear-progress-active-indicator-color:#3f51b5;
  --mdc-linear-progress-track-color:rgba(63, 81, 181, 0.25);
}
.mat-mdc-progress-bar.mat-accent {
  --mdc-linear-progress-active-indicator-color:#ff4081;
  --mdc-linear-progress-track-color:rgba(255, 64, 129, 0.25);
}
.mat-mdc-progress-bar.mat-warn {
  --mdc-linear-progress-active-indicator-color:#f44336;
  --mdc-linear-progress-track-color:rgba(244, 67, 54, 0.25);
}
html {
  --mdc-plain-tooltip-container-shape:4px;
  --mdc-plain-tooltip-supporting-text-line-height:16px;
}
html {
  --mdc-plain-tooltip-container-color:#616161;
  --mdc-plain-tooltip-supporting-text-color:#fff;
}
html {
  --mdc-plain-tooltip-supporting-text-font:Roboto, sans-serif;
  --mdc-plain-tooltip-supporting-text-size:12px;
  --mdc-plain-tooltip-supporting-text-weight:400;
  --mdc-plain-tooltip-supporting-text-tracking:0.0333333333em;
}
html {
  --mdc-filled-text-field-active-indicator-height:1px;
  --mdc-filled-text-field-focus-active-indicator-height:2px;
  --mdc-filled-text-field-container-shape:4px;
  --mdc-outlined-text-field-outline-width:1px;
  --mdc-outlined-text-field-focus-outline-width:2px;
  --mdc-outlined-text-field-container-shape:4px;
}
html {
  --mdc-filled-text-field-caret-color:#3f51b5;
  --mdc-filled-text-field-focus-active-indicator-color:#3f51b5;
  --mdc-filled-text-field-focus-label-text-color:rgba(63, 81, 181, 0.87);
  --mdc-filled-text-field-container-color:whitesmoke;
  --mdc-filled-text-field-disabled-container-color:#fafafa;
  --mdc-filled-text-field-label-text-color:rgba(0, 0, 0, 0.6);
  --mdc-filled-text-field-hover-label-text-color:rgba(0, 0, 0, 0.6);
  --mdc-filled-text-field-disabled-label-text-color:rgba(0, 0, 0, 0.38);
  --mdc-filled-text-field-input-text-color:rgba(0, 0, 0, 0.87);
  --mdc-filled-text-field-disabled-input-text-color:rgba(0, 0, 0, 0.38);
  --mdc-filled-text-field-input-text-placeholder-color:rgba(0, 0, 0, 0.6);
  --mdc-filled-text-field-error-hover-label-text-color:#f44336;
  --mdc-filled-text-field-error-focus-label-text-color:#f44336;
  --mdc-filled-text-field-error-label-text-color:#f44336;
  --mdc-filled-text-field-error-caret-color:#f44336;
  --mdc-filled-text-field-active-indicator-color:rgba(0, 0, 0, 0.42);
  --mdc-filled-text-field-disabled-active-indicator-color:rgba(0, 0, 0, 0.06);
  --mdc-filled-text-field-hover-active-indicator-color:rgba(0, 0, 0, 0.87);
  --mdc-filled-text-field-error-active-indicator-color:#f44336;
  --mdc-filled-text-field-error-focus-active-indicator-color:#f44336;
  --mdc-filled-text-field-error-hover-active-indicator-color:#f44336;
  --mdc-outlined-text-field-caret-color:#3f51b5;
  --mdc-outlined-text-field-focus-outline-color:#3f51b5;
  --mdc-outlined-text-field-focus-label-text-color:rgba(63, 81, 181, 0.87);
  --mdc-outlined-text-field-label-text-color:rgba(0, 0, 0, 0.6);
  --mdc-outlined-text-field-hover-label-text-color:rgba(0, 0, 0, 0.6);
  --mdc-outlined-text-field-disabled-label-text-color:rgba(0, 0, 0, 0.38);
  --mdc-outlined-text-field-input-text-color:rgba(0, 0, 0, 0.87);
  --mdc-outlined-text-field-disabled-input-text-color:rgba(0, 0, 0, 0.38);
  --mdc-outlined-text-field-input-text-placeholder-color:rgba(0, 0, 0, 0.6);
  --mdc-outlined-text-field-error-caret-color:#f44336;
  --mdc-outlined-text-field-error-focus-label-text-color:#f44336;
  --mdc-outlined-text-field-error-label-text-color:#f44336;
  --mdc-outlined-text-field-error-hover-label-text-color:#f44336;
  --mdc-outlined-text-field-outline-color:rgba(0, 0, 0, 0.38);
  --mdc-outlined-text-field-disabled-outline-color:rgba(0, 0, 0, 0.06);
  --mdc-outlined-text-field-hover-outline-color:rgba(0, 0, 0, 0.87);
  --mdc-outlined-text-field-error-focus-outline-color:#f44336;
  --mdc-outlined-text-field-error-hover-outline-color:#f44336;
  --mdc-outlined-text-field-error-outline-color:#f44336;
  --mat-form-field-focus-select-arrow-color:rgba(63, 81, 181, 0.87);
  --mat-form-field-disabled-input-text-placeholder-color:rgba(0, 0, 0, 0.38);
  --mat-form-field-state-layer-color:rgba(0, 0, 0, 0.87);
  --mat-form-field-error-text-color:#f44336;
  --mat-form-field-select-option-text-color:inherit;
  --mat-form-field-select-disabled-option-text-color:GrayText;
  --mat-form-field-leading-icon-color:unset;
  --mat-form-field-disabled-leading-icon-color:unset;
  --mat-form-field-trailing-icon-color:unset;
  --mat-form-field-disabled-trailing-icon-color:unset;
  --mat-form-field-error-focus-trailing-icon-color:unset;
  --mat-form-field-error-hover-trailing-icon-color:unset;
  --mat-form-field-error-trailing-icon-color:unset;
  --mat-form-field-enabled-select-arrow-color:rgba(0, 0, 0, 0.54);
  --mat-form-field-disabled-select-arrow-color:rgba(0, 0, 0, 0.38);
  --mat-form-field-hover-state-layer-opacity:0.04;
  --mat-form-field-focus-state-layer-opacity:0.08;
}
.mat-mdc-form-field.mat-accent {
  --mdc-filled-text-field-caret-color:#ff4081;
  --mdc-filled-text-field-focus-active-indicator-color:#ff4081;
  --mdc-filled-text-field-focus-label-text-color:rgba(255, 64, 129, 0.87);
  --mdc-outlined-text-field-caret-color:#ff4081;
  --mdc-outlined-text-field-focus-outline-color:#ff4081;
  --mdc-outlined-text-field-focus-label-text-color:rgba(255, 64, 129, 0.87);
  --mat-form-field-focus-select-arrow-color:rgba(255, 64, 129, 0.87);
}
.mat-mdc-form-field.mat-warn {
  --mdc-filled-text-field-caret-color:#f44336;
  --mdc-filled-text-field-focus-active-indicator-color:#f44336;
  --mdc-filled-text-field-focus-label-text-color:rgba(244, 67, 54, 0.87);
  --mdc-outlined-text-field-caret-color:#f44336;
  --mdc-outlined-text-field-focus-outline-color:#f44336;
  --mdc-outlined-text-field-focus-label-text-color:rgba(244, 67, 54, 0.87);
  --mat-form-field-focus-select-arrow-color:rgba(244, 67, 54, 0.87);
}
html {
  --mat-form-field-container-height:56px;
  --mat-form-field-filled-label-display:block;
  --mat-form-field-container-vertical-padding:16px;
  --mat-form-field-filled-with-label-container-padding-top:24px;
  --mat-form-field-filled-with-label-container-padding-bottom:8px;
}
html {
  --mdc-filled-text-field-label-text-font:Roboto, sans-serif;
  --mdc-filled-text-field-label-text-size:16px;
  --mdc-filled-text-field-label-text-tracking:0.03125em;
  --mdc-filled-text-field-label-text-weight:400;
  --mdc-outlined-text-field-label-text-font:Roboto, sans-serif;
  --mdc-outlined-text-field-label-text-size:16px;
  --mdc-outlined-text-field-label-text-tracking:0.03125em;
  --mdc-outlined-text-field-label-text-weight:400;
  --mat-form-field-container-text-font:Roboto, sans-serif;
  --mat-form-field-container-text-line-height:24px;
  --mat-form-field-container-text-size:16px;
  --mat-form-field-container-text-tracking:0.03125em;
  --mat-form-field-container-text-weight:400;
  --mat-form-field-outlined-label-text-populated-size:16px;
  --mat-form-field-subscript-text-font:Roboto, sans-serif;
  --mat-form-field-subscript-text-line-height:20px;
  --mat-form-field-subscript-text-size:12px;
  --mat-form-field-subscript-text-tracking:0.0333333333em;
  --mat-form-field-subscript-text-weight:400;
}
html {
  --mat-select-container-elevation-shadow:0px 5px 5px -3px rgba(0, 0, 0, 0.2),
    0px 8px 10px 1px rgba(0, 0, 0, 0.14),
    0px 3px 14px 2px rgba(0, 0, 0, 0.12);
}
html {
  --mat-select-panel-background-color:white;
  --mat-select-enabled-trigger-text-color:rgba(0, 0, 0, 0.87);
  --mat-select-disabled-trigger-text-color:rgba(0, 0, 0, 0.38);
  --mat-select-placeholder-text-color:rgba(0, 0, 0, 0.6);
  --mat-select-enabled-arrow-color:rgba(0, 0, 0, 0.54);
  --mat-select-disabled-arrow-color:rgba(0, 0, 0, 0.38);
  --mat-select-focused-arrow-color:rgba(63, 81, 181, 0.87);
  --mat-select-invalid-arrow-color:rgba(244, 67, 54, 0.87);
}
html .mat-mdc-form-field.mat-accent {
  --mat-select-panel-background-color:white;
  --mat-select-enabled-trigger-text-color:rgba(0, 0, 0, 0.87);
  --mat-select-disabled-trigger-text-color:rgba(0, 0, 0, 0.38);
  --mat-select-placeholder-text-color:rgba(0, 0, 0, 0.6);
  --mat-select-enabled-arrow-color:rgba(0, 0, 0, 0.54);
  --mat-select-disabled-arrow-color:rgba(0, 0, 0, 0.38);
  --mat-select-focused-arrow-color:rgba(255, 64, 129, 0.87);
  --mat-select-invalid-arrow-color:rgba(244, 67, 54, 0.87);
}
html .mat-mdc-form-field.mat-warn {
  --mat-select-panel-background-color:white;
  --mat-select-enabled-trigger-text-color:rgba(0, 0, 0, 0.87);
  --mat-select-disabled-trigger-text-color:rgba(0, 0, 0, 0.38);
  --mat-select-placeholder-text-color:rgba(0, 0, 0, 0.6);
  --mat-select-enabled-arrow-color:rgba(0, 0, 0, 0.54);
  --mat-select-disabled-arrow-color:rgba(0, 0, 0, 0.38);
  --mat-select-focused-arrow-color:rgba(244, 67, 54, 0.87);
  --mat-select-invalid-arrow-color:rgba(244, 67, 54, 0.87);
}
html {
  --mat-select-arrow-transform:translateY(-8px);
}
html {
  --mat-select-trigger-text-font:Roboto, sans-serif;
  --mat-select-trigger-text-line-height:24px;
  --mat-select-trigger-text-size:16px;
  --mat-select-trigger-text-tracking:0.03125em;
  --mat-select-trigger-text-weight:400;
}
html {
  --mat-autocomplete-container-shape:4px;
  --mat-autocomplete-container-elevation-shadow:0px 5px 5px -3px rgba(0, 0, 0, 0.2),
    0px 8px 10px 1px rgba(0, 0, 0, 0.14),
    0px 3px 14px 2px rgba(0, 0, 0, 0.12);
}
html {
  --mat-autocomplete-background-color:white;
}
html {
  --mdc-dialog-container-elevation-shadow:0px 11px 15px -7px rgba(0, 0, 0, 0.2),
    0px 24px 38px 3px rgba(0, 0, 0, 0.14),
    0px 9px 46px 8px rgba(0, 0, 0, 0.12);
  --mdc-dialog-container-shadow-color:#000;
  --mdc-dialog-container-shape:4px;
  --mat-dialog-container-max-width:80vw;
  --mat-dialog-container-small-max-width:80vw;
  --mat-dialog-container-min-width:0;
  --mat-dialog-actions-alignment:start;
  --mat-dialog-actions-padding:8px;
  --mat-dialog-content-padding:20px 24px;
  --mat-dialog-with-actions-content-padding:20px 24px;
  --mat-dialog-headline-padding:0 24px 9px;
}
html {
  --mdc-dialog-container-color:white;
  --mdc-dialog-subhead-color:rgba(0, 0, 0, 0.87);
  --mdc-dialog-supporting-text-color:rgba(0, 0, 0, 0.6);
}
html {
  --mdc-dialog-subhead-font:Roboto, sans-serif;
  --mdc-dialog-subhead-line-height:32px;
  --mdc-dialog-subhead-size:20px;
  --mdc-dialog-subhead-weight:500;
  --mdc-dialog-subhead-tracking:0.0125em;
  --mdc-dialog-supporting-text-font:Roboto, sans-serif;
  --mdc-dialog-supporting-text-line-height:24px;
  --mdc-dialog-supporting-text-size:16px;
  --mdc-dialog-supporting-text-weight:400;
  --mdc-dialog-supporting-text-tracking:0.03125em;
}
.mat-mdc-standard-chip {
  --mdc-chip-container-shape-family:rounded;
  --mdc-chip-container-shape-radius:16px 16px 16px 16px;
  --mdc-chip-with-avatar-avatar-shape-family:rounded;
  --mdc-chip-with-avatar-avatar-shape-radius:14px 14px 14px 14px;
  --mdc-chip-with-avatar-avatar-size:28px;
  --mdc-chip-with-icon-icon-size:18px;
  --mdc-chip-outline-width:0;
  --mdc-chip-outline-color:transparent;
  --mdc-chip-disabled-outline-color:transparent;
  --mdc-chip-focus-outline-color:transparent;
  --mdc-chip-hover-state-layer-opacity:0.04;
  --mdc-chip-with-avatar-disabled-avatar-opacity:1;
  --mdc-chip-flat-selected-outline-width:0;
  --mdc-chip-selected-hover-state-layer-opacity:0.04;
  --mdc-chip-with-trailing-icon-disabled-trailing-icon-opacity:1;
  --mdc-chip-with-icon-disabled-icon-opacity:1;
  --mat-chip-disabled-container-opacity:0.4;
  --mat-chip-trailing-action-opacity:0.54;
  --mat-chip-trailing-action-focus-opacity:1;
  --mat-chip-trailing-action-state-layer-color:transparent;
  --mat-chip-selected-trailing-action-state-layer-color:transparent;
  --mat-chip-trailing-action-hover-state-layer-opacity:0;
  --mat-chip-trailing-action-focus-state-layer-opacity:0;
}
.mat-mdc-standard-chip {
  --mdc-chip-disabled-label-text-color:#212121;
  --mdc-chip-elevated-container-color:#e0e0e0;
  --mdc-chip-elevated-selected-container-color:#e0e0e0;
  --mdc-chip-elevated-disabled-container-color:#e0e0e0;
  --mdc-chip-flat-disabled-selected-container-color:#e0e0e0;
  --mdc-chip-focus-state-layer-color:black;
  --mdc-chip-hover-state-layer-color:black;
  --mdc-chip-selected-hover-state-layer-color:black;
  --mdc-chip-focus-state-layer-opacity:0.12;
  --mdc-chip-selected-focus-state-layer-color:black;
  --mdc-chip-selected-focus-state-layer-opacity:0.12;
  --mdc-chip-label-text-color:#212121;
  --mdc-chip-selected-label-text-color:#212121;
  --mdc-chip-with-icon-icon-color:#212121;
  --mdc-chip-with-icon-disabled-icon-color:#212121;
  --mdc-chip-with-icon-selected-icon-color:#212121;
  --mdc-chip-with-trailing-icon-disabled-trailing-icon-color:#212121;
  --mdc-chip-with-trailing-icon-trailing-icon-color:#212121;
  --mat-chip-selected-disabled-trailing-icon-color:#212121;
  --mat-chip-selected-trailing-icon-color:#212121;
}
.mat-mdc-standard-chip.mat-mdc-chip-selected.mat-primary,
.mat-mdc-standard-chip.mat-mdc-chip-highlighted.mat-primary {
  --mdc-chip-disabled-label-text-color:white;
  --mdc-chip-elevated-container-color:#3f51b5;
  --mdc-chip-elevated-selected-container-color:#3f51b5;
  --mdc-chip-elevated-disabled-container-color:#3f51b5;
  --mdc-chip-flat-disabled-selected-container-color:#3f51b5;
  --mdc-chip-focus-state-layer-color:black;
  --mdc-chip-hover-state-layer-color:black;
  --mdc-chip-selected-hover-state-layer-color:black;
  --mdc-chip-focus-state-layer-opacity:0.12;
  --mdc-chip-selected-focus-state-layer-color:black;
  --mdc-chip-selected-focus-state-layer-opacity:0.12;
  --mdc-chip-label-text-color:white;
  --mdc-chip-selected-label-text-color:white;
  --mdc-chip-with-icon-icon-color:white;
  --mdc-chip-with-icon-disabled-icon-color:white;
  --mdc-chip-with-icon-selected-icon-color:white;
  --mdc-chip-with-trailing-icon-disabled-trailing-icon-color:white;
  --mdc-chip-with-trailing-icon-trailing-icon-color:white;
  --mat-chip-selected-disabled-trailing-icon-color:white;
  --mat-chip-selected-trailing-icon-color:white;
}
.mat-mdc-standard-chip.mat-mdc-chip-selected.mat-accent,
.mat-mdc-standard-chip.mat-mdc-chip-highlighted.mat-accent {
  --mdc-chip-disabled-label-text-color:white;
  --mdc-chip-elevated-container-color:#ff4081;
  --mdc-chip-elevated-selected-container-color:#ff4081;
  --mdc-chip-elevated-disabled-container-color:#ff4081;
  --mdc-chip-flat-disabled-selected-container-color:#ff4081;
  --mdc-chip-focus-state-layer-color:black;
  --mdc-chip-hover-state-layer-color:black;
  --mdc-chip-selected-hover-state-layer-color:black;
  --mdc-chip-focus-state-layer-opacity:0.12;
  --mdc-chip-selected-focus-state-layer-color:black;
  --mdc-chip-selected-focus-state-layer-opacity:0.12;
  --mdc-chip-label-text-color:white;
  --mdc-chip-selected-label-text-color:white;
  --mdc-chip-with-icon-icon-color:white;
  --mdc-chip-with-icon-disabled-icon-color:white;
  --mdc-chip-with-icon-selected-icon-color:white;
  --mdc-chip-with-trailing-icon-disabled-trailing-icon-color:white;
  --mdc-chip-with-trailing-icon-trailing-icon-color:white;
  --mat-chip-selected-disabled-trailing-icon-color:white;
  --mat-chip-selected-trailing-icon-color:white;
}
.mat-mdc-standard-chip.mat-mdc-chip-selected.mat-warn,
.mat-mdc-standard-chip.mat-mdc-chip-highlighted.mat-warn {
  --mdc-chip-disabled-label-text-color:white;
  --mdc-chip-elevated-container-color:#f44336;
  --mdc-chip-elevated-selected-container-color:#f44336;
  --mdc-chip-elevated-disabled-container-color:#f44336;
  --mdc-chip-flat-disabled-selected-container-color:#f44336;
  --mdc-chip-focus-state-layer-color:black;
  --mdc-chip-hover-state-layer-color:black;
  --mdc-chip-selected-hover-state-layer-color:black;
  --mdc-chip-focus-state-layer-opacity:0.12;
  --mdc-chip-selected-focus-state-layer-color:black;
  --mdc-chip-selected-focus-state-layer-opacity:0.12;
  --mdc-chip-label-text-color:white;
  --mdc-chip-selected-label-text-color:white;
  --mdc-chip-with-icon-icon-color:white;
  --mdc-chip-with-icon-disabled-icon-color:white;
  --mdc-chip-with-icon-selected-icon-color:white;
  --mdc-chip-with-trailing-icon-disabled-trailing-icon-color:white;
  --mdc-chip-with-trailing-icon-trailing-icon-color:white;
  --mat-chip-selected-disabled-trailing-icon-color:white;
  --mat-chip-selected-trailing-icon-color:white;
}
.mat-mdc-chip.mat-mdc-standard-chip {
  --mdc-chip-container-height:32px;
}
.mat-mdc-standard-chip {
  --mdc-chip-label-text-font:Roboto, sans-serif;
  --mdc-chip-label-text-line-height:20px;
  --mdc-chip-label-text-size:14px;
  --mdc-chip-label-text-tracking:0.0178571429em;
  --mdc-chip-label-text-weight:400;
}
html {
  --mdc-switch-disabled-selected-icon-opacity:0.38;
  --mdc-switch-disabled-track-opacity:0.12;
  --mdc-switch-disabled-unselected-icon-opacity:0.38;
  --mdc-switch-handle-height:20px;
  --mdc-switch-handle-shape:10px;
  --mdc-switch-handle-width:20px;
  --mdc-switch-selected-icon-size:18px;
  --mdc-switch-track-height:14px;
  --mdc-switch-track-shape:7px;
  --mdc-switch-track-width:36px;
  --mdc-switch-unselected-icon-size:18px;
  --mdc-switch-selected-focus-state-layer-opacity:0.12;
  --mdc-switch-selected-hover-state-layer-opacity:0.04;
  --mdc-switch-selected-pressed-state-layer-opacity:0.1;
  --mdc-switch-unselected-focus-state-layer-opacity:0.12;
  --mdc-switch-unselected-hover-state-layer-opacity:0.04;
  --mdc-switch-unselected-pressed-state-layer-opacity:0.1;
  --mat-switch-disabled-selected-handle-opacity:0.38;
  --mat-switch-disabled-unselected-handle-opacity:0.38;
  --mat-switch-unselected-handle-size:20px;
  --mat-switch-selected-handle-size:20px;
  --mat-switch-pressed-handle-size:20px;
  --mat-switch-with-icon-handle-size:20px;
  --mat-switch-selected-handle-horizontal-margin:0;
  --mat-switch-selected-with-icon-handle-horizontal-margin:0;
  --mat-switch-selected-pressed-handle-horizontal-margin:0;
  --mat-switch-unselected-handle-horizontal-margin:0;
  --mat-switch-unselected-with-icon-handle-horizontal-margin:0;
  --mat-switch-unselected-pressed-handle-horizontal-margin:0;
  --mat-switch-visible-track-opacity:1;
  --mat-switch-hidden-track-opacity:1;
  --mat-switch-visible-track-transition:transform 75ms 0ms cubic-bezier(0, 0, 0.2, 1);
  --mat-switch-hidden-track-transition:transform 75ms 0ms cubic-bezier(0.4, 0, 0.6, 1);
  --mat-switch-track-outline-width:1px;
  --mat-switch-track-outline-color:transparent;
  --mat-switch-selected-track-outline-width:1px;
  --mat-switch-disabled-unselected-track-outline-width:1px;
  --mat-switch-disabled-unselected-track-outline-color:transparent;
}
html {
  --mdc-switch-selected-focus-state-layer-color:#3949ab;
  --mdc-switch-selected-handle-color:#3949ab;
  --mdc-switch-selected-hover-state-layer-color:#3949ab;
  --mdc-switch-selected-pressed-state-layer-color:#3949ab;
  --mdc-switch-selected-focus-handle-color:#1a237e;
  --mdc-switch-selected-hover-handle-color:#1a237e;
  --mdc-switch-selected-pressed-handle-color:#1a237e;
  --mdc-switch-selected-focus-track-color:#7986cb;
  --mdc-switch-selected-hover-track-color:#7986cb;
  --mdc-switch-selected-pressed-track-color:#7986cb;
  --mdc-switch-selected-track-color:#7986cb;
  --mdc-switch-disabled-selected-handle-color:#424242;
  --mdc-switch-disabled-selected-icon-color:#fff;
  --mdc-switch-disabled-selected-track-color:#424242;
  --mdc-switch-disabled-unselected-handle-color:#424242;
  --mdc-switch-disabled-unselected-icon-color:#fff;
  --mdc-switch-disabled-unselected-track-color:#424242;
  --mdc-switch-handle-surface-color:var(--mdc-theme-surface, #fff);
  --mdc-switch-handle-elevation-shadow:0px 2px 1px -1px rgba(0, 0, 0, 0.2),
    0px 1px 1px 0px rgba(0, 0, 0, 0.14),
    0px 1px 3px 0px rgba(0, 0, 0, 0.12);
  --mdc-switch-handle-shadow-color:black;
  --mdc-switch-disabled-handle-elevation-shadow:0px 0px 0px 0px rgba(0, 0, 0, 0.2),
    0px 0px 0px 0px rgba(0, 0, 0, 0.14),
    0px 0px 0px 0px rgba(0, 0, 0, 0.12);
  --mdc-switch-selected-icon-color:#fff;
  --mdc-switch-unselected-focus-handle-color:#212121;
  --mdc-switch-unselected-focus-state-layer-color:#424242;
  --mdc-switch-unselected-focus-track-color:#e0e0e0;
  --mdc-switch-unselected-handle-color:#616161;
  --mdc-switch-unselected-hover-handle-color:#212121;
  --mdc-switch-unselected-hover-state-layer-color:#424242;
  --mdc-switch-unselected-hover-track-color:#e0e0e0;
  --mdc-switch-unselected-icon-color:#fff;
  --mdc-switch-unselected-pressed-handle-color:#212121;
  --mdc-switch-unselected-pressed-state-layer-color:#424242;
  --mdc-switch-unselected-pressed-track-color:#e0e0e0;
  --mdc-switch-unselected-track-color:#e0e0e0;
  --mdc-switch-disabled-label-text-color: rgba(0, 0, 0, 0.38);
}
html .mat-mdc-slide-toggle {
  --mdc-form-field-label-text-color:rgba(0, 0, 0, 0.87);
}
html .mat-mdc-slide-toggle.mat-accent {
  --mdc-switch-selected-focus-state-layer-color:#d81b60;
  --mdc-switch-selected-handle-color:#d81b60;
  --mdc-switch-selected-hover-state-layer-color:#d81b60;
  --mdc-switch-selected-pressed-state-layer-color:#d81b60;
  --mdc-switch-selected-focus-handle-color:#880e4f;
  --mdc-switch-selected-hover-handle-color:#880e4f;
  --mdc-switch-selected-pressed-handle-color:#880e4f;
  --mdc-switch-selected-focus-track-color:#f06292;
  --mdc-switch-selected-hover-track-color:#f06292;
  --mdc-switch-selected-pressed-track-color:#f06292;
  --mdc-switch-selected-track-color:#f06292;
}
html .mat-mdc-slide-toggle.mat-warn {
  --mdc-switch-selected-focus-state-layer-color:#e53935;
  --mdc-switch-selected-handle-color:#e53935;
  --mdc-switch-selected-hover-state-layer-color:#e53935;
  --mdc-switch-selected-pressed-state-layer-color:#e53935;
  --mdc-switch-selected-focus-handle-color:#b71c1c;
  --mdc-switch-selected-hover-handle-color:#b71c1c;
  --mdc-switch-selected-pressed-handle-color:#b71c1c;
  --mdc-switch-selected-focus-track-color:#e57373;
  --mdc-switch-selected-hover-track-color:#e57373;
  --mdc-switch-selected-pressed-track-color:#e57373;
  --mdc-switch-selected-track-color:#e57373;
}
html {
  --mdc-switch-state-layer-size:40px;
}
html .mat-mdc-slide-toggle {
  --mdc-form-field-label-text-font:Roboto, sans-serif;
  --mdc-form-field-label-text-line-height:20px;
  --mdc-form-field-label-text-size:14px;
  --mdc-form-field-label-text-tracking:0.0178571429em;
  --mdc-form-field-label-text-weight:400;
}
html {
  --mdc-radio-disabled-selected-icon-opacity:0.38;
  --mdc-radio-disabled-unselected-icon-opacity:0.38;
  --mdc-radio-state-layer-size:40px;
}
.mat-mdc-radio-button {
  --mdc-form-field-label-text-color:rgba(0, 0, 0, 0.87);
}
.mat-mdc-radio-button.mat-primary {
  --mdc-radio-disabled-selected-icon-color:black;
  --mdc-radio-disabled-unselected-icon-color:black;
  --mdc-radio-unselected-hover-icon-color:#212121;
  --mdc-radio-unselected-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-radio-unselected-pressed-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-radio-selected-focus-icon-color:#3f51b5;
  --mdc-radio-selected-hover-icon-color:#3f51b5;
  --mdc-radio-selected-icon-color:#3f51b5;
  --mdc-radio-selected-pressed-icon-color:#3f51b5;
  --mat-radio-ripple-color:black;
  --mat-radio-checked-ripple-color:#3f51b5;
  --mat-radio-disabled-label-color:rgba(0, 0, 0, 0.38);
}
.mat-mdc-radio-button.mat-accent {
  --mdc-radio-disabled-selected-icon-color:black;
  --mdc-radio-disabled-unselected-icon-color:black;
  --mdc-radio-unselected-hover-icon-color:#212121;
  --mdc-radio-unselected-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-radio-unselected-pressed-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-radio-selected-focus-icon-color:#ff4081;
  --mdc-radio-selected-hover-icon-color:#ff4081;
  --mdc-radio-selected-icon-color:#ff4081;
  --mdc-radio-selected-pressed-icon-color:#ff4081;
  --mat-radio-ripple-color:black;
  --mat-radio-checked-ripple-color:#ff4081;
  --mat-radio-disabled-label-color:rgba(0, 0, 0, 0.38);
}
.mat-mdc-radio-button.mat-warn {
  --mdc-radio-disabled-selected-icon-color:black;
  --mdc-radio-disabled-unselected-icon-color:black;
  --mdc-radio-unselected-hover-icon-color:#212121;
  --mdc-radio-unselected-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-radio-unselected-pressed-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-radio-selected-focus-icon-color:#f44336;
  --mdc-radio-selected-hover-icon-color:#f44336;
  --mdc-radio-selected-icon-color:#f44336;
  --mdc-radio-selected-pressed-icon-color:#f44336;
  --mat-radio-ripple-color:black;
  --mat-radio-checked-ripple-color:#f44336;
  --mat-radio-disabled-label-color:rgba(0, 0, 0, 0.38);
}
html {
  --mdc-radio-state-layer-size:40px;
  --mat-radio-touch-target-display:block;
}
.mat-mdc-radio-button {
  --mdc-form-field-label-text-font:Roboto, sans-serif;
  --mdc-form-field-label-text-line-height:20px;
  --mdc-form-field-label-text-size:14px;
  --mdc-form-field-label-text-tracking:0.0178571429em;
  --mdc-form-field-label-text-weight:400;
}
html {
  --mat-slider-value-indicator-width:auto;
  --mat-slider-value-indicator-height:32px;
  --mat-slider-value-indicator-caret-display:block;
  --mat-slider-value-indicator-border-radius:4px;
  --mat-slider-value-indicator-padding:0 12px;
  --mat-slider-value-indicator-text-transform:none;
  --mat-slider-value-indicator-container-transform:translateX(-50%);
  --mdc-slider-active-track-height:6px;
  --mdc-slider-active-track-shape:9999px;
  --mdc-slider-handle-height:20px;
  --mdc-slider-handle-shape:50%;
  --mdc-slider-handle-width:20px;
  --mdc-slider-inactive-track-height:4px;
  --mdc-slider-inactive-track-shape:9999px;
  --mdc-slider-with-overlap-handle-outline-width:1px;
  --mdc-slider-with-tick-marks-active-container-opacity:0.6;
  --mdc-slider-with-tick-marks-container-shape:50%;
  --mdc-slider-with-tick-marks-container-size:2px;
  --mdc-slider-with-tick-marks-inactive-container-opacity:0.6;
}
html {
  --mdc-slider-handle-color:#3f51b5;
  --mdc-slider-focus-handle-color:#3f51b5;
  --mdc-slider-hover-handle-color:#3f51b5;
  --mdc-slider-active-track-color:#3f51b5;
  --mdc-slider-inactive-track-color:#3f51b5;
  --mdc-slider-with-tick-marks-inactive-container-color:#3f51b5;
  --mdc-slider-with-tick-marks-active-container-color:white;
  --mdc-slider-disabled-active-track-color:#000;
  --mdc-slider-disabled-handle-color:#000;
  --mdc-slider-disabled-inactive-track-color:#000;
  --mdc-slider-label-container-color:#000;
  --mdc-slider-label-label-text-color:#fff;
  --mdc-slider-with-overlap-handle-outline-color:#fff;
  --mdc-slider-with-tick-marks-disabled-container-color:#000;
  --mdc-slider-handle-elevation:0px 2px 1px -1px rgba(0, 0, 0, 0.2),
    0px 1px 1px 0px rgba(0, 0, 0, 0.14),
    0px 1px 3px 0px rgba(0, 0, 0, 0.12);
  --mat-slider-ripple-color:#3f51b5;
  --mat-slider-hover-state-layer-color:rgba(63, 81, 181, 0.05);
  --mat-slider-focus-state-layer-color:rgba(63, 81, 181, 0.2);
  --mat-slider-value-indicator-opacity:0.6;
}
html .mat-accent {
  --mat-slider-ripple-color:#ff4081;
  --mat-slider-hover-state-layer-color:rgba(255, 64, 129, 0.05);
  --mat-slider-focus-state-layer-color:rgba(255, 64, 129, 0.2);
  --mdc-slider-handle-color:#ff4081;
  --mdc-slider-focus-handle-color:#ff4081;
  --mdc-slider-hover-handle-color:#ff4081;
  --mdc-slider-active-track-color:#ff4081;
  --mdc-slider-inactive-track-color:#ff4081;
  --mdc-slider-with-tick-marks-inactive-container-color:#ff4081;
  --mdc-slider-with-tick-marks-active-container-color:white;
}
html .mat-warn {
  --mat-slider-ripple-color:#f44336;
  --mat-slider-hover-state-layer-color:rgba(244, 67, 54, 0.05);
  --mat-slider-focus-state-layer-color:rgba(244, 67, 54, 0.2);
  --mdc-slider-handle-color:#f44336;
  --mdc-slider-focus-handle-color:#f44336;
  --mdc-slider-hover-handle-color:#f44336;
  --mdc-slider-active-track-color:#f44336;
  --mdc-slider-inactive-track-color:#f44336;
  --mdc-slider-with-tick-marks-inactive-container-color:#f44336;
  --mdc-slider-with-tick-marks-active-container-color:white;
}
html {
  --mdc-slider-label-label-text-font:Roboto, sans-serif;
  --mdc-slider-label-label-text-size:14px;
  --mdc-slider-label-label-text-line-height:22px;
  --mdc-slider-label-label-text-tracking:0.0071428571em;
  --mdc-slider-label-label-text-weight:500;
}
html {
  --mat-menu-container-shape:4px;
  --mat-menu-divider-bottom-spacing:0;
  --mat-menu-divider-top-spacing:0;
  --mat-menu-item-spacing:16px;
  --mat-menu-item-icon-size:24px;
  --mat-menu-item-leading-spacing:16px;
  --mat-menu-item-trailing-spacing:16px;
  --mat-menu-item-with-icon-leading-spacing:16px;
  --mat-menu-item-with-icon-trailing-spacing:16px;
}
html {
  --mat-menu-item-label-text-color:rgba(0, 0, 0, 0.87);
  --mat-menu-item-icon-color:rgba(0, 0, 0, 0.87);
  --mat-menu-item-hover-state-layer-color:rgba(0, 0, 0, 0.04);
  --mat-menu-item-focus-state-layer-color:rgba(0, 0, 0, 0.04);
  --mat-menu-container-color:white;
  --mat-menu-divider-color:rgba(0, 0, 0, 0.12);
}
html {
  --mat-menu-item-label-text-font:Roboto, sans-serif;
  --mat-menu-item-label-text-size:16px;
  --mat-menu-item-label-text-tracking:0.03125em;
  --mat-menu-item-label-text-line-height:24px;
  --mat-menu-item-label-text-weight:400;
}
html {
  --mdc-list-list-item-container-shape:0;
  --mdc-list-list-item-leading-avatar-shape:50%;
  --mdc-list-list-item-container-color:transparent;
  --mdc-list-list-item-selected-container-color:transparent;
  --mdc-list-list-item-leading-avatar-color:transparent;
  --mdc-list-list-item-leading-icon-size:24px;
  --mdc-list-list-item-leading-avatar-size:40px;
  --mdc-list-list-item-trailing-icon-size:24px;
  --mdc-list-list-item-disabled-state-layer-color:transparent;
  --mdc-list-list-item-disabled-state-layer-opacity:0;
  --mdc-list-list-item-disabled-label-text-opacity:0.38;
  --mdc-list-list-item-disabled-leading-icon-opacity:0.38;
  --mdc-list-list-item-disabled-trailing-icon-opacity:0.38;
  --mat-list-active-indicator-color:transparent;
  --mat-list-active-indicator-shape:4px;
}
html {
  --mdc-list-list-item-label-text-color:rgba(0, 0, 0, 0.87);
  --mdc-list-list-item-supporting-text-color:rgba(0, 0, 0, 0.54);
  --mdc-list-list-item-leading-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-list-list-item-trailing-supporting-text-color:rgba(0, 0, 0, 0.38);
  --mdc-list-list-item-trailing-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-list-list-item-selected-trailing-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-list-list-item-disabled-label-text-color:black;
  --mdc-list-list-item-disabled-leading-icon-color:black;
  --mdc-list-list-item-disabled-trailing-icon-color:black;
  --mdc-list-list-item-hover-label-text-color:rgba(0, 0, 0, 0.87);
  --mdc-list-list-item-hover-leading-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-list-list-item-hover-trailing-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-list-list-item-focus-label-text-color:rgba(0, 0, 0, 0.87);
  --mdc-list-list-item-hover-state-layer-color:black;
  --mdc-list-list-item-hover-state-layer-opacity:0.04;
  --mdc-list-list-item-focus-state-layer-color:black;
  --mdc-list-list-item-focus-state-layer-opacity:0.12;
}
.mdc-list-item__start,
.mdc-list-item__end {
  --mdc-radio-disabled-selected-icon-color:black;
  --mdc-radio-disabled-unselected-icon-color:black;
  --mdc-radio-unselected-hover-icon-color:#212121;
  --mdc-radio-unselected-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-radio-unselected-pressed-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-radio-selected-focus-icon-color:#3f51b5;
  --mdc-radio-selected-hover-icon-color:#3f51b5;
  --mdc-radio-selected-icon-color:#3f51b5;
  --mdc-radio-selected-pressed-icon-color:#3f51b5;
}
.mat-accent .mdc-list-item__start,
.mat-accent .mdc-list-item__end {
  --mdc-radio-disabled-selected-icon-color:black;
  --mdc-radio-disabled-unselected-icon-color:black;
  --mdc-radio-unselected-hover-icon-color:#212121;
  --mdc-radio-unselected-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-radio-unselected-pressed-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-radio-selected-focus-icon-color:#ff4081;
  --mdc-radio-selected-hover-icon-color:#ff4081;
  --mdc-radio-selected-icon-color:#ff4081;
  --mdc-radio-selected-pressed-icon-color:#ff4081;
}
.mat-warn .mdc-list-item__start,
.mat-warn .mdc-list-item__end {
  --mdc-radio-disabled-selected-icon-color:black;
  --mdc-radio-disabled-unselected-icon-color:black;
  --mdc-radio-unselected-hover-icon-color:#212121;
  --mdc-radio-unselected-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-radio-unselected-pressed-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-radio-selected-focus-icon-color:#f44336;
  --mdc-radio-selected-hover-icon-color:#f44336;
  --mdc-radio-selected-icon-color:#f44336;
  --mdc-radio-selected-pressed-icon-color:#f44336;
}
.mat-mdc-list-option {
  --mdc-checkbox-disabled-selected-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-checkbox-disabled-unselected-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-checkbox-selected-checkmark-color:white;
  --mdc-checkbox-selected-focus-icon-color:#3f51b5;
  --mdc-checkbox-selected-hover-icon-color:#3f51b5;
  --mdc-checkbox-selected-icon-color:#3f51b5;
  --mdc-checkbox-selected-pressed-icon-color:#3f51b5;
  --mdc-checkbox-unselected-focus-icon-color:#212121;
  --mdc-checkbox-unselected-hover-icon-color:#212121;
  --mdc-checkbox-unselected-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-checkbox-unselected-pressed-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-checkbox-selected-focus-state-layer-color:#3f51b5;
  --mdc-checkbox-selected-hover-state-layer-color:#3f51b5;
  --mdc-checkbox-selected-pressed-state-layer-color:#3f51b5;
  --mdc-checkbox-unselected-focus-state-layer-color:black;
  --mdc-checkbox-unselected-hover-state-layer-color:black;
  --mdc-checkbox-unselected-pressed-state-layer-color:black;
}
.mat-mdc-list-option.mat-accent {
  --mdc-checkbox-disabled-selected-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-checkbox-disabled-unselected-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-checkbox-selected-checkmark-color:white;
  --mdc-checkbox-selected-focus-icon-color:#ff4081;
  --mdc-checkbox-selected-hover-icon-color:#ff4081;
  --mdc-checkbox-selected-icon-color:#ff4081;
  --mdc-checkbox-selected-pressed-icon-color:#ff4081;
  --mdc-checkbox-unselected-focus-icon-color:#212121;
  --mdc-checkbox-unselected-hover-icon-color:#212121;
  --mdc-checkbox-unselected-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-checkbox-unselected-pressed-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-checkbox-selected-focus-state-layer-color:#ff4081;
  --mdc-checkbox-selected-hover-state-layer-color:#ff4081;
  --mdc-checkbox-selected-pressed-state-layer-color:#ff4081;
  --mdc-checkbox-unselected-focus-state-layer-color:black;
  --mdc-checkbox-unselected-hover-state-layer-color:black;
  --mdc-checkbox-unselected-pressed-state-layer-color:black;
}
.mat-mdc-list-option.mat-warn {
  --mdc-checkbox-disabled-selected-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-checkbox-disabled-unselected-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-checkbox-selected-checkmark-color:white;
  --mdc-checkbox-selected-focus-icon-color:#f44336;
  --mdc-checkbox-selected-hover-icon-color:#f44336;
  --mdc-checkbox-selected-icon-color:#f44336;
  --mdc-checkbox-selected-pressed-icon-color:#f44336;
  --mdc-checkbox-unselected-focus-icon-color:#212121;
  --mdc-checkbox-unselected-hover-icon-color:#212121;
  --mdc-checkbox-unselected-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-checkbox-unselected-pressed-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-checkbox-selected-focus-state-layer-color:#f44336;
  --mdc-checkbox-selected-hover-state-layer-color:#f44336;
  --mdc-checkbox-selected-pressed-state-layer-color:#f44336;
  --mdc-checkbox-unselected-focus-state-layer-color:black;
  --mdc-checkbox-unselected-hover-state-layer-color:black;
  --mdc-checkbox-unselected-pressed-state-layer-color:black;
}
.mat-mdc-list-base.mat-mdc-list-base .mdc-list-item--selected .mdc-list-item__primary-text,
.mat-mdc-list-base.mat-mdc-list-base .mdc-list-item--activated .mdc-list-item__primary-text {
  color: #3f51b5;
}
.mat-mdc-list-base.mat-mdc-list-base .mdc-list-item--selected.mdc-list-item--with-leading-icon .mdc-list-item__start,
.mat-mdc-list-base.mat-mdc-list-base .mdc-list-item--activated.mdc-list-item--with-leading-icon .mdc-list-item__start {
  color: #3f51b5;
}
.mat-mdc-list-base .mdc-list-item--disabled .mdc-list-item__start,
.mat-mdc-list-base .mdc-list-item--disabled .mdc-list-item__content,
.mat-mdc-list-base .mdc-list-item--disabled .mdc-list-item__end {
  opacity: 1;
}
html {
  --mdc-list-list-item-one-line-container-height:48px;
  --mdc-list-list-item-two-line-container-height:64px;
  --mdc-list-list-item-three-line-container-height:88px;
  --mat-list-list-item-leading-icon-start-space:16px;
  --mat-list-list-item-leading-icon-end-space:32px;
}
.mdc-list-item__start,
.mdc-list-item__end {
  --mdc-radio-state-layer-size:40px;
}
.mat-mdc-list-item.mdc-list-item--with-leading-avatar.mdc-list-item--with-one-line,
.mat-mdc-list-item.mdc-list-item--with-leading-checkbox.mdc-list-item--with-one-line,
.mat-mdc-list-item.mdc-list-item--with-leading-icon.mdc-list-item--with-one-line {
  height: 56px;
}
.mat-mdc-list-item.mdc-list-item--with-leading-avatar.mdc-list-item--with-two-lines,
.mat-mdc-list-item.mdc-list-item--with-leading-checkbox.mdc-list-item--with-two-lines,
.mat-mdc-list-item.mdc-list-item--with-leading-icon.mdc-list-item--with-two-lines {
  height: 72px;
}
html {
  --mdc-list-list-item-label-text-font:Roboto, sans-serif;
  --mdc-list-list-item-label-text-line-height:24px;
  --mdc-list-list-item-label-text-size:16px;
  --mdc-list-list-item-label-text-tracking:0.03125em;
  --mdc-list-list-item-label-text-weight:400;
  --mdc-list-list-item-supporting-text-font:Roboto, sans-serif;
  --mdc-list-list-item-supporting-text-line-height:20px;
  --mdc-list-list-item-supporting-text-size:14px;
  --mdc-list-list-item-supporting-text-tracking:0.0178571429em;
  --mdc-list-list-item-supporting-text-weight:400;
  --mdc-list-list-item-trailing-supporting-text-font:Roboto, sans-serif;
  --mdc-list-list-item-trailing-supporting-text-line-height:20px;
  --mdc-list-list-item-trailing-supporting-text-size:12px;
  --mdc-list-list-item-trailing-supporting-text-tracking:0.0333333333em;
  --mdc-list-list-item-trailing-supporting-text-weight:400;
}
.mdc-list-group__subheader {
  font: 400 16px/28px Roboto, sans-serif;
  letter-spacing: .009375em;
}
html {
  --mat-paginator-container-text-color:rgba(0, 0, 0, 0.87);
  --mat-paginator-container-background-color:white;
  --mat-paginator-enabled-icon-color:rgba(0, 0, 0, 0.54);
  --mat-paginator-disabled-icon-color:rgba(0, 0, 0, 0.12);
}
html {
  --mat-paginator-container-size:56px;
  --mat-paginator-form-field-container-height:40px;
  --mat-paginator-form-field-container-vertical-padding:8px;
}
html {
  --mat-paginator-container-text-font:Roboto, sans-serif;
  --mat-paginator-container-text-line-height:20px;
  --mat-paginator-container-text-size:12px;
  --mat-paginator-container-text-tracking:0.0333333333em;
  --mat-paginator-container-text-weight:400;
  --mat-paginator-select-trigger-text-size:12px;
}
html {
  --mdc-tab-indicator-active-indicator-height:2px;
  --mdc-tab-indicator-active-indicator-shape:0;
  --mdc-secondary-navigation-tab-container-height:48px;
  --mat-tab-header-divider-color:transparent;
  --mat-tab-header-divider-height:0;
}
.mat-mdc-tab-group,
.mat-mdc-tab-nav-bar {
  --mdc-tab-indicator-active-indicator-color:#3f51b5;
  --mat-tab-header-disabled-ripple-color:rgba(0, 0, 0, 0.38);
  --mat-tab-header-pagination-icon-color:black;
  --mat-tab-header-inactive-label-text-color:rgba(0, 0, 0, 0.6);
  --mat-tab-header-active-label-text-color:#3f51b5;
  --mat-tab-header-active-ripple-color:#3f51b5;
  --mat-tab-header-inactive-ripple-color:#3f51b5;
  --mat-tab-header-inactive-focus-label-text-color:rgba(0, 0, 0, 0.6);
  --mat-tab-header-inactive-hover-label-text-color:rgba(0, 0, 0, 0.6);
  --mat-tab-header-active-focus-label-text-color:#3f51b5;
  --mat-tab-header-active-hover-label-text-color:#3f51b5;
  --mat-tab-header-active-focus-indicator-color:#3f51b5;
  --mat-tab-header-active-hover-indicator-color:#3f51b5;
}
.mat-mdc-tab-group.mat-accent,
.mat-mdc-tab-nav-bar.mat-accent {
  --mdc-tab-indicator-active-indicator-color:#ff4081;
  --mat-tab-header-disabled-ripple-color:rgba(0, 0, 0, 0.38);
  --mat-tab-header-pagination-icon-color:black;
  --mat-tab-header-inactive-label-text-color:rgba(0, 0, 0, 0.6);
  --mat-tab-header-active-label-text-color:#ff4081;
  --mat-tab-header-active-ripple-color:#ff4081;
  --mat-tab-header-inactive-ripple-color:#ff4081;
  --mat-tab-header-inactive-focus-label-text-color:rgba(0, 0, 0, 0.6);
  --mat-tab-header-inactive-hover-label-text-color:rgba(0, 0, 0, 0.6);
  --mat-tab-header-active-focus-label-text-color:#ff4081;
  --mat-tab-header-active-hover-label-text-color:#ff4081;
  --mat-tab-header-active-focus-indicator-color:#ff4081;
  --mat-tab-header-active-hover-indicator-color:#ff4081;
}
.mat-mdc-tab-group.mat-warn,
.mat-mdc-tab-nav-bar.mat-warn {
  --mdc-tab-indicator-active-indicator-color:#f44336;
  --mat-tab-header-disabled-ripple-color:rgba(0, 0, 0, 0.38);
  --mat-tab-header-pagination-icon-color:black;
  --mat-tab-header-inactive-label-text-color:rgba(0, 0, 0, 0.6);
  --mat-tab-header-active-label-text-color:#f44336;
  --mat-tab-header-active-ripple-color:#f44336;
  --mat-tab-header-inactive-ripple-color:#f44336;
  --mat-tab-header-inactive-focus-label-text-color:rgba(0, 0, 0, 0.6);
  --mat-tab-header-inactive-hover-label-text-color:rgba(0, 0, 0, 0.6);
  --mat-tab-header-active-focus-label-text-color:#f44336;
  --mat-tab-header-active-hover-label-text-color:#f44336;
  --mat-tab-header-active-focus-indicator-color:#f44336;
  --mat-tab-header-active-hover-indicator-color:#f44336;
}
.mat-mdc-tab-group.mat-background-primary,
.mat-mdc-tab-nav-bar.mat-background-primary {
  --mat-tab-header-with-background-background-color:#3f51b5;
  --mat-tab-header-with-background-foreground-color:white;
}
.mat-mdc-tab-group.mat-background-accent,
.mat-mdc-tab-nav-bar.mat-background-accent {
  --mat-tab-header-with-background-background-color:#ff4081;
  --mat-tab-header-with-background-foreground-color:white;
}
.mat-mdc-tab-group.mat-background-warn,
.mat-mdc-tab-nav-bar.mat-background-warn {
  --mat-tab-header-with-background-background-color:#f44336;
  --mat-tab-header-with-background-foreground-color:white;
}
.mat-mdc-tab-header {
  --mdc-secondary-navigation-tab-container-height:48px;
}
.mat-mdc-tab-header {
  --mat-tab-header-label-text-font:Roboto, sans-serif;
  --mat-tab-header-label-text-size:14px;
  --mat-tab-header-label-text-tracking:0.0892857143em;
  --mat-tab-header-label-text-line-height:36px;
  --mat-tab-header-label-text-weight:500;
}
html {
  --mdc-checkbox-disabled-selected-checkmark-color:#fff;
  --mdc-checkbox-selected-focus-state-layer-opacity:0.16;
  --mdc-checkbox-selected-hover-state-layer-opacity:0.04;
  --mdc-checkbox-selected-pressed-state-layer-opacity:0.16;
  --mdc-checkbox-unselected-focus-state-layer-opacity:0.16;
  --mdc-checkbox-unselected-hover-state-layer-opacity:0.04;
  --mdc-checkbox-unselected-pressed-state-layer-opacity:0.16;
}
html {
  --mdc-checkbox-disabled-selected-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-checkbox-disabled-unselected-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-checkbox-selected-checkmark-color:white;
  --mdc-checkbox-selected-focus-icon-color:#ff4081;
  --mdc-checkbox-selected-hover-icon-color:#ff4081;
  --mdc-checkbox-selected-icon-color:#ff4081;
  --mdc-checkbox-selected-pressed-icon-color:#ff4081;
  --mdc-checkbox-unselected-focus-icon-color:#212121;
  --mdc-checkbox-unselected-hover-icon-color:#212121;
  --mdc-checkbox-unselected-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-checkbox-unselected-pressed-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-checkbox-selected-focus-state-layer-color:#ff4081;
  --mdc-checkbox-selected-hover-state-layer-color:#ff4081;
  --mdc-checkbox-selected-pressed-state-layer-color:#ff4081;
  --mdc-checkbox-unselected-focus-state-layer-color:black;
  --mdc-checkbox-unselected-hover-state-layer-color:black;
  --mdc-checkbox-unselected-pressed-state-layer-color:black;
  --mat-checkbox-disabled-label-color:rgba(0, 0, 0, 0.38);
}
.mat-mdc-checkbox {
  --mdc-form-field-label-text-color:rgba(0, 0, 0, 0.87);
}
.mat-mdc-checkbox.mat-primary {
  --mdc-checkbox-disabled-selected-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-checkbox-disabled-unselected-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-checkbox-selected-checkmark-color:white;
  --mdc-checkbox-selected-focus-icon-color:#3f51b5;
  --mdc-checkbox-selected-hover-icon-color:#3f51b5;
  --mdc-checkbox-selected-icon-color:#3f51b5;
  --mdc-checkbox-selected-pressed-icon-color:#3f51b5;
  --mdc-checkbox-unselected-focus-icon-color:#212121;
  --mdc-checkbox-unselected-hover-icon-color:#212121;
  --mdc-checkbox-unselected-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-checkbox-unselected-pressed-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-checkbox-selected-focus-state-layer-color:#3f51b5;
  --mdc-checkbox-selected-hover-state-layer-color:#3f51b5;
  --mdc-checkbox-selected-pressed-state-layer-color:#3f51b5;
  --mdc-checkbox-unselected-focus-state-layer-color:black;
  --mdc-checkbox-unselected-hover-state-layer-color:black;
  --mdc-checkbox-unselected-pressed-state-layer-color:black;
}
.mat-mdc-checkbox.mat-warn {
  --mdc-checkbox-disabled-selected-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-checkbox-disabled-unselected-icon-color:rgba(0, 0, 0, 0.38);
  --mdc-checkbox-selected-checkmark-color:white;
  --mdc-checkbox-selected-focus-icon-color:#f44336;
  --mdc-checkbox-selected-hover-icon-color:#f44336;
  --mdc-checkbox-selected-icon-color:#f44336;
  --mdc-checkbox-selected-pressed-icon-color:#f44336;
  --mdc-checkbox-unselected-focus-icon-color:#212121;
  --mdc-checkbox-unselected-hover-icon-color:#212121;
  --mdc-checkbox-unselected-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-checkbox-unselected-pressed-icon-color:rgba(0, 0, 0, 0.54);
  --mdc-checkbox-selected-focus-state-layer-color:#f44336;
  --mdc-checkbox-selected-hover-state-layer-color:#f44336;
  --mdc-checkbox-selected-pressed-state-layer-color:#f44336;
  --mdc-checkbox-unselected-focus-state-layer-color:black;
  --mdc-checkbox-unselected-hover-state-layer-color:black;
  --mdc-checkbox-unselected-pressed-state-layer-color:black;
}
html {
  --mdc-checkbox-state-layer-size:40px;
  --mat-checkbox-touch-target-display:block;
}
.mat-mdc-checkbox {
  --mdc-form-field-label-text-font:Roboto, sans-serif;
  --mdc-form-field-label-text-line-height:20px;
  --mdc-form-field-label-text-size:14px;
  --mdc-form-field-label-text-tracking:0.0178571429em;
  --mdc-form-field-label-text-weight:400;
}
html {
  --mdc-text-button-container-shape:4px;
  --mdc-text-button-keep-touch-target:false;
  --mdc-filled-button-container-shape:4px;
  --mdc-filled-button-keep-touch-target:false;
  --mdc-protected-button-container-shape:4px;
  --mdc-protected-button-keep-touch-target:false;
  --mdc-outlined-button-keep-touch-target:false;
  --mdc-outlined-button-outline-width:1px;
  --mdc-outlined-button-container-shape:4px;
  --mat-text-button-horizontal-padding:8px;
  --mat-text-button-with-icon-horizontal-padding:8px;
  --mat-text-button-icon-spacing:8px;
  --mat-text-button-icon-offset:0;
  --mat-filled-button-horizontal-padding:16px;
  --mat-filled-button-icon-spacing:8px;
  --mat-filled-button-icon-offset:-4px;
  --mat-protected-button-horizontal-padding:16px;
  --mat-protected-button-icon-spacing:8px;
  --mat-protected-button-icon-offset:-4px;
  --mat-outlined-button-horizontal-padding:15px;
  --mat-outlined-button-icon-spacing:8px;
  --mat-outlined-button-icon-offset:-4px;
}
html {
  --mdc-text-button-label-text-color:black;
  --mdc-text-button-disabled-label-text-color:rgba(0, 0, 0, 0.38);
  --mat-text-button-state-layer-color:black;
  --mat-text-button-disabled-state-layer-color:black;
  --mat-text-button-ripple-color:rgba(0, 0, 0, 0.1);
  --mat-text-button-hover-state-layer-opacity:0.04;
  --mat-text-button-focus-state-layer-opacity:0.12;
  --mat-text-button-pressed-state-layer-opacity:0.12;
  --mdc-filled-button-container-color:white;
  --mdc-filled-button-label-text-color:black;
  --mdc-filled-button-disabled-container-color:rgba(0, 0, 0, 0.12);
  --mdc-filled-button-disabled-label-text-color:rgba(0, 0, 0, 0.38);
  --mat-filled-button-state-layer-color:black;
  --mat-filled-button-disabled-state-layer-color:black;
  --mat-filled-button-ripple-color:rgba(0, 0, 0, 0.1);
  --mat-filled-button-hover-state-layer-opacity:0.04;
  --mat-filled-button-focus-state-layer-opacity:0.12;
  --mat-filled-button-pressed-state-layer-opacity:0.12;
  --mdc-protected-button-container-color:white;
  --mdc-protected-button-label-text-color:black;
  --mdc-protected-button-disabled-container-color:rgba(0, 0, 0, 0.12);
  --mdc-protected-button-disabled-label-text-color:rgba(0, 0, 0, 0.38);
  --mdc-protected-button-container-elevation-shadow:0px 3px 1px -2px rgba(0, 0, 0, 0.2),
    0px 2px 2px 0px rgba(0, 0, 0, 0.14),
    0px 1px 5px 0px rgba(0, 0, 0, 0.12);
  --mdc-protected-button-disabled-container-elevation-shadow:0px 0px 0px 0px rgba(0, 0, 0, 0.2),
    0px 0px 0px 0px rgba(0, 0, 0, 0.14),
    0px 0px 0px 0px rgba(0, 0, 0, 0.12);
  --mdc-protected-button-focus-container-elevation-shadow:0px 2px 4px -1px rgba(0, 0, 0, 0.2),
    0px 4px 5px 0px rgba(0, 0, 0, 0.14),
    0px 1px 10px 0px rgba(0, 0, 0, 0.12);
  --mdc-protected-button-hover-container-elevation-shadow:0px 2px 4px -1px rgba(0, 0, 0, 0.2),
    0px 4px 5px 0px rgba(0, 0, 0, 0.14),
    0px 1px 10px 0px rgba(0, 0, 0, 0.12);
  --mdc-protected-button-pressed-container-elevation-shadow:0px 5px 5px -3px rgba(0, 0, 0, 0.2),
    0px 8px 10px 1px rgba(0, 0, 0, 0.14),
    0px 3px 14px 2px rgba(0, 0, 0, 0.12);
  --mdc-protected-button-container-shadow-color:#000;
  --mat-protected-button-state-layer-color:black;
  --mat-protected-button-disabled-state-layer-color:black;
  --mat-protected-button-ripple-color:rgba(0, 0, 0, 0.1);
  --mat-protected-button-hover-state-layer-opacity:0.04;
  --mat-protected-button-focus-state-layer-opacity:0.12;
  --mat-protected-button-pressed-state-layer-opacity:0.12;
  --mdc-outlined-button-disabled-outline-color:rgba(0, 0, 0, 0.12);
  --mdc-outlined-button-disabled-label-text-color:rgba(0, 0, 0, 0.38);
  --mdc-outlined-button-label-text-color:black;
  --mdc-outlined-button-outline-color:rgba(0, 0, 0, 0.12);
  --mat-outlined-button-state-layer-color:black;
  --mat-outlined-button-disabled-state-layer-color:black;
  --mat-outlined-button-ripple-color:rgba(0, 0, 0, 0.1);
  --mat-outlined-button-hover-state-layer-opacity:0.04;
  --mat-outlined-button-focus-state-layer-opacity:0.12;
  --mat-outlined-button-pressed-state-layer-opacity:0.12;
}
.mat-mdc-button.mat-primary {
  --mdc-text-button-label-text-color:#3f51b5;
  --mat-text-button-state-layer-color:#3f51b5;
  --mat-text-button-ripple-color:rgba(63, 81, 181, 0.1);
}
.mat-mdc-button.mat-accent {
  --mdc-text-button-label-text-color:#ff4081;
  --mat-text-button-state-layer-color:#ff4081;
  --mat-text-button-ripple-color:rgba(255, 64, 129, 0.1);
}
.mat-mdc-button.mat-warn {
  --mdc-text-button-label-text-color:#f44336;
  --mat-text-button-state-layer-color:#f44336;
  --mat-text-button-ripple-color:rgba(244, 67, 54, 0.1);
}
.mat-mdc-unelevated-button.mat-primary {
  --mdc-filled-button-container-color:#3f51b5;
  --mdc-filled-button-label-text-color:white;
  --mat-filled-button-state-layer-color:white;
  --mat-filled-button-ripple-color:rgba(255, 255, 255, 0.1);
}
.mat-mdc-unelevated-button.mat-accent {
  --mdc-filled-button-container-color:#ff4081;
  --mdc-filled-button-label-text-color:white;
  --mat-filled-button-state-layer-color:white;
  --mat-filled-button-ripple-color:rgba(255, 255, 255, 0.1);
}
.mat-mdc-unelevated-button.mat-warn {
  --mdc-filled-button-container-color:#f44336;
  --mdc-filled-button-label-text-color:white;
  --mat-filled-button-state-layer-color:white;
  --mat-filled-button-ripple-color:rgba(255, 255, 255, 0.1);
}
.mat-mdc-raised-button.mat-primary {
  --mdc-protected-button-container-color:#3f51b5;
  --mdc-protected-button-label-text-color:white;
  --mat-protected-button-state-layer-color:white;
  --mat-protected-button-ripple-color:rgba(255, 255, 255, 0.1);
}
.mat-mdc-raised-button.mat-accent {
  --mdc-protected-button-container-color:#ff4081;
  --mdc-protected-button-label-text-color:white;
  --mat-protected-button-state-layer-color:white;
  --mat-protected-button-ripple-color:rgba(255, 255, 255, 0.1);
}
.mat-mdc-raised-button.mat-warn {
  --mdc-protected-button-container-color:#f44336;
  --mdc-protected-button-label-text-color:white;
  --mat-protected-button-state-layer-color:white;
  --mat-protected-button-ripple-color:rgba(255, 255, 255, 0.1);
}
.mat-mdc-outlined-button.mat-primary {
  --mdc-outlined-button-label-text-color:#3f51b5;
  --mdc-outlined-button-outline-color:rgba(0, 0, 0, 0.12);
  --mat-outlined-button-state-layer-color:#3f51b5;
  --mat-outlined-button-ripple-color:rgba(63, 81, 181, 0.1);
}
.mat-mdc-outlined-button.mat-accent {
  --mdc-outlined-button-label-text-color:#ff4081;
  --mdc-outlined-button-outline-color:rgba(0, 0, 0, 0.12);
  --mat-outlined-button-state-layer-color:#ff4081;
  --mat-outlined-button-ripple-color:rgba(255, 64, 129, 0.1);
}
.mat-mdc-outlined-button.mat-warn {
  --mdc-outlined-button-label-text-color:#f44336;
  --mdc-outlined-button-outline-color:rgba(0, 0, 0, 0.12);
  --mat-outlined-button-state-layer-color:#f44336;
  --mat-outlined-button-ripple-color:rgba(244, 67, 54, 0.1);
}
html {
  --mdc-text-button-container-height:36px;
  --mdc-filled-button-container-height:36px;
  --mdc-outlined-button-container-height:36px;
  --mdc-protected-button-container-height:36px;
  --mat-text-button-touch-target-display:block;
  --mat-filled-button-touch-target-display:block;
  --mat-protected-button-touch-target-display:block;
  --mat-outlined-button-touch-target-display:block;
}
html {
  --mdc-text-button-label-text-font:Roboto, sans-serif;
  --mdc-text-button-label-text-size:14px;
  --mdc-text-button-label-text-tracking:0.0892857143em;
  --mdc-text-button-label-text-weight:500;
  --mdc-text-button-label-text-transform:none;
  --mdc-filled-button-label-text-font:Roboto, sans-serif;
  --mdc-filled-button-label-text-size:14px;
  --mdc-filled-button-label-text-tracking:0.0892857143em;
  --mdc-filled-button-label-text-weight:500;
  --mdc-filled-button-label-text-transform:none;
  --mdc-outlined-button-label-text-font:Roboto, sans-serif;
  --mdc-outlined-button-label-text-size:14px;
  --mdc-outlined-button-label-text-tracking:0.0892857143em;
  --mdc-outlined-button-label-text-weight:500;
  --mdc-outlined-button-label-text-transform:none;
  --mdc-protected-button-label-text-font:Roboto, sans-serif;
  --mdc-protected-button-label-text-size:14px;
  --mdc-protected-button-label-text-tracking:0.0892857143em;
  --mdc-protected-button-label-text-weight:500;
  --mdc-protected-button-label-text-transform:none;
}
html {
  --mdc-icon-button-icon-size:24px;
}
html {
  --mdc-icon-button-icon-color:inherit;
  --mdc-icon-button-disabled-icon-color:rgba(0, 0, 0, 0.38);
  --mat-icon-button-state-layer-color:black;
  --mat-icon-button-disabled-state-layer-color:black;
  --mat-icon-button-ripple-color:rgba(0, 0, 0, 0.1);
  --mat-icon-button-hover-state-layer-opacity:0.04;
  --mat-icon-button-focus-state-layer-opacity:0.12;
  --mat-icon-button-pressed-state-layer-opacity:0.12;
}
html .mat-mdc-icon-button.mat-primary {
  --mdc-icon-button-icon-color:#3f51b5;
  --mat-icon-button-state-layer-color:#3f51b5;
  --mat-icon-button-ripple-color:rgba(63, 81, 181, 0.1);
}
html .mat-mdc-icon-button.mat-accent {
  --mdc-icon-button-icon-color:#ff4081;
  --mat-icon-button-state-layer-color:#ff4081;
  --mat-icon-button-ripple-color:rgba(255, 64, 129, 0.1);
}
html .mat-mdc-icon-button.mat-warn {
  --mdc-icon-button-icon-color:#f44336;
  --mat-icon-button-state-layer-color:#f44336;
  --mat-icon-button-ripple-color:rgba(244, 67, 54, 0.1);
}
html {
  --mat-icon-button-touch-target-display:block;
}
.mat-mdc-icon-button.mat-mdc-button-base {
  --mdc-icon-button-state-layer-size:48px;
  width: var(--mdc-icon-button-state-layer-size);
  height: var(--mdc-icon-button-state-layer-size);
  padding: 12px;
}
html {
  --mdc-fab-container-shape:50%;
  --mdc-fab-icon-size:24px;
  --mdc-fab-small-container-shape:50%;
  --mdc-fab-small-icon-size:24px;
  --mdc-extended-fab-container-height:48px;
  --mdc-extended-fab-container-shape:24px;
}
html {
  --mdc-fab-container-color:white;
  --mdc-fab-container-elevation-shadow:0px 3px 5px -1px rgba(0, 0, 0, 0.2),
    0px 6px 10px 0px rgba(0, 0, 0, 0.14),
    0px 1px 18px 0px rgba(0, 0, 0, 0.12);
  --mdc-fab-focus-container-elevation-shadow:0px 5px 5px -3px rgba(0, 0, 0, 0.2),
    0px 8px 10px 1px rgba(0, 0, 0, 0.14),
    0px 3px 14px 2px rgba(0, 0, 0, 0.12);
  --mdc-fab-hover-container-elevation-shadow:0px 5px 5px -3px rgba(0, 0, 0, 0.2),
    0px 8px 10px 1px rgba(0, 0, 0, 0.14),
    0px 3px 14px 2px rgba(0, 0, 0, 0.12);
  --mdc-fab-pressed-container-elevation-shadow:0px 7px 8px -4px rgba(0, 0, 0, 0.2),
    0px 12px 17px 2px rgba(0, 0, 0, 0.14),
    0px 5px 22px 4px rgba(0, 0, 0, 0.12);
  --mdc-fab-container-shadow-color:#000;
  --mat-fab-foreground-color:black;
  --mat-fab-state-layer-color:black;
  --mat-fab-disabled-state-layer-color:black;
  --mat-fab-ripple-color:rgba(0, 0, 0, 0.1);
  --mat-fab-hover-state-layer-opacity:0.04;
  --mat-fab-focus-state-layer-opacity:0.12;
  --mat-fab-pressed-state-layer-opacity:0.12;
  --mat-fab-disabled-state-container-color:rgba(0, 0, 0, 0.12);
  --mat-fab-disabled-state-foreground-color:rgba(0, 0, 0, 0.38);
  --mdc-fab-small-container-color:white;
  --mdc-fab-small-container-elevation-shadow:0px 3px 5px -1px rgba(0, 0, 0, 0.2),
    0px 6px 10px 0px rgba(0, 0, 0, 0.14),
    0px 1px 18px 0px rgba(0, 0, 0, 0.12);
  --mdc-fab-small-focus-container-elevation-shadow:0px 5px 5px -3px rgba(0, 0, 0, 0.2),
    0px 8px 10px 1px rgba(0, 0, 0, 0.14),
    0px 3px 14px 2px rgba(0, 0, 0, 0.12);
  --mdc-fab-small-hover-container-elevation-shadow:0px 5px 5px -3px rgba(0, 0, 0, 0.2),
    0px 8px 10px 1px rgba(0, 0, 0, 0.14),
    0px 3px 14px 2px rgba(0, 0, 0, 0.12);
  --mdc-fab-small-pressed-container-elevation-shadow:0px 7px 8px -4px rgba(0, 0, 0, 0.2),
    0px 12px 17px 2px rgba(0, 0, 0, 0.14),
    0px 5px 22px 4px rgba(0, 0, 0, 0.12);
  --mdc-fab-small-container-shadow-color:#000;
  --mat-fab-small-foreground-color:black;
  --mat-fab-small-state-layer-color:black;
  --mat-fab-small-disabled-state-layer-color:black;
  --mat-fab-small-ripple-color:rgba(0, 0, 0, 0.1);
  --mat-fab-small-hover-state-layer-opacity:0.04;
  --mat-fab-small-focus-state-layer-opacity:0.12;
  --mat-fab-small-pressed-state-layer-opacity:0.12;
  --mat-fab-small-disabled-state-container-color:rgba(0, 0, 0, 0.12);
  --mat-fab-small-disabled-state-foreground-color:rgba(0, 0, 0, 0.38);
  --mdc-extended-fab-container-elevation-shadow:0px 3px 5px -1px rgba(0, 0, 0, 0.2),
    0px 6px 10px 0px rgba(0, 0, 0, 0.14),
    0px 1px 18px 0px rgba(0, 0, 0, 0.12);
  --mdc-extended-fab-focus-container-elevation-shadow:0px 5px 5px -3px rgba(0, 0, 0, 0.2),
    0px 8px 10px 1px rgba(0, 0, 0, 0.14),
    0px 3px 14px 2px rgba(0, 0, 0, 0.12);
  --mdc-extended-fab-hover-container-elevation-shadow:0px 5px 5px -3px rgba(0, 0, 0, 0.2),
    0px 8px 10px 1px rgba(0, 0, 0, 0.14),
    0px 3px 14px 2px rgba(0, 0, 0, 0.12);
  --mdc-extended-fab-pressed-container-elevation-shadow:0px 7px 8px -4px rgba(0, 0, 0, 0.2),
    0px 12px 17px 2px rgba(0, 0, 0, 0.14),
    0px 5px 22px 4px rgba(0, 0, 0, 0.12);
  --mdc-extended-fab-container-shadow-color:#000;
}
html .mat-mdc-fab.mat-primary {
  --mdc-fab-container-color:#3f51b5;
  --mat-fab-foreground-color:white;
  --mat-fab-state-layer-color:white;
  --mat-fab-ripple-color:rgba(255, 255, 255, 0.1);
}
html .mat-mdc-fab.mat-accent {
  --mdc-fab-container-color:#ff4081;
  --mat-fab-foreground-color:white;
  --mat-fab-state-layer-color:white;
  --mat-fab-ripple-color:rgba(255, 255, 255, 0.1);
}
html .mat-mdc-fab.mat-warn {
  --mdc-fab-container-color:#f44336;
  --mat-fab-foreground-color:white;
  --mat-fab-state-layer-color:white;
  --mat-fab-ripple-color:rgba(255, 255, 255, 0.1);
}
html .mat-mdc-mini-fab.mat-primary {
  --mdc-fab-small-container-color:#3f51b5;
  --mat-fab-small-foreground-color:white;
  --mat-fab-small-state-layer-color:white;
  --mat-fab-small-ripple-color:rgba(255, 255, 255, 0.1);
}
html .mat-mdc-mini-fab.mat-accent {
  --mdc-fab-small-container-color:#ff4081;
  --mat-fab-small-foreground-color:white;
  --mat-fab-small-state-layer-color:white;
  --mat-fab-small-ripple-color:rgba(255, 255, 255, 0.1);
}
html .mat-mdc-mini-fab.mat-warn {
  --mdc-fab-small-container-color:#f44336;
  --mat-fab-small-foreground-color:white;
  --mat-fab-small-state-layer-color:white;
  --mat-fab-small-ripple-color:rgba(255, 255, 255, 0.1);
}
html {
  --mat-fab-touch-target-display:block;
  --mat-fab-small-touch-target-display:block;
}
html {
  --mdc-extended-fab-label-text-font:Roboto, sans-serif;
  --mdc-extended-fab-label-text-size:14px;
  --mdc-extended-fab-label-text-tracking:0.0892857143em;
  --mdc-extended-fab-label-text-weight:500;
}
html {
  --mdc-snackbar-container-shape:4px;
}
html {
  --mdc-snackbar-container-color:#333333;
  --mdc-snackbar-supporting-text-color:rgba(255, 255, 255, 0.87);
  --mat-snack-bar-button-color:#ff4081;
}
html {
  --mdc-snackbar-supporting-text-font:Roboto, sans-serif;
  --mdc-snackbar-supporting-text-line-height:20px;
  --mdc-snackbar-supporting-text-size:14px;
  --mdc-snackbar-supporting-text-weight:400;
}
html {
  --mat-table-row-item-outline-width:1px;
}
html {
  --mat-table-background-color:white;
  --mat-table-header-headline-color:rgba(0, 0, 0, 0.87);
  --mat-table-row-item-label-text-color:rgba(0, 0, 0, 0.87);
  --mat-table-row-item-outline-color:rgba(0, 0, 0, 0.12);
}
html {
  --mat-table-header-container-height:56px;
  --mat-table-footer-container-height:52px;
  --mat-table-row-item-container-height:52px;
}
html {
  --mat-table-header-headline-font:Roboto, sans-serif;
  --mat-table-header-headline-line-height:22px;
  --mat-table-header-headline-size:14px;
  --mat-table-header-headline-weight:500;
  --mat-table-header-headline-tracking:0.0071428571em;
  --mat-table-row-item-label-text-font:Roboto, sans-serif;
  --mat-table-row-item-label-text-line-height:20px;
  --mat-table-row-item-label-text-size:14px;
  --mat-table-row-item-label-text-weight:400;
  --mat-table-row-item-label-text-tracking:0.0178571429em;
  --mat-table-footer-supporting-text-font:Roboto, sans-serif;
  --mat-table-footer-supporting-text-line-height:20px;
  --mat-table-footer-supporting-text-size:14px;
  --mat-table-footer-supporting-text-weight:400;
  --mat-table-footer-supporting-text-tracking:0.0178571429em;
}
html {
  --mdc-circular-progress-active-indicator-width:4px;
  --mdc-circular-progress-size:48px;
}
html {
  --mdc-circular-progress-active-indicator-color:#3f51b5;
}
html .mat-accent {
  --mdc-circular-progress-active-indicator-color:#ff4081;
}
html .mat-warn {
  --mdc-circular-progress-active-indicator-color:#f44336;
}
html {
  --mat-badge-container-shape:50%;
  --mat-badge-container-size:unset;
  --mat-badge-small-size-container-size:unset;
  --mat-badge-large-size-container-size:unset;
  --mat-badge-legacy-container-size:22px;
  --mat-badge-legacy-small-size-container-size:16px;
  --mat-badge-legacy-large-size-container-size:28px;
  --mat-badge-container-offset:-11px 0;
  --mat-badge-small-size-container-offset:-8px 0;
  --mat-badge-large-size-container-offset:-14px 0;
  --mat-badge-container-overlap-offset:-11px;
  --mat-badge-small-size-container-overlap-offset:-8px;
  --mat-badge-large-size-container-overlap-offset:-14px;
  --mat-badge-container-padding:0;
  --mat-badge-small-size-container-padding:0;
  --mat-badge-large-size-container-padding:0;
}
html {
  --mat-badge-background-color:#3f51b5;
  --mat-badge-text-color:white;
  --mat-badge-disabled-state-background-color:#b9b9b9;
  --mat-badge-disabled-state-text-color:rgba(0, 0, 0, 0.38);
}
.mat-badge-accent {
  --mat-badge-background-color:#ff4081;
  --mat-badge-text-color:white;
}
.mat-badge-warn {
  --mat-badge-background-color:#f44336;
  --mat-badge-text-color:white;
}
html {
  --mat-badge-text-font:Roboto, sans-serif;
  --mat-badge-text-size:12px;
  --mat-badge-text-weight:600;
  --mat-badge-small-size-text-size:9px;
  --mat-badge-large-size-text-size:24px;
}
html {
  --mat-bottom-sheet-container-shape:4px;
}
html {
  --mat-bottom-sheet-container-text-color:rgba(0, 0, 0, 0.87);
  --mat-bottom-sheet-container-background-color:white;
}
html {
  --mat-bottom-sheet-container-text-font:Roboto, sans-serif;
  --mat-bottom-sheet-container-text-line-height:20px;
  --mat-bottom-sheet-container-text-size:14px;
  --mat-bottom-sheet-container-text-tracking:0.0178571429em;
  --mat-bottom-sheet-container-text-weight:400;
}
html {
  --mat-legacy-button-toggle-height:36px;
  --mat-legacy-button-toggle-shape:2px;
  --mat-legacy-button-toggle-focus-state-layer-opacity:1;
  --mat-standard-button-toggle-shape:4px;
  --mat-standard-button-toggle-hover-state-layer-opacity:0.04;
  --mat-standard-button-toggle-focus-state-layer-opacity:0.12;
}
html {
  --mat-legacy-button-toggle-text-color:rgba(0, 0, 0, 0.38);
  --mat-legacy-button-toggle-state-layer-color:rgba(0, 0, 0, 0.12);
  --mat-legacy-button-toggle-selected-state-text-color:rgba(0, 0, 0, 0.54);
  --mat-legacy-button-toggle-selected-state-background-color:#e0e0e0;
  --mat-legacy-button-toggle-disabled-state-text-color:rgba(0, 0, 0, 0.26);
  --mat-legacy-button-toggle-disabled-state-background-color:#eeeeee;
  --mat-legacy-button-toggle-disabled-selected-state-background-color:#bdbdbd;
  --mat-standard-button-toggle-text-color:rgba(0, 0, 0, 0.87);
  --mat-standard-button-toggle-background-color:white;
  --mat-standard-button-toggle-state-layer-color:black;
  --mat-standard-button-toggle-selected-state-background-color:#e0e0e0;
  --mat-standard-button-toggle-selected-state-text-color:rgba(0, 0, 0, 0.87);
  --mat-standard-button-toggle-disabled-state-text-color:rgba(0, 0, 0, 0.26);
  --mat-standard-button-toggle-disabled-state-background-color:white;
  --mat-standard-button-toggle-disabled-selected-state-text-color:rgba(0, 0, 0, 0.87);
  --mat-standard-button-toggle-disabled-selected-state-background-color:#bdbdbd;
  --mat-standard-button-toggle-divider-color:#e0e0e0;
}
html {
  --mat-standard-button-toggle-height:48px;
}
html {
  --mat-legacy-button-toggle-label-text-font:Roboto, sans-serif;
  --mat-legacy-button-toggle-label-text-line-height:24px;
  --mat-legacy-button-toggle-label-text-size:16px;
  --mat-legacy-button-toggle-label-text-tracking:0.03125em;
  --mat-legacy-button-toggle-label-text-weight:400;
  --mat-standard-button-toggle-label-text-font:Roboto, sans-serif;
  --mat-standard-button-toggle-label-text-line-height:24px;
  --mat-standard-button-toggle-label-text-size:16px;
  --mat-standard-button-toggle-label-text-tracking:0.03125em;
  --mat-standard-button-toggle-label-text-weight:400;
}
html {
  --mat-datepicker-calendar-container-shape:4px;
  --mat-datepicker-calendar-container-touch-shape:4px;
  --mat-datepicker-calendar-container-elevation-shadow:0px 2px 4px -1px rgba(0, 0, 0, 0.2),
    0px 4px 5px 0px rgba(0, 0, 0, 0.14),
    0px 1px 10px 0px rgba(0, 0, 0, 0.12);
  --mat-datepicker-calendar-container-touch-elevation-shadow:0px 11px 15px -7px rgba(0, 0, 0, 0.2),
    0px 24px 38px 3px rgba(0, 0, 0, 0.14),
    0px 9px 46px 8px rgba(0, 0, 0, 0.12);
}
html {
  --mat-datepicker-calendar-date-selected-state-text-color:white;
  --mat-datepicker-calendar-date-selected-state-background-color:#3f51b5;
  --mat-datepicker-calendar-date-selected-disabled-state-background-color:rgba(63, 81, 181, 0.4);
  --mat-datepicker-calendar-date-today-selected-state-outline-color:white;
  --mat-datepicker-calendar-date-focus-state-background-color:rgba(63, 81, 181, 0.3);
  --mat-datepicker-calendar-date-hover-state-background-color:rgba(63, 81, 181, 0.3);
  --mat-datepicker-toggle-active-state-icon-color:#3f51b5;
  --mat-datepicker-calendar-date-in-range-state-background-color:rgba(63, 81, 181, 0.2);
  --mat-datepicker-calendar-date-in-comparison-range-state-background-color:rgba(249, 171, 0, 0.2);
  --mat-datepicker-calendar-date-in-overlap-range-state-background-color:#a8dab5;
  --mat-datepicker-calendar-date-in-overlap-range-selected-state-background-color:#46a35e;
  --mat-datepicker-toggle-icon-color:rgba(0, 0, 0, 0.54);
  --mat-datepicker-calendar-body-label-text-color:rgba(0, 0, 0, 0.54);
  --mat-datepicker-calendar-period-button-text-color:black;
  --mat-datepicker-calendar-period-button-icon-color:rgba(0, 0, 0, 0.54);
  --mat-datepicker-calendar-navigation-button-icon-color:rgba(0, 0, 0, 0.54);
  --mat-datepicker-calendar-header-divider-color:rgba(0, 0, 0, 0.12);
  --mat-datepicker-calendar-header-text-color:rgba(0, 0, 0, 0.54);
  --mat-datepicker-calendar-date-today-outline-color:rgba(0, 0, 0, 0.38);
  --mat-datepicker-calendar-date-today-disabled-state-outline-color:rgba(0, 0, 0, 0.18);
  --mat-datepicker-calendar-date-text-color:rgba(0, 0, 0, 0.87);
  --mat-datepicker-calendar-date-outline-color:transparent;
  --mat-datepicker-calendar-date-disabled-state-text-color:rgba(0, 0, 0, 0.38);
  --mat-datepicker-calendar-date-preview-state-outline-color:rgba(0, 0, 0, 0.24);
  --mat-datepicker-range-input-separator-color:rgba(0, 0, 0, 0.87);
  --mat-datepicker-range-input-disabled-state-separator-color:rgba(0, 0, 0, 0.38);
  --mat-datepicker-range-input-disabled-state-text-color:rgba(0, 0, 0, 0.38);
  --mat-datepicker-calendar-container-background-color:white;
  --mat-datepicker-calendar-container-text-color:rgba(0, 0, 0, 0.87);
}
.mat-datepicker-content.mat-accent {
  --mat-datepicker-calendar-date-selected-state-text-color:white;
  --mat-datepicker-calendar-date-selected-state-background-color:#ff4081;
  --mat-datepicker-calendar-date-selected-disabled-state-background-color:rgba(255, 64, 129, 0.4);
  --mat-datepicker-calendar-date-today-selected-state-outline-color:white;
  --mat-datepicker-calendar-date-focus-state-background-color:rgba(255, 64, 129, 0.3);
  --mat-datepicker-calendar-date-hover-state-background-color:rgba(255, 64, 129, 0.3);
  --mat-datepicker-calendar-date-in-range-state-background-color:rgba(255, 64, 129, 0.2);
  --mat-datepicker-calendar-date-in-comparison-range-state-background-color:rgba(249, 171, 0, 0.2);
  --mat-datepicker-calendar-date-in-overlap-range-state-background-color:#a8dab5;
  --mat-datepicker-calendar-date-in-overlap-range-selected-state-background-color:#46a35e;
}
.mat-datepicker-content.mat-warn {
  --mat-datepicker-calendar-date-selected-state-text-color:white;
  --mat-datepicker-calendar-date-selected-state-background-color:#f44336;
  --mat-datepicker-calendar-date-selected-disabled-state-background-color:rgba(244, 67, 54, 0.4);
  --mat-datepicker-calendar-date-today-selected-state-outline-color:white;
  --mat-datepicker-calendar-date-focus-state-background-color:rgba(244, 67, 54, 0.3);
  --mat-datepicker-calendar-date-hover-state-background-color:rgba(244, 67, 54, 0.3);
  --mat-datepicker-calendar-date-in-range-state-background-color:rgba(244, 67, 54, 0.2);
  --mat-datepicker-calendar-date-in-comparison-range-state-background-color:rgba(249, 171, 0, 0.2);
  --mat-datepicker-calendar-date-in-overlap-range-state-background-color:#a8dab5;
  --mat-datepicker-calendar-date-in-overlap-range-selected-state-background-color:#46a35e;
}
.mat-datepicker-toggle-active.mat-accent {
  --mat-datepicker-toggle-active-state-icon-color:#ff4081;
}
.mat-datepicker-toggle-active.mat-warn {
  --mat-datepicker-toggle-active-state-icon-color:#f44336;
}
.mat-calendar-controls {
  --mat-icon-button-touch-target-display:none;
}
.mat-calendar-controls .mat-mdc-icon-button.mat-mdc-button-base {
  --mdc-icon-button-state-layer-size:40px;
  width: var(--mdc-icon-button-state-layer-size);
  height: var(--mdc-icon-button-state-layer-size);
  padding: 8px;
}
html {
  --mat-datepicker-calendar-text-font:Roboto, sans-serif;
  --mat-datepicker-calendar-text-size:13px;
  --mat-datepicker-calendar-body-label-text-size:14px;
  --mat-datepicker-calendar-body-label-text-weight:500;
  --mat-datepicker-calendar-period-button-text-size:14px;
  --mat-datepicker-calendar-period-button-text-weight:500;
  --mat-datepicker-calendar-header-text-size:11px;
  --mat-datepicker-calendar-header-text-weight:400;
}
html {
  --mat-divider-width:1px;
}
html {
  --mat-divider-color:rgba(0, 0, 0, 0.12);
}
html {
  --mat-expansion-container-shape:4px;
  --mat-expansion-legacy-header-indicator-display:inline-block;
  --mat-expansion-header-indicator-display:none;
}
html {
  --mat-expansion-container-background-color:white;
  --mat-expansion-container-text-color:rgba(0, 0, 0, 0.87);
  --mat-expansion-actions-divider-color:rgba(0, 0, 0, 0.12);
  --mat-expansion-header-hover-state-layer-color:rgba(0, 0, 0, 0.04);
  --mat-expansion-header-focus-state-layer-color:rgba(0, 0, 0, 0.04);
  --mat-expansion-header-disabled-state-text-color:rgba(0, 0, 0, 0.26);
  --mat-expansion-header-text-color:rgba(0, 0, 0, 0.87);
  --mat-expansion-header-description-color:rgba(0, 0, 0, 0.54);
  --mat-expansion-header-indicator-color:rgba(0, 0, 0, 0.54);
}
html {
  --mat-expansion-header-collapsed-state-height:48px;
  --mat-expansion-header-expanded-state-height:64px;
}
html {
  --mat-expansion-header-text-font:Roboto, sans-serif;
  --mat-expansion-header-text-size:14px;
  --mat-expansion-header-text-weight:500;
  --mat-expansion-header-text-line-height:inherit;
  --mat-expansion-header-text-tracking:inherit;
  --mat-expansion-container-text-font:Roboto, sans-serif;
  --mat-expansion-container-text-line-height:20px;
  --mat-expansion-container-text-size:14px;
  --mat-expansion-container-text-tracking:0.0178571429em;
  --mat-expansion-container-text-weight:400;
}
html {
  --mat-grid-list-tile-header-primary-text-size:14px;
  --mat-grid-list-tile-header-secondary-text-size:12px;
  --mat-grid-list-tile-footer-primary-text-size:14px;
  --mat-grid-list-tile-footer-secondary-text-size:12px;
}
html {
  --mat-icon-color:inherit;
}
.mat-icon.mat-primary {
  --mat-icon-color:#3f51b5;
}
.mat-icon.mat-accent {
  --mat-icon-color:#ff4081;
}
.mat-icon.mat-warn {
  --mat-icon-color:#f44336;
}
html {
  --mat-sidenav-container-shape:0;
  --mat-sidenav-container-elevation-shadow:0px 8px 10px -5px rgba(0, 0, 0, 0.2),
    0px 16px 24px 2px rgba(0, 0, 0, 0.14),
    0px 6px 30px 5px rgba(0, 0, 0, 0.12);
  --mat-sidenav-container-width:auto;
}
html {
  --mat-sidenav-container-divider-color:rgba(0, 0, 0, 0.12);
  --mat-sidenav-container-background-color:white;
  --mat-sidenav-container-text-color:rgba(0, 0, 0, 0.87);
  --mat-sidenav-content-background-color:#fafafa;
  --mat-sidenav-content-text-color:rgba(0, 0, 0, 0.87);
  --mat-sidenav-scrim-color:rgba(0, 0, 0, 0.6);
}
html {
  --mat-stepper-header-icon-foreground-color:white;
  --mat-stepper-header-selected-state-icon-background-color:#3f51b5;
  --mat-stepper-header-selected-state-icon-foreground-color:white;
  --mat-stepper-header-done-state-icon-background-color:#3f51b5;
  --mat-stepper-header-done-state-icon-foreground-color:white;
  --mat-stepper-header-edit-state-icon-background-color:#3f51b5;
  --mat-stepper-header-edit-state-icon-foreground-color:white;
  --mat-stepper-container-color:white;
  --mat-stepper-line-color:rgba(0, 0, 0, 0.12);
  --mat-stepper-header-hover-state-layer-color:rgba(0, 0, 0, 0.04);
  --mat-stepper-header-focus-state-layer-color:rgba(0, 0, 0, 0.04);
  --mat-stepper-header-label-text-color:rgba(0, 0, 0, 0.54);
  --mat-stepper-header-optional-label-text-color:rgba(0, 0, 0, 0.54);
  --mat-stepper-header-selected-state-label-text-color:rgba(0, 0, 0, 0.87);
  --mat-stepper-header-error-state-label-text-color:#f44336;
  --mat-stepper-header-icon-background-color:rgba(0, 0, 0, 0.54);
  --mat-stepper-header-error-state-icon-foreground-color:#f44336;
  --mat-stepper-header-error-state-icon-background-color:transparent;
}
html .mat-step-header.mat-accent {
  --mat-stepper-header-icon-foreground-color:white;
  --mat-stepper-header-selected-state-icon-background-color:#ff4081;
  --mat-stepper-header-selected-state-icon-foreground-color:white;
  --mat-stepper-header-done-state-icon-background-color:#ff4081;
  --mat-stepper-header-done-state-icon-foreground-color:white;
  --mat-stepper-header-edit-state-icon-background-color:#ff4081;
  --mat-stepper-header-edit-state-icon-foreground-color:white;
}
html .mat-step-header.mat-warn {
  --mat-stepper-header-icon-foreground-color:white;
  --mat-stepper-header-selected-state-icon-background-color:#f44336;
  --mat-stepper-header-selected-state-icon-foreground-color:white;
  --mat-stepper-header-done-state-icon-background-color:#f44336;
  --mat-stepper-header-done-state-icon-foreground-color:white;
  --mat-stepper-header-edit-state-icon-background-color:#f44336;
  --mat-stepper-header-edit-state-icon-foreground-color:white;
}
html {
  --mat-stepper-header-height:72px;
}
html {
  --mat-stepper-container-text-font:Roboto, sans-serif;
  --mat-stepper-header-label-text-font:Roboto, sans-serif;
  --mat-stepper-header-label-text-size:14px;
  --mat-stepper-header-label-text-weight:400;
  --mat-stepper-header-error-state-label-text-size:16px;
  --mat-stepper-header-selected-state-label-text-size:16px;
  --mat-stepper-header-selected-state-label-text-weight:400;
}
html {
  --mat-sort-arrow-color:#757575;
}
html {
  --mat-toolbar-container-background-color:whitesmoke;
  --mat-toolbar-container-text-color:rgba(0, 0, 0, 0.87);
}
.mat-toolbar.mat-primary {
  --mat-toolbar-container-background-color:#3f51b5;
  --mat-toolbar-container-text-color:white;
}
.mat-toolbar.mat-accent {
  --mat-toolbar-container-background-color:#ff4081;
  --mat-toolbar-container-text-color:white;
}
.mat-toolbar.mat-warn {
  --mat-toolbar-container-background-color:#f44336;
  --mat-toolbar-container-text-color:white;
}
html {
  --mat-toolbar-standard-height:64px;
  --mat-toolbar-mobile-height:56px;
}
html {
  --mat-toolbar-title-text-font:Roboto, sans-serif;
  --mat-toolbar-title-text-line-height:32px;
  --mat-toolbar-title-text-size:20px;
  --mat-toolbar-title-text-tracking:0.0125em;
  --mat-toolbar-title-text-weight:500;
}
html {
  --mat-tree-container-background-color:white;
  --mat-tree-node-text-color:rgba(0, 0, 0, 0.87);
}
html {
  --mat-tree-node-min-height:48px;
}
html {
  --mat-tree-node-text-font:Roboto, sans-serif;
  --mat-tree-node-text-size:14px;
  --mat-tree-node-text-weight:400;
}
.mat-h1,
.mat-headline-5,
.mat-typography .mat-h1,
.mat-typography .mat-headline-5,
.mat-typography h1 {
  font: 400 24px/32px Roboto, sans-serif;
  letter-spacing: normal;
  margin: 0 0 16px;
}
.mat-h2,
.mat-headline-6,
.mat-typography .mat-h2,
.mat-typography .mat-headline-6,
.mat-typography h2 {
  font: 500 20px/32px Roboto, sans-serif;
  letter-spacing: .0125em;
  margin: 0 0 16px;
}
.mat-h3,
.mat-subtitle-1,
.mat-typography .mat-h3,
.mat-typography .mat-subtitle-1,
.mat-typography h3 {
  font: 400 16px/28px Roboto, sans-serif;
  letter-spacing: .009375em;
  margin: 0 0 16px;
}
.mat-h4,
.mat-body-1,
.mat-typography .mat-h4,
.mat-typography .mat-body-1,
.mat-typography h4 {
  font: 400 16px/24px Roboto, sans-serif;
  letter-spacing: .03125em;
  margin: 0 0 16px;
}
.mat-h5,
.mat-typography .mat-h5,
.mat-typography h5 {
  font: 400 calc(14px*.83)/20px Roboto, sans-serif;
  margin: 0 0 12px;
}
.mat-h6,
.mat-typography .mat-h6,
.mat-typography h6 {
  font: 400 calc(14px*.67)/20px Roboto, sans-serif;
  margin: 0 0 12px;
}
.mat-body-strong,
.mat-subtitle-2,
.mat-typography .mat-body-strong,
.mat-typography .mat-subtitle-2 {
  font: 500 14px/22px Roboto, sans-serif;
  letter-spacing: .0071428571em;
}
.mat-body,
.mat-body-2,
.mat-typography .mat-body,
.mat-typography .mat-body-2,
.mat-typography {
  font: 400 14px/20px Roboto, sans-serif;
  letter-spacing: .0178571429em;
}
.mat-body p,
.mat-body-2 p,
.mat-typography .mat-body p,
.mat-typography .mat-body-2 p,
.mat-typography p {
  margin: 0 0 12px;
}
.mat-small,
.mat-caption,
.mat-typography .mat-small,
.mat-typography .mat-caption {
  font: 400 12px/20px Roboto, sans-serif;
  letter-spacing: .0333333333em;
}
.mat-headline-1,
.mat-typography .mat-headline-1 {
  font: 300 96px/96px Roboto, sans-serif;
  letter-spacing: -0.015625em;
  margin: 0 0 56px;
}
.mat-headline-2,
.mat-typography .mat-headline-2 {
  font: 300 60px/60px Roboto, sans-serif;
  letter-spacing: -.0083333333em;
  margin: 0 0 64px;
}
.mat-headline-3,
.mat-typography .mat-headline-3 {
  font: 400 48px/50px Roboto, sans-serif;
  letter-spacing: normal;
  margin: 0 0 64px;
}
.mat-headline-4,
.mat-typography .mat-headline-4 {
  font: 400 34px/40px Roboto, sans-serif;
  letter-spacing: .0073529412em;
  margin: 0 0 64px;
}

/* projects/smart-curation-viewer/src/styles.scss */
.eimmo-input-obt {
  height: 34px;
  border-radius: 4px;
  border: solid 1px #e7e7e7;
  background-color: #ffffff;
  font-size: 14px;
  font-weight: normal;
  font-style: normal;
  letter-spacing: normal;
  color: #000;
  padding: 0 8px;
  box-sizing: border-box;
}
.eimmo-input-obt:focus {
  outline: none;
}
.eimmo-input-obt::placeholder {
  color: #c4c4c4;
}
.ko,
.en,
.ja {
  --mat-badge-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-badge-text-size: 12px;
  --mat-badge-text-weight: 600;
  --mat-badge-small-size-text-size: 9px;
  --mat-badge-large-size-text-size: 24px;
  --mat-bottom-sheet-container-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-bottom-sheet-container-text-line-height: 20px;
  --mat-bottom-sheet-container-text-size: 14px;
  --mat-bottom-sheet-container-text-tracking: 0.0178571429em;
  --mat-bottom-sheet-container-text-weight: 400;
  --mat-legacy-button-toggle-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-legacy-button-toggle-label-text-line-height: 24px;
  --mat-legacy-button-toggle-label-text-size: 16px;
  --mat-legacy-button-toggle-label-text-tracking: 0.03125em;
  --mat-legacy-button-toggle-label-text-weight: 400;
  --mat-standard-button-toggle-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-standard-button-toggle-label-text-line-height: 24px;
  --mat-standard-button-toggle-label-text-size: 16px;
  --mat-standard-button-toggle-label-text-tracking: 0.03125em;
  --mat-standard-button-toggle-label-text-weight: 400;
  --mat-datepicker-calendar-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-datepicker-calendar-text-size: 13px;
  --mat-datepicker-calendar-body-label-text-size: 14px;
  --mat-datepicker-calendar-body-label-text-weight: 500;
  --mat-datepicker-calendar-period-button-text-size: 14px;
  --mat-datepicker-calendar-period-button-text-weight: 500;
  --mat-datepicker-calendar-header-text-size: 11px;
  --mat-datepicker-calendar-header-text-weight: 400;
  --mat-expansion-header-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-expansion-header-text-size: 14px;
  --mat-expansion-header-text-weight: 500;
  --mat-expansion-header-text-line-height: inherit;
  --mat-expansion-header-text-tracking: inherit;
  --mat-expansion-container-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-expansion-container-text-line-height: 20px;
  --mat-expansion-container-text-size: 14px;
  --mat-expansion-container-text-tracking: 0.0178571429em;
  --mat-expansion-container-text-weight: 400;
  --mat-grid-list-tile-header-primary-text-size: 14px;
  --mat-grid-list-tile-header-secondary-text-size: 12px;
  --mat-grid-list-tile-footer-primary-text-size: 14px;
  --mat-grid-list-tile-footer-secondary-text-size: 12px;
  --mat-stepper-container-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-stepper-header-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-stepper-header-label-text-size: 14px;
  --mat-stepper-header-label-text-weight: 400;
  --mat-stepper-header-error-state-label-text-size: 16px;
  --mat-stepper-header-selected-state-label-text-size: 16px;
  --mat-stepper-header-selected-state-label-text-weight: 400;
  --mat-toolbar-title-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-toolbar-title-text-line-height: 32px;
  --mat-toolbar-title-text-size: 20px;
  --mat-toolbar-title-text-tracking: 0.0125em;
  --mat-toolbar-title-text-weight: 500;
  --mat-tree-node-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-tree-node-text-size: 14px;
  --mat-tree-node-text-weight: 400;
  --mat-option-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-option-label-text-line-height: 24px;
  --mat-option-label-text-size: 16px;
  --mat-option-label-text-tracking: 0.03125em;
  --mat-option-label-text-weight: 400;
  --mat-optgroup-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-optgroup-label-text-line-height: 24px;
  --mat-optgroup-label-text-size: 16px;
  --mat-optgroup-label-text-tracking: 0.03125em;
  --mat-optgroup-label-text-weight: 400;
  --mat-card-title-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-card-title-text-line-height: 32px;
  --mat-card-title-text-size: 20px;
  --mat-card-title-text-tracking: 0.0125em;
  --mat-card-title-text-weight: 500;
  --mat-card-subtitle-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-card-subtitle-text-line-height: 22px;
  --mat-card-subtitle-text-size: 14px;
  --mat-card-subtitle-text-tracking: 0.0071428571em;
  --mat-card-subtitle-text-weight: 500;
  --mdc-plain-tooltip-supporting-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-plain-tooltip-supporting-text-size: 12px;
  --mdc-plain-tooltip-supporting-text-weight: 400;
  --mdc-plain-tooltip-supporting-text-tracking: 0.0333333333em;
  --mdc-filled-text-field-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-filled-text-field-label-text-size: 16px;
  --mdc-filled-text-field-label-text-tracking: 0.03125em;
  --mdc-filled-text-field-label-text-weight: 400;
  --mdc-outlined-text-field-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-outlined-text-field-label-text-size: 16px;
  --mdc-outlined-text-field-label-text-tracking: 0.03125em;
  --mdc-outlined-text-field-label-text-weight: 400;
  --mat-form-field-container-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-form-field-container-text-line-height: 24px;
  --mat-form-field-container-text-size: 16px;
  --mat-form-field-container-text-tracking: 0.03125em;
  --mat-form-field-container-text-weight: 400;
  --mat-form-field-outlined-label-text-populated-size: 16px;
  --mat-form-field-subscript-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-form-field-subscript-text-line-height: 20px;
  --mat-form-field-subscript-text-size: 12px;
  --mat-form-field-subscript-text-tracking: 0.0333333333em;
  --mat-form-field-subscript-text-weight: 400;
  --mat-select-trigger-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-select-trigger-text-line-height: 24px;
  --mat-select-trigger-text-size: 16px;
  --mat-select-trigger-text-tracking: 0.03125em;
  --mat-select-trigger-text-weight: 400;
  --mdc-dialog-subhead-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-dialog-subhead-line-height: 32px;
  --mdc-dialog-subhead-size: 20px;
  --mdc-dialog-subhead-weight: 500;
  --mdc-dialog-subhead-tracking: 0.0125em;
  --mdc-dialog-supporting-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-dialog-supporting-text-line-height: 24px;
  --mdc-dialog-supporting-text-size: 16px;
  --mdc-dialog-supporting-text-weight: 400;
  --mdc-dialog-supporting-text-tracking: 0.03125em;
  --mdc-slider-label-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-slider-label-label-text-size: 14px;
  --mdc-slider-label-label-text-line-height: 22px;
  --mdc-slider-label-label-text-tracking: 0.0071428571em;
  --mdc-slider-label-label-text-weight: 500;
  --mat-menu-item-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-menu-item-label-text-size: 16px;
  --mat-menu-item-label-text-tracking: 0.03125em;
  --mat-menu-item-label-text-line-height: 24px;
  --mat-menu-item-label-text-weight: 400;
  --mdc-list-list-item-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-list-list-item-label-text-line-height: 24px;
  --mdc-list-list-item-label-text-size: 16px;
  --mdc-list-list-item-label-text-tracking: 0.03125em;
  --mdc-list-list-item-label-text-weight: 400;
  --mdc-list-list-item-supporting-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-list-list-item-supporting-text-line-height: 20px;
  --mdc-list-list-item-supporting-text-size: 14px;
  --mdc-list-list-item-supporting-text-tracking: 0.0178571429em;
  --mdc-list-list-item-supporting-text-weight: 400;
  --mdc-list-list-item-trailing-supporting-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-list-list-item-trailing-supporting-text-line-height: 20px;
  --mdc-list-list-item-trailing-supporting-text-size: 12px;
  --mdc-list-list-item-trailing-supporting-text-tracking: 0.0333333333em;
  --mdc-list-list-item-trailing-supporting-text-weight: 400;
  --mat-paginator-container-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-paginator-container-text-line-height: 20px;
  --mat-paginator-container-text-size: 12px;
  --mat-paginator-container-text-tracking: 0.0333333333em;
  --mat-paginator-container-text-weight: 400;
  --mat-paginator-select-trigger-text-size: 12px;
  --mdc-text-button-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-text-button-label-text-size: 14px;
  --mdc-text-button-label-text-tracking: 0.0892857143em;
  --mdc-text-button-label-text-weight: 500;
  --mdc-text-button-label-text-transform: none;
  --mdc-filled-button-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-filled-button-label-text-size: 14px;
  --mdc-filled-button-label-text-tracking: 0.0892857143em;
  --mdc-filled-button-label-text-weight: 500;
  --mdc-filled-button-label-text-transform: none;
  --mdc-outlined-button-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-outlined-button-label-text-size: 14px;
  --mdc-outlined-button-label-text-tracking: 0.0892857143em;
  --mdc-outlined-button-label-text-weight: 500;
  --mdc-outlined-button-label-text-transform: none;
  --mdc-protected-button-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-protected-button-label-text-size: 14px;
  --mdc-protected-button-label-text-tracking: 0.0892857143em;
  --mdc-protected-button-label-text-weight: 500;
  --mdc-protected-button-label-text-transform: none;
  --mdc-extended-fab-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-extended-fab-label-text-size: 14px;
  --mdc-extended-fab-label-text-tracking: 0.0892857143em;
  --mdc-extended-fab-label-text-weight: 500;
  --mdc-snackbar-supporting-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-snackbar-supporting-text-line-height: 20px;
  --mdc-snackbar-supporting-text-size: 14px;
  --mdc-snackbar-supporting-text-weight: 400;
  --mat-table-header-headline-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-table-header-headline-line-height: 22px;
  --mat-table-header-headline-size: 14px;
  --mat-table-header-headline-weight: 500;
  --mat-table-header-headline-tracking: 0.0071428571em;
  --mat-table-row-item-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-table-row-item-label-text-line-height: 20px;
  --mat-table-row-item-label-text-size: 14px;
  --mat-table-row-item-label-text-weight: 400;
  --mat-table-row-item-label-text-tracking: 0.0178571429em;
  --mat-table-footer-supporting-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-table-footer-supporting-text-line-height: 20px;
  --mat-table-footer-supporting-text-size: 14px;
  --mat-table-footer-supporting-text-weight: 400;
  --mat-table-footer-supporting-text-tracking: 0.0178571429em;
}
.ko .mat-h1,
.ko .mat-headline-5,
.ko .mat-typography .mat-h1,
.ko .mat-typography .mat-headline-5,
.ko .mat-typography h1,
.en .mat-h1,
.en .mat-headline-5,
.en .mat-typography .mat-h1,
.en .mat-typography .mat-headline-5,
.en .mat-typography h1,
.ja .mat-h1,
.ja .mat-headline-5,
.ja .mat-typography .mat-h1,
.ja .mat-typography .mat-headline-5,
.ja .mat-typography h1 {
  font:
    400 24px / 32px "Pretendard",
    "sans-serif",
    "Roboto";
  letter-spacing: normal;
  margin: 0 0 16px;
}
.ko .mat-h2,
.ko .mat-headline-6,
.ko .mat-typography .mat-h2,
.ko .mat-typography .mat-headline-6,
.ko .mat-typography h2,
.en .mat-h2,
.en .mat-headline-6,
.en .mat-typography .mat-h2,
.en .mat-typography .mat-headline-6,
.en .mat-typography h2,
.ja .mat-h2,
.ja .mat-headline-6,
.ja .mat-typography .mat-h2,
.ja .mat-typography .mat-headline-6,
.ja .mat-typography h2 {
  font:
    500 20px / 32px "Pretendard",
    "sans-serif",
    "Roboto";
  letter-spacing: 0.0125em;
  margin: 0 0 16px;
}
.ko .mat-h3,
.ko .mat-subtitle-1,
.ko .mat-typography .mat-h3,
.ko .mat-typography .mat-subtitle-1,
.ko .mat-typography h3,
.en .mat-h3,
.en .mat-subtitle-1,
.en .mat-typography .mat-h3,
.en .mat-typography .mat-subtitle-1,
.en .mat-typography h3,
.ja .mat-h3,
.ja .mat-subtitle-1,
.ja .mat-typography .mat-h3,
.ja .mat-typography .mat-subtitle-1,
.ja .mat-typography h3 {
  font:
    400 16px / 28px "Pretendard",
    "sans-serif",
    "Roboto";
  letter-spacing: 0.009375em;
  margin: 0 0 16px;
}
.ko .mat-h4,
.ko .mat-body-1,
.ko .mat-typography .mat-h4,
.ko .mat-typography .mat-body-1,
.ko .mat-typography h4,
.en .mat-h4,
.en .mat-body-1,
.en .mat-typography .mat-h4,
.en .mat-typography .mat-body-1,
.en .mat-typography h4,
.ja .mat-h4,
.ja .mat-body-1,
.ja .mat-typography .mat-h4,
.ja .mat-typography .mat-body-1,
.ja .mat-typography h4 {
  font:
    400 16px / 24px "Pretendard",
    "sans-serif",
    "Roboto";
  letter-spacing: 0.03125em;
  margin: 0 0 16px;
}
.ko .mat-h5,
.ko .mat-typography .mat-h5,
.ko .mat-typography h5,
.en .mat-h5,
.en .mat-typography .mat-h5,
.en .mat-typography h5,
.ja .mat-h5,
.ja .mat-typography .mat-h5,
.ja .mat-typography h5 {
  font:
    400 calc(14px * 0.83) / 20px "Pretendard",
    "sans-serif",
    "Roboto";
  margin: 0 0 12px;
}
.ko .mat-h6,
.ko .mat-typography .mat-h6,
.ko .mat-typography h6,
.en .mat-h6,
.en .mat-typography .mat-h6,
.en .mat-typography h6,
.ja .mat-h6,
.ja .mat-typography .mat-h6,
.ja .mat-typography h6 {
  font:
    400 calc(14px * 0.67) / 20px "Pretendard",
    "sans-serif",
    "Roboto";
  margin: 0 0 12px;
}
.ko .mat-body-strong,
.ko .mat-subtitle-2,
.ko .mat-typography .mat-body-strong,
.ko .mat-typography .mat-subtitle-2,
.en .mat-body-strong,
.en .mat-subtitle-2,
.en .mat-typography .mat-body-strong,
.en .mat-typography .mat-subtitle-2,
.ja .mat-body-strong,
.ja .mat-subtitle-2,
.ja .mat-typography .mat-body-strong,
.ja .mat-typography .mat-subtitle-2 {
  font:
    500 14px / 22px "Pretendard",
    "sans-serif",
    "Roboto";
  letter-spacing: 0.0071428571em;
}
.ko .mat-body,
.ko .mat-body-2,
.ko .mat-typography .mat-body,
.ko .mat-typography .mat-body-2,
.ko .mat-typography,
.en .mat-body,
.en .mat-body-2,
.en .mat-typography .mat-body,
.en .mat-typography .mat-body-2,
.en .mat-typography,
.ja .mat-body,
.ja .mat-body-2,
.ja .mat-typography .mat-body,
.ja .mat-typography .mat-body-2,
.ja .mat-typography {
  font:
    400 14px / 20px "Pretendard",
    "sans-serif",
    "Roboto";
  letter-spacing: 0.0178571429em;
}
.ko .mat-body p,
.ko .mat-body-2 p,
.ko .mat-typography .mat-body p,
.ko .mat-typography .mat-body-2 p,
.ko .mat-typography p,
.en .mat-body p,
.en .mat-body-2 p,
.en .mat-typography .mat-body p,
.en .mat-typography .mat-body-2 p,
.en .mat-typography p,
.ja .mat-body p,
.ja .mat-body-2 p,
.ja .mat-typography .mat-body p,
.ja .mat-typography .mat-body-2 p,
.ja .mat-typography p {
  margin: 0 0 12px;
}
.ko .mat-small,
.ko .mat-caption,
.ko .mat-typography .mat-small,
.ko .mat-typography .mat-caption,
.en .mat-small,
.en .mat-caption,
.en .mat-typography .mat-small,
.en .mat-typography .mat-caption,
.ja .mat-small,
.ja .mat-caption,
.ja .mat-typography .mat-small,
.ja .mat-typography .mat-caption {
  font:
    400 12px / 20px "Pretendard",
    "sans-serif",
    "Roboto";
  letter-spacing: 0.0333333333em;
}
.ko .mat-headline-1,
.ko .mat-typography .mat-headline-1,
.en .mat-headline-1,
.en .mat-typography .mat-headline-1,
.ja .mat-headline-1,
.ja .mat-typography .mat-headline-1 {
  font:
    300 96px / 96px "Pretendard",
    "sans-serif",
    "Roboto";
  letter-spacing: -0.015625em;
  margin: 0 0 56px;
}
.ko .mat-headline-2,
.ko .mat-typography .mat-headline-2,
.en .mat-headline-2,
.en .mat-typography .mat-headline-2,
.ja .mat-headline-2,
.ja .mat-typography .mat-headline-2 {
  font:
    300 60px / 60px "Pretendard",
    "sans-serif",
    "Roboto";
  letter-spacing: -0.0083333333em;
  margin: 0 0 64px;
}
.ko .mat-headline-3,
.ko .mat-typography .mat-headline-3,
.en .mat-headline-3,
.en .mat-typography .mat-headline-3,
.ja .mat-headline-3,
.ja .mat-typography .mat-headline-3 {
  font:
    400 48px / 50px "Pretendard",
    "sans-serif",
    "Roboto";
  letter-spacing: normal;
  margin: 0 0 64px;
}
.ko .mat-headline-4,
.ko .mat-typography .mat-headline-4,
.en .mat-headline-4,
.en .mat-typography .mat-headline-4,
.ja .mat-headline-4,
.ja .mat-typography .mat-headline-4 {
  font:
    400 34px / 40px "Pretendard",
    "sans-serif",
    "Roboto";
  letter-spacing: 0.0073529412em;
  margin: 0 0 64px;
}
.ko .mat-mdc-standard-chip,
.en .mat-mdc-standard-chip,
.ja .mat-mdc-standard-chip {
  --mdc-chip-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-chip-label-text-line-height: 20px;
  --mdc-chip-label-text-size: 14px;
  --mdc-chip-label-text-tracking: 0.0178571429em;
  --mdc-chip-label-text-weight: 400;
}
.ko .mat-mdc-slide-toggle,
.en .mat-mdc-slide-toggle,
.ja .mat-mdc-slide-toggle {
  --mdc-form-field-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-form-field-label-text-line-height: 20px;
  --mdc-form-field-label-text-size: 14px;
  --mdc-form-field-label-text-tracking: 0.0178571429em;
  --mdc-form-field-label-text-weight: 400;
}
.ko .mat-mdc-radio-button,
.en .mat-mdc-radio-button,
.ja .mat-mdc-radio-button {
  --mdc-form-field-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-form-field-label-text-line-height: 20px;
  --mdc-form-field-label-text-size: 14px;
  --mdc-form-field-label-text-tracking: 0.0178571429em;
  --mdc-form-field-label-text-weight: 400;
}
.ko .mdc-list-group__subheader,
.en .mdc-list-group__subheader,
.ja .mdc-list-group__subheader {
  font:
    400 16px / 28px "Pretendard",
    "sans-serif",
    "Roboto";
  letter-spacing: 0.009375em;
}
.ko .mat-mdc-tab-header,
.en .mat-mdc-tab-header,
.ja .mat-mdc-tab-header {
  --mat-tab-header-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mat-tab-header-label-text-size: 14px;
  --mat-tab-header-label-text-tracking: 0.0892857143em;
  --mat-tab-header-label-text-line-height: 36px;
  --mat-tab-header-label-text-weight: 500;
}
.ko .mat-mdc-checkbox,
.en .mat-mdc-checkbox,
.ja .mat-mdc-checkbox {
  --mdc-form-field-label-text-font:
    Pretendard,
    sans-serif,
    Roboto;
  --mdc-form-field-label-text-line-height: 20px;
  --mdc-form-field-label-text-size: 14px;
  --mdc-form-field-label-text-tracking: 0.0178571429em;
  --mdc-form-field-label-text-weight: 400;
}
.vi {
  --mat-badge-text-font: Times New Roman, Roboto;
  --mat-badge-text-size: 12px;
  --mat-badge-text-weight: 600;
  --mat-badge-small-size-text-size: 9px;
  --mat-badge-large-size-text-size: 24px;
  --mat-bottom-sheet-container-text-font: Times New Roman, Roboto;
  --mat-bottom-sheet-container-text-line-height: 20px;
  --mat-bottom-sheet-container-text-size: 14px;
  --mat-bottom-sheet-container-text-tracking: 0.0178571429em;
  --mat-bottom-sheet-container-text-weight: 400;
  --mat-legacy-button-toggle-label-text-font: Times New Roman, Roboto;
  --mat-legacy-button-toggle-label-text-line-height: 24px;
  --mat-legacy-button-toggle-label-text-size: 16px;
  --mat-legacy-button-toggle-label-text-tracking: 0.03125em;
  --mat-legacy-button-toggle-label-text-weight: 400;
  --mat-standard-button-toggle-label-text-font: Times New Roman, Roboto;
  --mat-standard-button-toggle-label-text-line-height: 24px;
  --mat-standard-button-toggle-label-text-size: 16px;
  --mat-standard-button-toggle-label-text-tracking: 0.03125em;
  --mat-standard-button-toggle-label-text-weight: 400;
  --mat-datepicker-calendar-text-font: Times New Roman, Roboto;
  --mat-datepicker-calendar-text-size: 13px;
  --mat-datepicker-calendar-body-label-text-size: 14px;
  --mat-datepicker-calendar-body-label-text-weight: 500;
  --mat-datepicker-calendar-period-button-text-size: 14px;
  --mat-datepicker-calendar-period-button-text-weight: 500;
  --mat-datepicker-calendar-header-text-size: 11px;
  --mat-datepicker-calendar-header-text-weight: 400;
  --mat-expansion-header-text-font: Times New Roman, Roboto;
  --mat-expansion-header-text-size: 14px;
  --mat-expansion-header-text-weight: 500;
  --mat-expansion-header-text-line-height: inherit;
  --mat-expansion-header-text-tracking: inherit;
  --mat-expansion-container-text-font: Times New Roman, Roboto;
  --mat-expansion-container-text-line-height: 20px;
  --mat-expansion-container-text-size: 14px;
  --mat-expansion-container-text-tracking: 0.0178571429em;
  --mat-expansion-container-text-weight: 400;
  --mat-grid-list-tile-header-primary-text-size: 14px;
  --mat-grid-list-tile-header-secondary-text-size: 12px;
  --mat-grid-list-tile-footer-primary-text-size: 14px;
  --mat-grid-list-tile-footer-secondary-text-size: 12px;
  --mat-stepper-container-text-font: Times New Roman, Roboto;
  --mat-stepper-header-label-text-font: Times New Roman, Roboto;
  --mat-stepper-header-label-text-size: 14px;
  --mat-stepper-header-label-text-weight: 400;
  --mat-stepper-header-error-state-label-text-size: 16px;
  --mat-stepper-header-selected-state-label-text-size: 16px;
  --mat-stepper-header-selected-state-label-text-weight: 400;
  --mat-toolbar-title-text-font: Times New Roman, Roboto;
  --mat-toolbar-title-text-line-height: 32px;
  --mat-toolbar-title-text-size: 20px;
  --mat-toolbar-title-text-tracking: 0.0125em;
  --mat-toolbar-title-text-weight: 500;
  --mat-tree-node-text-font: Times New Roman, Roboto;
  --mat-tree-node-text-size: 14px;
  --mat-tree-node-text-weight: 400;
  --mat-option-label-text-font: Times New Roman, Roboto;
  --mat-option-label-text-line-height: 24px;
  --mat-option-label-text-size: 16px;
  --mat-option-label-text-tracking: 0.03125em;
  --mat-option-label-text-weight: 400;
  --mat-optgroup-label-text-font: Times New Roman, Roboto;
  --mat-optgroup-label-text-line-height: 24px;
  --mat-optgroup-label-text-size: 16px;
  --mat-optgroup-label-text-tracking: 0.03125em;
  --mat-optgroup-label-text-weight: 400;
  --mat-card-title-text-font: Times New Roman, Roboto;
  --mat-card-title-text-line-height: 32px;
  --mat-card-title-text-size: 20px;
  --mat-card-title-text-tracking: 0.0125em;
  --mat-card-title-text-weight: 500;
  --mat-card-subtitle-text-font: Times New Roman, Roboto;
  --mat-card-subtitle-text-line-height: 22px;
  --mat-card-subtitle-text-size: 14px;
  --mat-card-subtitle-text-tracking: 0.0071428571em;
  --mat-card-subtitle-text-weight: 500;
  --mdc-plain-tooltip-supporting-text-font: Times New Roman, Roboto;
  --mdc-plain-tooltip-supporting-text-size: 12px;
  --mdc-plain-tooltip-supporting-text-weight: 400;
  --mdc-plain-tooltip-supporting-text-tracking: 0.0333333333em;
  --mdc-filled-text-field-label-text-font: Times New Roman, Roboto;
  --mdc-filled-text-field-label-text-size: 16px;
  --mdc-filled-text-field-label-text-tracking: 0.03125em;
  --mdc-filled-text-field-label-text-weight: 400;
  --mdc-outlined-text-field-label-text-font: Times New Roman, Roboto;
  --mdc-outlined-text-field-label-text-size: 16px;
  --mdc-outlined-text-field-label-text-tracking: 0.03125em;
  --mdc-outlined-text-field-label-text-weight: 400;
  --mat-form-field-container-text-font: Times New Roman, Roboto;
  --mat-form-field-container-text-line-height: 24px;
  --mat-form-field-container-text-size: 16px;
  --mat-form-field-container-text-tracking: 0.03125em;
  --mat-form-field-container-text-weight: 400;
  --mat-form-field-outlined-label-text-populated-size: 16px;
  --mat-form-field-subscript-text-font: Times New Roman, Roboto;
  --mat-form-field-subscript-text-line-height: 20px;
  --mat-form-field-subscript-text-size: 12px;
  --mat-form-field-subscript-text-tracking: 0.0333333333em;
  --mat-form-field-subscript-text-weight: 400;
  --mat-select-trigger-text-font: Times New Roman, Roboto;
  --mat-select-trigger-text-line-height: 24px;
  --mat-select-trigger-text-size: 16px;
  --mat-select-trigger-text-tracking: 0.03125em;
  --mat-select-trigger-text-weight: 400;
  --mdc-dialog-subhead-font: Times New Roman, Roboto;
  --mdc-dialog-subhead-line-height: 32px;
  --mdc-dialog-subhead-size: 20px;
  --mdc-dialog-subhead-weight: 500;
  --mdc-dialog-subhead-tracking: 0.0125em;
  --mdc-dialog-supporting-text-font: Times New Roman, Roboto;
  --mdc-dialog-supporting-text-line-height: 24px;
  --mdc-dialog-supporting-text-size: 16px;
  --mdc-dialog-supporting-text-weight: 400;
  --mdc-dialog-supporting-text-tracking: 0.03125em;
  --mdc-slider-label-label-text-font: Times New Roman, Roboto;
  --mdc-slider-label-label-text-size: 14px;
  --mdc-slider-label-label-text-line-height: 22px;
  --mdc-slider-label-label-text-tracking: 0.0071428571em;
  --mdc-slider-label-label-text-weight: 500;
  --mat-menu-item-label-text-font: Times New Roman, Roboto;
  --mat-menu-item-label-text-size: 16px;
  --mat-menu-item-label-text-tracking: 0.03125em;
  --mat-menu-item-label-text-line-height: 24px;
  --mat-menu-item-label-text-weight: 400;
  --mdc-list-list-item-label-text-font: Times New Roman, Roboto;
  --mdc-list-list-item-label-text-line-height: 24px;
  --mdc-list-list-item-label-text-size: 16px;
  --mdc-list-list-item-label-text-tracking: 0.03125em;
  --mdc-list-list-item-label-text-weight: 400;
  --mdc-list-list-item-supporting-text-font: Times New Roman, Roboto;
  --mdc-list-list-item-supporting-text-line-height: 20px;
  --mdc-list-list-item-supporting-text-size: 14px;
  --mdc-list-list-item-supporting-text-tracking: 0.0178571429em;
  --mdc-list-list-item-supporting-text-weight: 400;
  --mdc-list-list-item-trailing-supporting-text-font: Times New Roman, Roboto;
  --mdc-list-list-item-trailing-supporting-text-line-height: 20px;
  --mdc-list-list-item-trailing-supporting-text-size: 12px;
  --mdc-list-list-item-trailing-supporting-text-tracking: 0.0333333333em;
  --mdc-list-list-item-trailing-supporting-text-weight: 400;
  --mat-paginator-container-text-font: Times New Roman, Roboto;
  --mat-paginator-container-text-line-height: 20px;
  --mat-paginator-container-text-size: 12px;
  --mat-paginator-container-text-tracking: 0.0333333333em;
  --mat-paginator-container-text-weight: 400;
  --mat-paginator-select-trigger-text-size: 12px;
  --mdc-text-button-label-text-font: Times New Roman, Roboto;
  --mdc-text-button-label-text-size: 14px;
  --mdc-text-button-label-text-tracking: 0.0892857143em;
  --mdc-text-button-label-text-weight: 500;
  --mdc-text-button-label-text-transform: none;
  --mdc-filled-button-label-text-font: Times New Roman, Roboto;
  --mdc-filled-button-label-text-size: 14px;
  --mdc-filled-button-label-text-tracking: 0.0892857143em;
  --mdc-filled-button-label-text-weight: 500;
  --mdc-filled-button-label-text-transform: none;
  --mdc-outlined-button-label-text-font: Times New Roman, Roboto;
  --mdc-outlined-button-label-text-size: 14px;
  --mdc-outlined-button-label-text-tracking: 0.0892857143em;
  --mdc-outlined-button-label-text-weight: 500;
  --mdc-outlined-button-label-text-transform: none;
  --mdc-protected-button-label-text-font: Times New Roman, Roboto;
  --mdc-protected-button-label-text-size: 14px;
  --mdc-protected-button-label-text-tracking: 0.0892857143em;
  --mdc-protected-button-label-text-weight: 500;
  --mdc-protected-button-label-text-transform: none;
  --mdc-extended-fab-label-text-font: Times New Roman, Roboto;
  --mdc-extended-fab-label-text-size: 14px;
  --mdc-extended-fab-label-text-tracking: 0.0892857143em;
  --mdc-extended-fab-label-text-weight: 500;
  --mdc-snackbar-supporting-text-font: Times New Roman, Roboto;
  --mdc-snackbar-supporting-text-line-height: 20px;
  --mdc-snackbar-supporting-text-size: 14px;
  --mdc-snackbar-supporting-text-weight: 400;
  --mat-table-header-headline-font: Times New Roman, Roboto;
  --mat-table-header-headline-line-height: 22px;
  --mat-table-header-headline-size: 14px;
  --mat-table-header-headline-weight: 500;
  --mat-table-header-headline-tracking: 0.0071428571em;
  --mat-table-row-item-label-text-font: Times New Roman, Roboto;
  --mat-table-row-item-label-text-line-height: 20px;
  --mat-table-row-item-label-text-size: 14px;
  --mat-table-row-item-label-text-weight: 400;
  --mat-table-row-item-label-text-tracking: 0.0178571429em;
  --mat-table-footer-supporting-text-font: Times New Roman, Roboto;
  --mat-table-footer-supporting-text-line-height: 20px;
  --mat-table-footer-supporting-text-size: 14px;
  --mat-table-footer-supporting-text-weight: 400;
  --mat-table-footer-supporting-text-tracking: 0.0178571429em;
}
.vi .mat-h1,
.vi .mat-headline-5,
.vi .mat-typography .mat-h1,
.vi .mat-typography .mat-headline-5,
.vi .mat-typography h1 {
  font: 400 24px / 32px "Times New Roman", "Roboto";
  letter-spacing: normal;
  margin: 0 0 16px;
}
.vi .mat-h2,
.vi .mat-headline-6,
.vi .mat-typography .mat-h2,
.vi .mat-typography .mat-headline-6,
.vi .mat-typography h2 {
  font: 500 20px / 32px "Times New Roman", "Roboto";
  letter-spacing: 0.0125em;
  margin: 0 0 16px;
}
.vi .mat-h3,
.vi .mat-subtitle-1,
.vi .mat-typography .mat-h3,
.vi .mat-typography .mat-subtitle-1,
.vi .mat-typography h3 {
  font: 400 16px / 28px "Times New Roman", "Roboto";
  letter-spacing: 0.009375em;
  margin: 0 0 16px;
}
.vi .mat-h4,
.vi .mat-body-1,
.vi .mat-typography .mat-h4,
.vi .mat-typography .mat-body-1,
.vi .mat-typography h4 {
  font: 400 16px / 24px "Times New Roman", "Roboto";
  letter-spacing: 0.03125em;
  margin: 0 0 16px;
}
.vi .mat-h5,
.vi .mat-typography .mat-h5,
.vi .mat-typography h5 {
  font: 400 calc(14px * 0.83) / 20px "Times New Roman", "Roboto";
  margin: 0 0 12px;
}
.vi .mat-h6,
.vi .mat-typography .mat-h6,
.vi .mat-typography h6 {
  font: 400 calc(14px * 0.67) / 20px "Times New Roman", "Roboto";
  margin: 0 0 12px;
}
.vi .mat-body-strong,
.vi .mat-subtitle-2,
.vi .mat-typography .mat-body-strong,
.vi .mat-typography .mat-subtitle-2 {
  font: 500 14px / 22px "Times New Roman", "Roboto";
  letter-spacing: 0.0071428571em;
}
.vi .mat-body,
.vi .mat-body-2,
.vi .mat-typography .mat-body,
.vi .mat-typography .mat-body-2,
.vi .mat-typography {
  font: 400 14px / 20px "Times New Roman", "Roboto";
  letter-spacing: 0.0178571429em;
}
.vi .mat-body p,
.vi .mat-body-2 p,
.vi .mat-typography .mat-body p,
.vi .mat-typography .mat-body-2 p,
.vi .mat-typography p {
  margin: 0 0 12px;
}
.vi .mat-small,
.vi .mat-caption,
.vi .mat-typography .mat-small,
.vi .mat-typography .mat-caption {
  font: 400 12px / 20px "Times New Roman", "Roboto";
  letter-spacing: 0.0333333333em;
}
.vi .mat-headline-1,
.vi .mat-typography .mat-headline-1 {
  font: 300 96px / 96px "Times New Roman", "Roboto";
  letter-spacing: -0.015625em;
  margin: 0 0 56px;
}
.vi .mat-headline-2,
.vi .mat-typography .mat-headline-2 {
  font: 300 60px / 60px "Times New Roman", "Roboto";
  letter-spacing: -0.0083333333em;
  margin: 0 0 64px;
}
.vi .mat-headline-3,
.vi .mat-typography .mat-headline-3 {
  font: 400 48px / 50px "Times New Roman", "Roboto";
  letter-spacing: normal;
  margin: 0 0 64px;
}
.vi .mat-headline-4,
.vi .mat-typography .mat-headline-4 {
  font: 400 34px / 40px "Times New Roman", "Roboto";
  letter-spacing: 0.0073529412em;
  margin: 0 0 64px;
}
.vi .mat-mdc-standard-chip {
  --mdc-chip-label-text-font: Times New Roman, Roboto;
  --mdc-chip-label-text-line-height: 20px;
  --mdc-chip-label-text-size: 14px;
  --mdc-chip-label-text-tracking: 0.0178571429em;
  --mdc-chip-label-text-weight: 400;
}
.vi .mat-mdc-slide-toggle {
  --mdc-form-field-label-text-font: Times New Roman, Roboto;
  --mdc-form-field-label-text-line-height: 20px;
  --mdc-form-field-label-text-size: 14px;
  --mdc-form-field-label-text-tracking: 0.0178571429em;
  --mdc-form-field-label-text-weight: 400;
}
.vi .mat-mdc-radio-button {
  --mdc-form-field-label-text-font: Times New Roman, Roboto;
  --mdc-form-field-label-text-line-height: 20px;
  --mdc-form-field-label-text-size: 14px;
  --mdc-form-field-label-text-tracking: 0.0178571429em;
  --mdc-form-field-label-text-weight: 400;
}
.vi .mdc-list-group__subheader {
  font: 400 16px / 28px "Times New Roman", "Roboto";
  letter-spacing: 0.009375em;
}
.vi .mat-mdc-tab-header {
  --mat-tab-header-label-text-font: Times New Roman, Roboto;
  --mat-tab-header-label-text-size: 14px;
  --mat-tab-header-label-text-tracking: 0.0892857143em;
  --mat-tab-header-label-text-line-height: 36px;
  --mat-tab-header-label-text-weight: 500;
}
.vi .mat-mdc-checkbox {
  --mdc-form-field-label-text-font: Times New Roman, Roboto;
  --mdc-form-field-label-text-line-height: 20px;
  --mdc-form-field-label-text-size: 14px;
  --mdc-form-field-label-text-tracking: 0.0178571429em;
  --mdc-form-field-label-text-weight: 400;
}
.eimmo-table {
  background-color: transparent;
}
.eimmo-table .mat-header-row {
  height: 52px;
  min-height: 52px;
  margin-bottom: 10px;
  padding: 0 10px;
  border-bottom: 1px solid #f5f5f5;
}
.eimmo-table .mat-header-row .mat-header-cell {
  font-size: 14px;
  font-weight: 700;
  font-stretch: normal;
  font-style: normal;
  line-height: normal;
  letter-spacing: normal;
  text-align: left;
  color: #9ea9bd;
}
.eimmo-table .mat-row {
  height: 70px;
  border-radius: 35px;
  border-bottom: none;
  margin: 10px;
  outline: none;
}
.eimmo-table .mat-row:hover {
  box-shadow: 0 0 10px 0 #d4d4d4;
  background-color: #ffffff;
  cursor: pointer;
}
.eimmo-table .mat-row .mat-cell {
  font-size: 16px;
  font-weight: 400;
  font-stretch: normal;
  font-style: normal;
  line-height: normal;
  letter-spacing: normal;
  text-align: left;
  color: #868686;
}
.eimmo-table .mat-footer-row {
  border-bottom: none;
  margin: 11px 0;
}
.eimmo-table .mat-footer-row .mat-footer-cell {
  font-size: 16px;
  font-weight: 400;
  font-stretch: normal;
  font-style: normal;
  line-height: normal;
  letter-spacing: normal;
  text-align: left;
  color: #868686;
}
.eimmo-table .mat-footer-row.hide {
  display: none;
}
.dynamic-size-dialog {
  transition: width 250ms ease, height 250ms ease;
}
.dynamic-size-dialog .mat-dialog-content {
  max-height: none;
}
.no-border-radius-dialog .mat-dialog-container {
  border-radius: 0;
}
.dialog-header {
  position: relative;
}
.dialog-header .close {
  color: #b5b5b5;
  position: absolute;
  font-size: 17px;
  cursor: pointer;
  right: -20px;
  -webkit-user-select: none;
  user-select: none;
}
.mimmo-dialog .mat-dialog-actions .positive,
.mimmo-dialog .mat-dialog-actions .negative,
.eimmo-dialog .mat-dialog-actions .positive,
.eimmo-dialog .mat-dialog-actions .negative {
  min-width: 101px;
  height: 29px;
  border-radius: 4px;
  border: solid 1px #e0e0e0;
  padding: 0 37px;
  font-size: 13px;
  font-weight: 500;
  font-stretch: normal;
  font-style: normal;
  line-height: normal;
  letter-spacing: normal;
  text-align: center;
}
.async-request-dialog .mat-dialog-actions .positive,
.async-request-dialog .mat-dialog-actions .negative {
  min-width: 80px;
  height: 34px;
  border-radius: 4px;
  padding: 0 20px;
  font-size: 14px;
  font-weight: 700;
  text-align: center;
  font-stretch: normal;
  font-style: normal;
  line-height: normal;
  letter-spacing: normal;
}
.gtaas-dialog {
  pointer-events: none !important;
}
.gtaas-dialog .mat-dialog-container {
  display: flex;
  background-color: transparent;
  box-shadow: none;
  padding: 0;
}
.gtaas-dialog .mat-dialog-title {
  margin: 0;
}
.gtaas-dialog .mat-dialog-content {
  margin: 0;
  padding: 0;
  max-height: none;
  overflow: hidden;
}
.gtaas-dialog .mat-dialog-actions {
  border-radius: 0 0 4px 4px;
  padding: 0;
  min-height: auto;
}
.gtaas-dialog .close {
  position: absolute;
  width: 25px;
  height: 25px;
  top: 2px;
  right: 2px;
}
.gtaas-dialog .close__icon {
  width: 12px;
  height: 12px;
  -webkit-mask-repeat: no-repeat;
  mask-repeat: no-repeat;
  -webkit-mask-image: url("./media/close.svg");
  mask-image: url("./media/close.svg");
  -webkit-mask-position: 50% 50%;
  mask-position: 50% 50%;
  background-color: #A5A5A5;
}
@supports (-ms-ime-align: auto) {
  .gtaas-dialog .close__icon {
    background: url("./media/close.svg") no-repeat 50% 50%;
  }
}
@media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
  .gtaas-dialog .close__icon {
    background: url("./media/close.svg") no-repeat 50% 50%;
  }
}
.gtaas-dialog .gtaas-dialog-header {
  display: flex;
  flex-direction: row;
  align-items: center;
  padding: 16px 18px;
  background: #F9FAFC;
  border-radius: 5px 5px 0 0;
  align-self: stretch;
}
.gtaas-dialog .gtaas-dialog-header span {
  position: static;
  font-style: normal;
  font-weight: bold;
  font-size: 14px;
  line-height: 17px;
  color: #515151;
}
.gtaas-dialog .gtaas-dialog-body {
  padding: 24px;
}
.gtaas-dialog .gtaas-dialog-body__row {
  display: flex;
  flex-direction: row;
  align-items: center;
}
.gtaas-dialog .gtaas-dialog-body__row.column {
  flex-direction: column;
  align-items: flex-start;
}
.gtaas-dialog .gtaas-dialog-body__row + .gtaas-dialog-body__row {
  margin-top: 16px;
}
.gtaas-dialog .gtaas-dialog-body__row .row-wrapper {
  display: flex;
  flex-direction: row;
}
.gtaas-dialog .gtaas-dialog-body .control-item {
  display: flex;
  flex-direction: column;
}
.gtaas-dialog .gtaas-dialog-body .control-item + .control-item {
  margin-left: 8px;
}
.gtaas-dialog .gtaas-dialog-body .control-item__title {
  font-style: normal;
  font-weight: normal;
  font-size: 16px;
  line-height: 19px;
  color: #515151;
}
.gtaas-dialog .gtaas-dialog-body .control-item__input {
  margin-top: 8px;
}
.gtaas-dialog .gtaas-dialog-body .control-radio-button {
  font-style: normal;
  font-weight: normal;
  font-size: 14px;
  line-height: 24px;
  color: #515151;
}
.gtaas-dialog .gtaas-dialog-body .control-desc {
  margin-top: 8px;
  font-style: normal;
  font-weight: normal;
  font-size: 12px;
  line-height: 15px;
  color: #888888;
}
.gtaas-dialog .gtaas-dialog-body .control-desc + .control-desc {
  margin-top: 4px;
}
.gtaas-dialog .gtaas-dialog-body .gtaas-error-message {
  font-style: normal;
  font-weight: normal;
  font-size: 12px;
  line-height: 14px;
  color: #ED2E2E;
}
.gtaas-dialog .gtaas-dialog-footer {
  padding: 0 24px 24px 24px;
  justify-content: flex-end;
}
.gtaas-dialog .gtaas-dialog-footer .action-buttons .button {
  width: 140px;
  height: 34px;
  background: #cccccc;
  border-radius: 4px;
  font-style: normal;
  font-weight: 500;
  font-size: 14px;
  line-height: 18px;
  text-align: center;
  color: #515151;
}
.gtaas-dialog .gtaas-dialog-footer .action-buttons .button.confirm {
  background: #6C69FF;
  color: #FFFFFF;
}
.eimmo-dialog {
  pointer-events: none !important;
}
.eimmo-dialog .mat-mdc-dialog-container {
  display: flex;
  background-color: transparent;
  box-shadow: none;
  padding: 0;
}
.eimmo-dialog .mat-mdc-dialog-container .mat-mdc-dialog-surface {
  background-color: transparent;
  box-shadow: none;
}
.eimmo-dialog .mat-dialog-title {
  margin: 0;
}
.eimmo-dialog .mat-dialog-title span {
  font-size: 18px;
  font-weight: 800;
  color: #5E328D;
  padding: 0 4px;
}
.eimmo-dialog .mat-dialog-content {
  margin: 0;
  padding: 0;
  max-height: none;
  overflow: hidden;
}
.eimmo-dialog .mat-dialog-actions {
  justify-content: flex-end;
  border-radius: 0 0 4px 4px;
  padding: 0;
  min-height: auto;
  margin: 20px 0 0;
}
.eimmo-dialog .mat-dialog-actions .negative {
  border: solid 1px #e0e0e0;
  background-color: #fbfbfc;
  color: #9ca6af;
}
.eimmo-dialog .mat-dialog-actions .positive {
  border: solid 1px #e0e0e0;
  background-color: #5E328D;
  color: #fff;
}
.eimmo-dialog .mat-dialog-actions .mat-button-base + .mat-button-base {
  margin-left: 5px;
}
.eimmo-dialog .close {
  position: absolute;
  width: 25px;
  height: 25px;
  top: 2px;
  right: 2px;
}
.eimmo-dialog .close__icon {
  width: 12px;
  height: 12px;
  -webkit-mask-repeat: no-repeat;
  mask-repeat: no-repeat;
  -webkit-mask-image: url("./media/close.svg");
  mask-image: url("./media/close.svg");
  -webkit-mask-position: 50% 50%;
  mask-position: 50% 50%;
  background-color: #000000;
}
@supports (-ms-ime-align: auto) {
  .eimmo-dialog .close__icon {
    background: url("./media/close.svg") no-repeat 50% 50%;
  }
}
@media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
  .eimmo-dialog .close__icon {
    background: url("./media/close.svg") no-repeat 50% 50%;
  }
}
.eimmo-dialog--file-progress .mat-dialog-container {
  padding: 0;
  border-top: 0;
}
.eimmo-dialog--file-progress .mat-dialog-title {
  background-color: #5E328D;
  color: #fff;
  font-size: 16px;
  line-height: 16px;
  padding: 13px 20px;
  margin: 0;
}
.eimmo-dialog--file-progress .mat-dialog-content {
  padding: 20px;
  margin: 0;
}
.eimmo-dialog--file-progress .mat-dialog-actions {
  margin: 0;
  min-height: 0;
  display: flex;
  justify-content: flex-end;
  padding: 10px 20px;
}
.point-density-example-dialog .mat-dialog-container {
  display: flex;
  box-sizing: border-box;
  flex-direction: column;
  pointer-events: auto;
  position: relative;
  background-color: #fff;
  border-radius: 10px;
  padding: 0;
  box-shadow: 0 0 8px rgba(0, 0, 0, 0.15);
}
.point-density-example-dialog .mat-dialog-container .mat-dialog-title {
  margin: 0;
  line-height: 14px;
}
.point-density-example-dialog .mat-dialog-container .mat-dialog-content {
  margin: 0;
  max-height: none;
}
.point-density-example-dialog .mat-dialog-container .mat-dialog-actions {
  display: flex;
  box-sizing: border-box;
  flex-direction: row;
  justify-content: flex-end;
  align-content: stretch;
  align-items: stretch;
  max-height: 100%;
  min-height: auto;
  margin: 0;
  padding: 0;
}
.async-request-dialog {
  pointer-events: none !important;
}
.async-request-dialog .mat-dialog-container {
  display: flex;
  background-color: #ffffff;
  padding: 0;
  border-top: 5px solid #5E328D;
}
.async-request-dialog .mat-dialog-title {
  margin: 0;
  font-size: 18px;
  font-weight: 700;
  line-height: 24px;
  color: #515151;
}
.async-request-dialog .mat-dialog-title:after {
  content: "";
  display: block;
  height: 100%;
  width: 100%;
}
.async-request-dialog .mat-dialog-content {
  margin: 0;
  padding: 0;
  max-height: none;
  font-size: 16px;
  overflow: hidden;
}
.async-request-dialog .mat-dialog-actions {
  justify-content: flex-end;
  margin: 0;
  min-height: auto;
}
.async-request-dialog .mat-dialog-actions .negative {
  border: 1px solid #888888;
  background-color: #ffffff;
  color: #515151;
}
.async-request-dialog .mat-dialog-actions .positive {
  background-color: #5e328c;
  color: #ffffff;
}
.async-request-dialog .mat-dialog-actions .mat-button-base + .mat-button-base {
  margin-left: 8px;
}
.async-request-dialog .mat-mdc-progress-bar-buffer {
  background-color: #E9ECEF;
}
.async-request-dialog .mat-mdc-progress-bar-fill::after {
  background-color: #5e328d;
}
.async-request-dialog .failed .mat-mdc-progress-bar-fill::after {
  background-color: #d06b6b;
}
.mimmo-dialog .mat-dialog-container {
  display: flex;
  border-radius: 10px;
  padding: 20px 30px 30px 30px !important;
  border-top: 8px solid #5e328c;
  box-shadow: none;
  position: relative;
}
.mimmo-dialog.inhouse .mat-dialog-container {
  border-top: 8px solid #3366ff;
}
.mimmo-dialog .mat-dialog-title {
  margin: 0;
}
.mimmo-dialog .mat-dialog-title span {
  font-style: normal;
  font-weight: 800;
  font-size: 18px;
  color: #5e328c;
  padding: 0 4px;
}
.mimmo-dialog .mat-dialog-title:after {
  content: "";
  display: block;
  height: 100%;
  width: 100%;
}
.mimmo-dialog .mat-dialog-content {
  margin: 0;
  padding: 0;
  max-height: 65vh;
  overflow: auto;
}
.mimmo-dialog .mat-dialog-actions {
  justify-content: flex-end;
  padding: 0;
  min-height: auto;
  margin: 20px 0 0;
}
.mimmo-dialog .mat-dialog-actions .negative {
  border: solid 1px #e0e0e0;
  background-color: #fbfbfc;
  color: #9ca6af;
}
.mimmo-dialog .mat-dialog-actions .positive {
  border: solid 1px #e0e0e0;
  background-color: #5e328c;
  color: #fff;
}
.mimmo-dialog .mat-dialog-actions .mat-button-base + .mat-button-base {
  margin-left: 5px;
}
.mimmo-dialog .close {
  position: absolute;
  width: 25px;
  height: 25px;
  top: 2px;
  right: 2px;
}
.mimmo-dialog .close .mat-button-wrapper {
  display: flex;
  justify-content: center;
}
.mimmo-dialog .close__icon {
  display: flex;
  width: 12px;
  height: 12px;
  color: #b5b5b5;
}
.mimmo-dialog--empty-container .mat-dialog-container {
  border-top: none;
  padding: 0;
  background-color: transparent;
}
.mimmo-dialog--no-padding .mat-dialog-container {
  padding: 0;
}
.mimmo-dialog--file-progress .mat-dialog-container {
  padding: 0;
  border-top: 0;
}
.mimmo-dialog--file-progress .mat-dialog-title {
  background-color: #5e328c;
  color: #fff;
  font-size: 16px;
  line-height: 16px;
  padding: 13px 20px;
  margin: 0;
}
.mimmo-dialog--file-progress .mat-dialog-content {
  padding: 20px;
  margin: 0;
}
.mimmo-dialog--file-progress .mat-dialog-actions {
  margin: 0;
  min-height: 0;
  display: flex;
  justify-content: flex-end;
  padding: 10px 20px;
}
.cdk-overlay-backdrop.cdk-overlay-backdrop-showing {
  opacity: 0.6;
  background-color: #cccccc;
}
.cdk-overlay-backdrop.cdk-overlay-backdrop-showing.design-system {
  pointer-events: auto;
  background: rgba(0, 0, 0, 0.5);
  opacity: 1;
  -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
  transition: opacity 400ms cubic-bezier(0.25, 0.8, 0.25, 1);
}
.cdk-overlay-backdrop.cdk-overlay-backdrop-showing.mat-overlay-transparent-backdrop,
.cdk-overlay-backdrop.cdk-overlay-backdrop-showing.transparent-backdrop {
  background-color: transparent;
  opacity: 0;
}
.cdk-overlay-backdrop.cdk-overlay-backdrop-showing.popover-backdrop {
  opacity: 0;
}
.eimmo-menu.mat-mdc-menu-panel {
  min-height: 0;
}
.eimmo-menu .mat-mdc-menu-content:not(:empty) {
  padding-top: 4px;
  padding-bottom: 4px;
}
.eimmo-menu .mat-mdc-menu-content:not(:empty) .mat-mdc-menu-item .mdc-list-item__primary-text {
  font-weight: normal;
  font-size: 12px;
  line-height: 29px;
  letter-spacing: 0.24px;
  color: #626262;
}
.eimmo-menu .mat-mdc-menu-item {
  padding: 0 21px;
  line-height: 29px;
  min-height: 0;
  height: 29px;
  font-weight: normal;
  font-size: 12px;
  letter-spacing: 0.24px;
  color: #626262;
}
.eimmo-menu .mat-mdc-menu-item[disabled] {
  color: #ccc;
}
.eimmo-menu .mat-mdc-menu-item .mat-icon {
  font-size: 15px;
  text-align: center;
  height: 15px;
  width: 15px;
  margin-right: 7px;
}
.eimmo-menu .mat-mdc-menu-item-submenu-trigger::after {
  color: #5d338a;
  right: 10px;
}
.mat-button,
.mat-flat-button,
.mat-icon-button,
.mat-stroked-button {
  font-size: 13px;
  font-weight: bold;
}
.mat-button[disabled],
.mat-flat-button[disabled],
.mat-icon-button[disabled],
.mat-stroked-button[disabled] {
  opacity: 0.5;
}
.mat-icon-button.eimmo-icon-button {
  display: flex;
  justify-content: center;
  align-items: center;
}
.mat-icon-button.eimmo-icon-button .mat-icon {
  display: flex;
}
.eimmo-input {
  font-size: 13px;
  border: solid 2px #ebebeb;
  background-color: #ffffff;
  padding: 7px 23px;
  border-radius: 15px;
  font-weight: normal;
}
.gtaas-input {
  min-width: 80px;
  background: #FFFFFF;
  border: 1px solid #E7E7E7;
  border-radius: 4px;
  outline: none;
  padding: 8px;
  font-size: 13px;
  font-weight: 400;
  font-stretch: normal;
  font-style: normal;
  line-height: normal;
  letter-spacing: normal;
  text-align: left;
  color: #898989;
  box-sizing: border-box;
}
.gtaas-input::placeholder {
  color: #C4C4C4;
}
.eimmo-tab {
  padding-top: 29px;
  padding-left: 77px;
  border-bottom: 1px solid #E7E7E7;
}
.eimmo-tab .mat-tab-link-container .mat-tab-link {
  height: 29px;
  min-width: 100px;
  padding: 0 17px;
  opacity: 1;
  font-weight: bold;
  font-size: 14px;
  line-height: 24px;
  color: #888888;
}
.eimmo-tab .mat-tab-link-container .mat-tab-link.mat-tab-label-active {
  color: #5E328D;
}
.eimmo-tab .mat-tab-link-container .mat-ink-bar {
  height: 3px;
  background-color: #5E328D;
}
.eimmo-button-toggle {
  border: 0;
}
.eimmo-button-toggle .mat-button-toggle {
  background: none;
}
.eimmo-button-toggle .mat-button-toggle + .mat-button-toggle {
  border: 0;
}
.eimmo-button-toggle .mat-button-toggle-appearance-standard .mat-button-toggle-label-content {
  line-height: 35px;
  padding: 0 8px;
}
.eimmo-button-toggle-bold {
  border: 0;
}
.eimmo-button-toggle-bold .mat-button-toggle {
  display: flex;
  background: none;
}
.eimmo-button-toggle-bold .mat-button-toggle + .mat-button-toggle {
  border: 0;
}
.eimmo-button-toggle-bold .mat-button-toggle-appearance-standard.mat-button-toggle-checked {
  font-weight: bold;
}
.eimmo-button-toggle-bold .mat-button-toggle-appearance-standard .mat-button-toggle-label-content {
  line-height: 1;
  padding: 0 8px;
  font-size: 14px;
  color: #515151;
}
.mat-button-toggle-group.eimmo-button-toggle-group {
  min-height: 30px;
  border: none;
  border-radius: 20px;
}
.mat-button-toggle-group.eimmo-button-toggle-group .mat-button-toggle {
  min-width: 150px;
  box-sizing: border-box;
  outline: none;
  color: #515151;
  background-color: #F9F9F9;
}
.mat-button-toggle-group.eimmo-button-toggle-group .mat-button-toggle.mat-button-toggle-checked {
  color: #FFFFFF;
  background-color: #5E328D;
}
.mat-button-toggle-group.eimmo-button-toggle-group .mat-button-toggle .mat-button-toggle-button {
  height: 30px;
}
.mat-button-toggle-group.eimmo-button-toggle-group .mat-button-toggle .mat-button-toggle-button .mat-button-toggle-label-content {
  padding: 0 18px;
  font-size: 14px;
  font-weight: normal;
  line-height: normal;
}
.mat-button-toggle-group.eimmo-button-toggle-group .mat-button-toggle + .mat-button-toggle {
  border-left: 1px solid #FFFFFF;
}
.mat-button-toggle-group.eimmo-sub-button-toggle-group {
  min-height: 30px;
  border: none;
  border-radius: 4px;
}
.mat-button-toggle-group.eimmo-sub-button-toggle-group .mat-button-toggle {
  min-width: 150px;
  box-sizing: border-box;
  outline: none;
  color: #515151;
  background-color: #F9F9F9;
}
.mat-button-toggle-group.eimmo-sub-button-toggle-group .mat-button-toggle.mat-button-toggle-checked {
  color: #FFFFFF;
  background-color: #515151;
}
.mat-button-toggle-group.eimmo-sub-button-toggle-group .mat-button-toggle .mat-button-toggle-button {
  height: 30px;
}
.mat-button-toggle-group.eimmo-sub-button-toggle-group .mat-button-toggle .mat-button-toggle-button .mat-button-toggle-label-content {
  padding: 0 18px;
  font-size: 14px;
  font-weight: normal;
  line-height: normal;
}
.mat-button-toggle-group.eimmo-sub-button-toggle-group .mat-button-toggle + .mat-button-toggle {
  border-left: 1px solid #FFFFFF;
}
.cdk-overlay-pane.mat-mdc-tooltip-panel .mdc-tooltip__surface {
  display: flex;
  box-sizing: border-box;
  flex-direction: column;
  justify-content: center;
  align-content: stretch;
  align-items: stretch;
  max-width: 100%;
  min-width: fit-content;
  border-radius: 4px;
  padding: 3px 5px;
  background-color: #e0e0e0;
  text-align: left;
  font-family:
    Pretendard,
    Silka,
    sans-serif;
  font-weight: 700;
  font-size: 10px;
  line-height: 12px;
  color: #262626;
}
.cdk-overlay-pane.mat-tooltip-panel .mat-tooltip {
  font-family:
    Pretendard,
    Silka,
    sans-serif;
  font-weight: 400;
  font-size: 10px;
  line-height: 12px;
  color: #dfdfdf;
  background-color: #333333;
  border-radius: 4px;
  padding: 4px 8px;
  word-break: break-all;
  white-space: pre-line;
}
.mat-tooltip.eimmo-tooltip {
  color: #fff;
  background-color: #5d338a;
}
.mat-tooltip.eimmo-tooltip2 {
  font-size: 11px;
  color: #FFFFFF;
  background-color: #333333;
  border-radius: 5px;
  padding: 8px 12px;
  word-break: break-all;
  white-space: pre-line;
  line-height: 16px;
}
.mat-tooltip.eimmo-tooltip3 {
  font-size: 11px;
  color: #FFFFFF;
  background: rgba(51, 51, 51, 0.8);
  border-radius: 5px;
  padding: 8px 12px;
  word-break: break-all;
  white-space: pre-line;
  line-height: 13px;
}
.mat-mdc-tooltip.full-text .mdc-tooltip__surface {
  min-width: 0;
  max-width: 400px;
  word-break: break-all;
}
.mat-tooltip.full-text {
  min-width: 0;
  max-width: 400px;
  word-break: break-all;
}
.arrow-tooltip-above {
  padding: 15px !important;
  font-size: 13px !important;
  background-color: rgba(62, 62, 62, 0.9);
  border-radius: 8px !important;
  position: relative;
  overflow: visible !important;
}
.arrow-tooltip-right {
  padding: 15px !important;
  font-size: 13px !important;
  background-color: rgba(62, 62, 62, 0.9);
  border-radius: 8px !important;
  position: relative;
  overflow: visible !important;
}
.arrow-tooltip-below {
  padding: 15px !important;
  font-size: 13px !important;
  background-color: rgba(62, 62, 62, 0.9);
  border-radius: 8px !important;
  position: relative;
  overflow: visible !important;
}
.arrow-tooltip-left {
  padding: 15px !important;
  font-size: 13px !important;
  background-color: rgba(62, 62, 62, 0.9);
  border-radius: 8px !important;
  position: relative;
  overflow: visible !important;
}
.arrow-tooltip-right:before {
  content: "";
  position: absolute;
  top: 50%;
  transform: translateY(-50%);
  left: -7px;
  border-style: solid;
  border-width: 7px 7px 7px 0;
  border-color: rgba(0, 0, 0, 0) rgba(62, 62, 62, 0.9) rgba(0, 0, 0, 0) rgba(0, 0, 0, 0);
}
.arrow-tooltip-left:before {
  content: "";
  position: absolute;
  top: 50%;
  transform: translateY(-50%);
  right: -7px;
  border-style: solid;
  border-width: 7px 0 7px 7px;
  border-color: rgba(0, 0, 0, 0) rgba(0, 0, 0, 0) rgba(0, 0, 0, 0) rgba(62, 62, 62, 0.9);
}
.arrow-tooltip-above:before {
  content: "";
  position: absolute;
  left: 50%;
  transform: translateX(-50%);
  bottom: -7px;
  border-style: solid;
  border-width: 7px 7px 0 7px;
  border-color: rgba(62, 62, 62, 0.9) rgba(0, 0, 0, 0) rgba(0, 0, 0, 0) rgba(0, 0, 0, 0);
}
.arrow-tooltip-below:before {
  content: "";
  position: absolute;
  left: 50%;
  transform: translateX(-50%);
  top: -7px;
  border-style: solid;
  border-width: 0 7px 7px 7px;
  border-color: rgba(0, 0, 0, 0) rgba(0, 0, 0, 0) rgba(62, 62, 62, 0.9) rgba(0, 0, 0, 0);
}
.mat-tooltip.itv-tooltip {
  white-space: pre-line;
  background-color: rgba(0, 0, 0, 0.5);
  font-size: 11px;
  text-align: center;
  color: #FFFFFF;
  padding: 6px 12px !important;
}
.mat-tooltip.itv-tooltip:before {
  border-color: rgba(0, 0, 0, 0) rgba(0, 0, 0, 0) rgba(0, 0, 0, 0.5) rgba(0, 0, 0, 0);
}
.mat-tooltip.width-unset {
  max-width: unset !important;
}
.eimmo-select {
  display: flex;
  height: 29px;
  border-radius: 4px;
  border: 1px solid #E7E7E7;
}
.eimmo-select .mat-select-trigger {
  display: flex;
  flex-direction: row;
  align-items: center;
  width: 100%;
  height: 100%;
  padding: 0 8px 0 22px;
}
.eimmo-select .mat-select-trigger .mat-select-value {
  flex: 1;
  display: flex;
  max-width: none;
  font-weight: normal;
  font-size: 14px;
}
.eimmo-select .mat-select-trigger .mat-select-value .mat-select-value-text {
  color: #515151;
}
.eimmo-select .mat-select-trigger .mat-select-value .mat-select-placeholder {
  color: #C4C4C4;
}
.eimmo-select .mat-select-trigger .mat-select-arrow-wrapper {
  flex-grow: 0;
  flex-shrink: 1;
  flex-basis: auto;
  display: flex;
  align-items: center;
}
.eimmo-select .mat-select-trigger .mat-select-arrow-wrapper .mat-select-arrow {
  width: 10px;
  height: 10px;
  border: none;
  margin-right: 0;
  background-image: url("./media/selectbox.svg");
}
.eimmo-select.mat-select-disabled {
  border-color: #EEEEEE;
}
.eimmo-select.mat-select-disabled .mat-select-trigger .mat-select-value .mat-select-value-text {
  color: #EAEAEA;
}
.eimmo-select.mat-select-disabled .mat-select-trigger .mat-select-value .mat-select-placeholder {
  color: #EAEAEA;
}
.eimmo-select2 {
  display: flex;
  height: 29px;
  border-radius: 5px;
  border: solid 1px #e4e4e4;
}
.eimmo-select2 .mat-select-trigger {
  display: flex;
  flex-direction: row;
  align-items: center;
  width: 100%;
  height: 100%;
  padding: 0 8px 0 14px;
}
.eimmo-select2 .mat-select-trigger .mat-select-value {
  flex: 1;
  display: flex;
  max-width: none;
  font-size: 12px;
  font-weight: 400;
  font-stretch: normal;
  font-style: normal;
  line-height: normal;
  letter-spacing: normal;
  text-align: left;
}
.eimmo-select2 .mat-select-trigger .mat-select-value .mat-select-value-text {
  color: #515151;
}
.eimmo-select2 .mat-select-trigger .mat-select-value .mat-select-placeholder {
  color: #898989;
}
.eimmo-select2 .mat-select-trigger .mat-select-arrow-wrapper {
  flex-grow: 0;
  flex-shrink: 1;
  flex-basis: auto;
  display: flex;
  align-items: center;
}
.eimmo-select2 .mat-select-trigger .mat-select-arrow-wrapper .mat-select-arrow {
  width: 10px;
  height: 10px;
  border: none;
  margin-right: 0;
  background-image: url("./media/selectbox.svg");
}
.eimmo-select-obt {
  height: 34px;
  border-radius: 4px;
  border: solid 1px #e7e7e7;
  font-style: normal;
  font-weight: normal;
  font-size: 14px;
  line-height: 34px;
  letter-spacing: -0.015em;
  background: #FFFFFF;
  box-sizing: border-box;
  color: #515151;
}
.eimmo-select-obt .mat-select-value {
  padding: 0 10px;
}
.eimmo-select-obt .mat-select-arrow {
  margin-right: 13px;
}
.eimmo-list-select {
  display: flex;
  height: 28px;
  border-radius: 5px;
}
.eimmo-list-select .mat-select-trigger {
  display: flex;
  flex-direction: row;
  align-items: center;
  width: 100%;
  height: 100%;
  padding: 0 8px;
}
.eimmo-list-select .mat-select-trigger .mat-select-value {
  flex: 1;
  display: flex;
  max-width: none;
  font-size: 11px;
  padding-left: 17px;
}
.eimmo-list-select .mat-select-trigger .mat-select-value .mat-select-value-text {
  color: #515151;
}
.eimmo-list-select .mat-select-trigger .mat-select-value .mat-select-placeholder {
  color: #898989;
}
.eimmo-list-select .mat-select-trigger .mat-select-arrow-wrapper {
  position: absolute;
}
.eimmo-list-select .mat-select-trigger .mat-select-arrow-wrapper .mat-select-arrow {
  width: 16px;
  height: 11px;
  border: none;
  margin: 0;
  background-image: url("./media/list-sort.svg");
}
.eimmo-list-header-select {
  display: flex;
  height: 100%;
}
.eimmo-list-header-select .mat-select-trigger {
  display: flex;
  flex-direction: row;
  align-items: center;
  width: 100%;
  height: 100%;
}
.eimmo-list-header-select .mat-select-trigger .mat-select-value {
  width: auto;
  display: flex;
  max-width: none;
  font-style: normal;
  font-weight: normal;
  font-size: 13px;
  line-height: 24px;
}
.eimmo-list-header-select .mat-select-trigger .mat-select-value .mat-select-value-text {
  color: #6F7288;
}
.eimmo-list-header-select .mat-select-trigger .mat-select-value .mat-select-placeholder {
  color: #6F7288;
}
.eimmo-list-header-select .mat-select-trigger .mat-select-arrow-wrapper {
  flex-grow: 0;
  flex-shrink: 1;
  flex-basis: auto;
  display: flex;
  align-items: center;
}
.eimmo-list-header-select .mat-select-trigger .mat-select-arrow-wrapper .mat-select-arrow {
  width: 10px;
  height: 6px;
  border: none;
  margin-left: 5px;
  background-image: url("./media/list-filter.svg");
}
.eimmo-list-header-select--center .mat-select-trigger {
  justify-content: center;
}
.mat-mdc-select-panel.eimmo-select-panel .mat-mdc-option {
  font-size: 12px;
  font-weight: 400;
  font-stretch: normal;
  font-style: normal;
  line-height: normal;
  letter-spacing: 0.24px;
  text-align: left;
  color: #626262;
}
.mat-mdc-select-panel.eimmo-select-panel .mat-mdc-option.mat-mdc-option-disabled {
  opacity: 0.5;
}
.mat-mdc-select-panel.eimmo-select-panel .mat-mdc-option .mat-pseudo-checkbox {
  border-width: 1px;
}
.mat-mdc-select-panel.eimmo-select-panel .mat-mdc-option .mat-pseudo-checkbox:not(.mat-pseudo-checkbox-checked) {
  border-color: #C1C1C1;
}
.mat-mdc-select-panel.eimmo-select-panel .mat-mdc-option .mat-pseudo-checkbox.mat-pseudo-checkbox-checked {
  background-color: #5E328D;
}
.mat-mdc-select-panel.eimmo-select-panel .mat-mdc-option .mat-pseudo-checkbox.mat-pseudo-checkbox-checked:after {
  top: 4.8px;
  left: 3px;
  width: 6px;
  height: 3px;
  border-left-width: 1px;
}
.mat-mdc-select-panel.eimmo-select-panel .mat-mdc-option .mat-pseudo-checkbox:after {
  border-bottom-width: 1px;
}
.mat-mdc-select-panel.eimmo-select-panel .mat-mdc-optgroup-label {
  font-size: 12px;
  font-weight: 400;
  font-stretch: normal;
  font-style: normal;
  letter-spacing: 0.24px;
  text-align: left;
  color: #898989;
}
.mat-mdc-select-panel.eimmo-member-role-select-panel .mat-mdc-option {
  height: 48px;
  font-size: 12px;
  font-weight: 400;
  font-stretch: normal;
  font-style: normal;
  line-height: normal;
  letter-spacing: 0.24px;
  text-align: left;
  color: #626262;
}
.mat-mdc-select-panel.eimmo-member-role-select-panel .mat-mdc-option.mat-mdc-option-disabled {
  opacity: 0.5;
}
.mat-mdc-select-panel.eimmo-member-role-select-panel .mat-mdc-option .mat-mdc-option-text {
  display: flex;
  flex-direction: row;
  align-items: center;
}
.mat-mdc-select-panel.eimmo-member-role-select-panel .mat-mdc-option .mat-mdc-option-text .member-role-label {
  min-width: 70px;
  max-width: 70px;
}
.mat-mdc-select-panel.eimmo-member-role-select-panel .mat-mdc-option .mat-mdc-option-text .member-role-description {
  white-space: normal;
}
.smart-labeling-select {
  background-color: #FFFFFF;
  height: 36px;
  border-radius: 6px;
  border: 1px solid #E0E0E0;
  padding: 8px 12px 8px 10px;
  box-sizing: border-box;
}
.smart-labeling-select .mat-mdc-select-value {
  color: #4F4F4F;
  font-size: 14px;
  line-height: 16px;
}
.smart-labeling-select .mat-mdc-select-arrow {
  -webkit-mask-repeat: no-repeat;
  mask-repeat: no-repeat;
  -webkit-mask-image: url("./media/arrow-down.svg");
  mask-image: url("./media/arrow-down.svg");
  -webkit-mask-size: 11px;
  mask-size: 11px;
  -webkit-mask-position: 50% 50%;
  mask-position: 50% 50%;
  background-color: #828282;
  color: #828282;
  margin: 0;
}
@supports (-ms-ime-align: auto) {
  .smart-labeling-select .mat-mdc-select-arrow {
    background: url("./media/arrow-down.svg") no-repeat 50% 50%;
    background-size: 11px;
  }
}
@media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
  .smart-labeling-select .mat-mdc-select-arrow {
    background: url("./media/arrow-down.svg") no-repeat 50% 50%;
    background-size: 11px;
  }
}
.smart-labeling-select.mat-mdc-select-disabled {
  background-color: #F2F2F2;
}
.smart-labeling-select.mat-mdc-select-disabled .mat-mdc-select-value {
  color: #BDBDBD;
}
.smart-labeling-select.mat-mdc-select-disabled .mat-mdc-select-arrow {
  background-color: #BDBDBD;
  color: #BDBDBD;
}
.aim-autocomplete .mat-mdc-autocomplete-panel {
  background-color: #333333;
  border-radius: 4px;
  height: 100%;
  overflow-y: auto;
}
.aim-autocomplete .mat-mdc-autocomplete-panel .mat-mdc-option {
  padding: 4px 8px;
}
.aim-autocomplete .mat-mdc-autocomplete-panel .mat-mdc-option.mat-active {
  background-color: #545454;
}
.aim-autocomplete .mat-mdc-autocomplete-panel .mat-mdc-option:hover {
  background-color: #545454;
}
.mat-checkbox.eimmo-checkbox .mat-checkbox-layout {
  width: 100%;
  height: 100%;
  justify-content: center;
}
.mat-checkbox.eimmo-checkbox .mat-checkbox-layout .mat-checkbox-inner-container .mat-checkbox-frame {
  border-color: #C1C1C1;
  border-width: 1px;
  border-radius: 3px;
}
.mat-checkbox.eimmo-checkbox .mat-checkbox-layout .mat-checkbox-inner-container .mat-checkbox-ripple {
  display: none;
}
.mat-checkbox.eimmo-checkbox .mat-checkbox-layout .mat-checkbox-inner-container .mat-checkbox-background .mat-checkbox-checkmark {
  width: 10px;
  height: 10px;
  top: 3px;
  left: 3px;
}
.mat-checkbox.eimmo-checkbox .mat-checkbox-layout .mat-checkbox-inner-container .mat-checkbox-background .mat-checkbox-mixedmark {
  width: calc(100% - 8px);
  height: 1px;
}
.mat-checkbox.eimmo-checkbox.mat-checkbox-checked.mat-accent .mat-checkbox-background,
.mat-checkbox.eimmo-checkbox.mat-checkbox-indeterminate.mat-accent .mat-checkbox-background {
  background-color: #5E328D;
}
.mat-checkbox.eimmo-checkbox.mat-checkbox-checked:not(.mat-checkbox-disabled).mat-accent .mat-ripple-element,
.mat-checkbox.eimmo-checkbox:active:not(.mat-checkbox-disabled).mat-accent .mat-ripple-element {
  background: #5E328D;
}
.mat-checkbox.eimmo-checkbox[disabled] .mat-checkbox-layout .mat-checkbox-background {
  background: #e7e7e7;
}
.mat-checkbox.eimmo-checkbox:hover:not([disabled]) .mat-checkbox-layout .mat-checkbox-frame {
  border-color: #5E328D;
}
.mat-mdc-radio-button.aimmo-radio.mat-accent {
  --mdc-radio-disabled-selected-icon-color: #000;
  --mdc-radio-disabled-unselected-icon-color: #000;
  --mdc-radio-unselected-focus-icon-color: #8e47ff;
  --mdc-radio-unselected-hover-icon-color: #8e47ff;
  --mdc-radio-unselected-icon-color: #545454;
  --mdc-radio-unselected-pressed-icon-color: rgba(0, 0, 0, 0.54);
  --mdc-radio-selected-focus-icon-color: #8e47ff;
  --mdc-radio-selected-hover-icon-color: #8e47ff;
  --mdc-radio-selected-icon-color: #8e47ff;
  --mdc-radio-selected-pressed-icon-color: #8e47ff;
  --mat-mdc-radio-ripple-color: #000;
  --mat-mdc-radio-checked-ripple-color: #8e47ff;
  --mdc-radio-state-layer-size: 20px;
  --mat-radio-checked-ripple-color: transparent;
}
.mat-mdc-radio-button.aimmo-radio.mat-accent .mdc-form-field {
  font-family:
    Pretendard,
    Silka,
    sans-serif;
  font-weight: 400;
  font-size: 14px;
  line-height: 18px;
  color: #dfdfdf;
}
.mat-mdc-radio-button.aimmo-radio.mat-accent .mdc-form-field label {
  padding-left: 8px;
}
.mat-mdc-radio-button.aimmo-radio.mat-accent.mat-mdc-radio-checked .mdc-radio__native-control:enabled + .mdc-radio__background .mdc-radio__inner-circle {
  border-color: #fff;
}
.mat-mdc-radio-button.aimmo-radio.mat-accent.mat-mdc-radio-checked .mdc-radio__outer-circle {
  border-width: 5px;
}
.mat-mdc-radio-button.aimmo-radio.mat-accent .mdc-radio__outer-circle {
  border-width: 1px;
}
.eimmo-checkbox.mat-mdc-checkbox.mat-accent {
  --mdc-checkbox-selected-checkmark-color: #fafafa;
  --mdc-checkbox-selected-focus-icon-color: #5E328D;
  --mdc-checkbox-selected-hover-icon-color: #5E328D;
  --mdc-checkbox-selected-icon-color: #5E328D;
  --mdc-checkbox-selected-pressed-icon-color: #5E328D;
  --mdc-checkbox-unselected-focus-icon-color: #5E328D;
  --mdc-checkbox-unselected-hover-icon-color: #5E328D;
  --mdc-checkbox-disabled-selected-icon-color: #e7e7e7;
  --mdc-checkbox-disabled-unselected-icon-color: #e7e7e7;
  --mdc-checkbox-unselected-icon-color: #545454;
  --mdc-checkbox-unselected-pressed-icon-color: #5E328D;
  --mdc-checkbox-state-layer-size: 16px;
}
.eimmo-checkbox.mat-mdc-checkbox .mdc-checkbox__ripple {
  display: none;
}
.eimmo-checkbox.mat-mdc-checkbox .mdc-checkbox__background {
  border-radius: 3px;
  border-width: 1px;
  position: initial;
}
.eimmo-checkbox.mat-mdc-checkbox .mdc-checkbox__checkmark {
  width: 8px;
  height: 8px;
  top: 5px;
  left: 5px;
}
.eimmo-checkbox.mat-mdc-checkbox .mdc-checkbox__mixedmark {
  width: calc(100% - 8px);
  border-width: 0.5px;
}
.eimmo-checkbox.mat-mdc-checkbox label {
  padding-left: 8px;
}
.eimmo-checkbox.mat-mdc-checkbox .mat-checkbox-layout {
  width: 100%;
  height: 100%;
  justify-content: center;
}
.mat-checkbox.eimmo-checkbox2 .mat-checkbox-layout {
  width: 100%;
  height: 100%;
  justify-content: center;
}
.mat-checkbox.eimmo-checkbox2 .mat-checkbox-layout .mat-checkbox-inner-container .mat-checkbox-frame {
  border-color: #C1C1C1;
  border-width: 1px;
}
.mat-checkbox.eimmo-checkbox2 .mat-checkbox-layout .mat-checkbox-inner-container .mat-checkbox-background .mat-checkbox-checkmark {
  width: 10px;
  height: 10px;
  top: 3px;
  left: 3px;
}
.mat-checkbox.eimmo-checkbox2 .mat-checkbox-layout .mat-checkbox-inner-container .mat-checkbox-background .mat-checkbox-mixedmark {
  width: calc(100% - 8px);
  height: 1px;
}
.mat-checkbox.eimmo-checkbox2.mat-checkbox-checked.mat-accent .mat-checkbox-background,
.mat-checkbox.eimmo-checkbox2.mat-checkbox-indeterminate.mat-accent .mat-checkbox-background {
  background-color: #A485FF;
}
.mat-checkbox.eimmo-checkbox2.mat-checkbox-checked:not(.mat-checkbox-disabled).mat-accent .mat-ripple-element,
.mat-checkbox.eimmo-checkbox2:active:not(.mat-checkbox-disabled).mat-accent .mat-ripple-element {
  background: #A485FF;
}
.mat-checkbox.itv-checkbox {
  display: flex;
  width: 100%;
}
.mat-checkbox.itv-checkbox .mat-checkbox-layout {
  width: 100%;
  height: 100%;
}
.mat-checkbox.itv-checkbox .mat-checkbox-layout .mat-checkbox-inner-container {
  width: 10px;
  height: 10px;
  margin-left: 0;
  margin-right: 10px;
}
.mat-checkbox.itv-checkbox .mat-checkbox-layout .mat-checkbox-inner-container .mat-checkbox-frame {
  border: 1px solid #DEE2E6;
  border-radius: 3px;
}
.mat-checkbox.itv-checkbox .mat-checkbox-layout .mat-checkbox-inner-container .mat-checkbox-ripple {
  display: none;
}
.mat-checkbox.itv-checkbox .mat-checkbox-layout .mat-checkbox-inner-container .mat-checkbox-background .mat-checkbox-checkmark {
  width: 10px;
  height: 10px;
}
.mat-checkbox.itv-checkbox .mat-checkbox-layout .mat-checkbox-inner-container .mat-checkbox-background .mat-checkbox-mixedmark {
  width: calc(100% - 8px);
  height: 1px;
}
.mat-checkbox.itv-checkbox .mat-checkbox-layout .mat-checkbox-label {
  max-width: 100%;
  width: 100%;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.mat-checkbox.itv-checkbox.mat-checkbox-checked.mat-accent .mat-checkbox-background,
.mat-checkbox.itv-checkbox.mat-checkbox-indeterminate.mat-accent .mat-checkbox-background {
  background-color: #8358FF;
}
.mat-checkbox.itv-checkbox.mat-checkbox-checked:not(.mat-checkbox-disabled).mat-accent .mat-ripple-element,
.mat-checkbox.itv-checkbox:active:not(.mat-checkbox-disabled).mat-accent .mat-ripple-element {
  background: #8358FF;
}
.mat-checkbox.itv-checkbox[disabled] .mat-checkbox-layout .mat-checkbox-background {
  background: #e7e7e7;
}
.mat-checkbox.itv-checkbox:hover:not([disabled]) .mat-checkbox-layout .mat-checkbox-frame {
  border-color: #8358FF;
}
.mat-radio-button.itv-radio-button {
  display: flex;
  width: 100%;
}
.mat-radio-button.itv-radio-button .mat-radio-label {
  display: flex;
  max-width: 100%;
  width: 100%;
  align-items: center;
}
.mat-radio-button.itv-radio-button .mat-radio-label .mat-radio-container {
  width: 10px;
  height: 10px;
  margin-left: 0;
  margin-right: 10px;
}
.mat-radio-button.itv-radio-button .mat-radio-label .mat-radio-container .mat-radio-outer-circle {
  width: 10px;
  height: 10px;
  border: 1px solid #DEE2E6;
}
.mat-radio-button.itv-radio-button .mat-radio-label .mat-radio-container .mat-radio-inner-circle {
  width: 10px;
  height: 10px;
  -webkit-mask-repeat: no-repeat;
  mask-repeat: no-repeat;
  -webkit-mask-image: url("./media/check.svg");
  mask-image: url("./media/check.svg");
  -webkit-mask-size: 14px;
  mask-size: 14px;
  -webkit-mask-position: 50% 50%;
  mask-position: 50% 50%;
  background-color: #FFFFFF;
}
@supports (-ms-ime-align: auto) {
  .mat-radio-button.itv-radio-button .mat-radio-label .mat-radio-container .mat-radio-inner-circle {
    background: url("./media/check.svg") no-repeat 50% 50%;
    background-size: 14px;
  }
}
@media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
  .mat-radio-button.itv-radio-button .mat-radio-label .mat-radio-container .mat-radio-inner-circle {
    background: url("./media/check.svg") no-repeat 50% 50%;
    background-size: 14px;
  }
}
.mat-radio-button.itv-radio-button .mat-radio-label .mat-radio-container .mat-radio-ripple {
  display: none;
}
.mat-radio-button.itv-radio-button .mat-radio-label .mat-radio-label-content {
  padding: 0;
  width: 100%;
}
.mat-radio-button.itv-radio-button.mat-radio-checked .mat-radio-label .mat-radio-container .mat-radio-outer-circle {
  background-color: #7148E7;
  border-color: #7148E7;
}
.mat-radio-button.itv-radio-button.mat-radio-checked .mat-radio-label .mat-radio-container .mat-radio-inner-circle {
  transform: scale(0.9);
}
.mat-radio-button.itv-radio-button:hover:not(.mat-radio-disabled) .mat-radio-label .mat-radio-container .mat-radio-outer-circle {
  border-color: #7148E7;
}
.mat-slide-toggle.eimmo-slide-toggle .mat-slide-toggle-label {
  justify-content: center;
}
.mat-slide-toggle.eimmo-slide-toggle .mat-slide-toggle-label .mat-slide-toggle-bar {
  width: 30px;
  height: 18px;
  background-color: #A2A2A2;
}
.mat-slide-toggle.eimmo-slide-toggle .mat-slide-toggle-label .mat-slide-toggle-bar .mat-slide-toggle-thumb-container {
  width: 10px;
  height: 10px;
  top: 4px;
  left: 4px;
}
.mat-slide-toggle.eimmo-slide-toggle .mat-slide-toggle-label .mat-slide-toggle-bar .mat-slide-toggle-thumb-container .mat-slide-toggle-thumb {
  width: 10px;
  height: 10px;
  background-color: #FFFFFF;
}
.mat-slide-toggle.eimmo-slide-toggle.mat-checked .mat-slide-toggle-bar {
  background-color: #5D338A;
}
.mat-slide-toggle.eimmo-slide-toggle.mat-checked .mat-slide-toggle-thumb-container {
  transform: translate3d(12px, 0, 0);
}
.mat-slide-toggle.eimmo-slide-toggle.mat-checked .mat-slide-toggle-thumb-container .mat-slide-toggle-thumb {
  background-color: #FFFFFF;
}
.mat-slide-toggle.eimmo-slide-toggle.mat-checked .mat-slide-toggle-thumb-container .mat-ripple-element {
  background-color: #5D338A;
}
.mat-radio-button.gtaas-radio + .mat-radio-button.gtaas-radio {
  margin-left: 8px;
}
.mat-radio-button.gtaas-radio .mat-radio-container {
  width: 18px;
  height: 18px;
}
.mat-radio-button.gtaas-radio .mat-radio-container .mat-radio-outer-circle {
  width: 18px;
  height: 18px;
  border-width: 2px;
  border-color: #515151;
}
.mat-radio-button.gtaas-radio .mat-radio-container .mat-radio-inner-circle {
  width: 18px;
  height: 18px;
  background-color: #515151;
}
.mat-radio-button.gtaas-radio .mat-radio-container .mat-radio-ripple .mat-ripple-element {
  background-color: #6d6d6d;
}
.mat-radio-button.gtaas-radio .mat-radio-label-content {
  padding-left: 5px;
}
.mat-radio-button.gtaas-radio.mat-radio-checked .mat-radio-inner-circle {
  transform: scale(0.4447);
}
.mat-radio-button.eimmo-radio .mat-radio-container {
  width: 18px;
  height: 18px;
}
.mat-radio-button.eimmo-radio .mat-radio-container .mat-radio-outer-circle {
  width: 18px;
  height: 18px;
  border-width: 1px;
  border-color: #C1C1C1;
}
.mat-radio-button.eimmo-radio .mat-radio-container .mat-radio-inner-circle {
  width: 18px;
  height: 18px;
  background-color: #5E328D;
}
.mat-radio-button.eimmo-radio .mat-radio-container .mat-radio-ripple .mat-ripple-element {
  background-color: #5D338A;
}
.mat-radio-button.eimmo-radio .mat-radio-label-content {
  padding-left: 10px;
}
.mat-radio-button.eimmo-radio.mat-radio-checked .mat-radio-inner-circle {
  transform: scale(0.4447);
}
.mat-mdc-chip-grid.aim-mat-chip-grid .mdc-evolution-chip-set__chips {
  gap: 4px;
}
.mat-mdc-chip-grid.aim-chip-grid {
  display: flex;
  flex-direction: row;
  justify-content: center;
  min-height: 32px;
  padding: 0 12px;
  box-sizing: border-box;
  background-color: #333333;
  border: solid 1px transparent;
  border-radius: 4px;
}
.mat-mdc-chip-grid.aim-chip-grid .mat-mdc-chip-row.aim-chip-row {
  --mdc-chip-elevated-container-color: transparent;
  --mdc-chip-elevated-disabled-container-color: #e0e0e0;
  --mdc-chip-container-height: 22px;
  --mdc-chip-container-shape-radius: 24px;
  --mdc-chip-label-text-color: #dfdfdf;
  --mdc-chip-with-trailing-icon-trailing-icon-color: #dfdfdf;
  font-family:
    Pretendard,
    Silka,
    sans-serif;
  font-weight: 400;
  font-size: 14px;
  line-height: 18px;
  border: 1px solid #545454;
}
.mat-mdc-chip-grid.aim-chip-grid .aim-chip-input {
  outline: none;
  border: none;
  margin: 0 0 0 8px;
  padding: 0;
  background-color: transparent;
  font-family:
    Pretendard,
    Silka,
    sans-serif;
  font-weight: 400;
  font-size: 14px;
  line-height: 18px;
  color: #dfdfdf;
  caret-color: #dfdfdf;
  cursor: text;
}
.mat-mdc-chip-grid.aim-chip-grid .aim-chip-input::placeholder {
  color: #787878;
}
.mat-mdc-chip-grid.aim-chip-grid .aim-chip-input:disabled {
  cursor: not-allowed;
}
.aim-scroll-theme.os-scrollbar {
  box-sizing: border-box;
  padding: 4px;
  background: transparent;
}
.aim-scroll-theme.os-scrollbar-horizontal {
  right: 8px;
  height: var(--aim-scroll-scrollbar-height-horizontal, 16px);
}
.aim-scroll-theme.os-scrollbar-vertical {
  bottom: 8px;
  width: var(--aim-scroll-scrollbar-width-vertical, 16px);
}
.aim-scroll-theme.os-scrollbar-rtl.os-scrollbar-horizontal {
  left: 8px;
  right: 0;
}
.aim-scroll-theme.os-scrollbar-unusable {
  background: transparent;
}
.aim-scroll-theme.os-scrollbar > .os-scrollbar-track {
  background: transparent;
}
.aim-scroll-theme.os-scrollbar-horizontal > .os-scrollbar-track > .os-scrollbar-handle {
  box-sizing: border-box;
  min-width: var(--aim-scroll-scrollbar-handle-min-width-horizontal, 24px);
}
.aim-scroll-theme.os-scrollbar-vertical > .os-scrollbar-track > .os-scrollbar-handle {
  box-sizing: border-box;
  min-height: var(--aim-scroll-scrollbar-handle-min-height-vertical, 24px);
}
.aim-scroll-theme.os-scrollbar-transition > .os-scrollbar-track > .os-scrollbar-handle {
  transition: background-color 0.3s;
}
.aim-scroll-theme.os-scrollbar > .os-scrollbar-track > .os-scrollbar-handle,
.aim-scroll-theme.os-scrollbar > .os-scrollbar-track {
  border-radius: 100px;
  border: 1px solid #545454;
}
.aim-scroll-theme.os-scrollbar > .os-scrollbar-track > .os-scrollbar-handle {
  background: rgba(84, 84, 84, 0.5);
}
.aim-scroll-theme.os-scrollbar:hover > .os-scrollbar-track > .os-scrollbar-handle {
  background: rgba(84, 84, 84, 0.5);
}
.aim-scroll-theme.os-scrollbar > .os-scrollbar-track > .os-scrollbar-handle.active {
  background: rgba(84, 84, 84, 0.5);
}
.aim-scroll-theme.os-scrollbar-horizontal .os-scrollbar-handle:before,
.aim-scroll-theme.os-scrollbar-vertical .os-scrollbar-handle:before {
  content: "";
  position: absolute;
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  display: block;
}
.aim-scroll-theme.os-host-scrollbar-hidden > .os-scrollbar-handle:before {
  display: none;
}
.aim-scroll-theme.os-scrollbar-horizontal .os-scrollbar-handle:before {
  top: -8px;
  bottom: -4px;
}
.aim-scroll-theme.os-scrollbar-vertical .os-scrollbar-handle:before {
  left: -8px;
  right: -4px;
}
.aim-scroll-theme.os-scrollbar-rtl.os-scrollbar-vertical .os-scrollbar-handle:before {
  right: -8px;
  left: -4px;
}
.cdk-overlay-backdrop-showing.aim-dialog-backdrop {
  pointer-events: auto;
  background-color: rgba(0, 0, 0, 0.5);
  background: rgba(0, 0, 0, 0.5);
  opacity: 1;
  -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
  transition: opacity 400ms cubic-bezier(0.25, 0.8, 0.25, 1);
}
.cdk-overlay-backdrop-showing.aim-dialog-backdrop + .cdk-global-overlay-wrapper {
  overflow: auto;
}
.cdk-overlay-backdrop-showing.aim-dialog-backdrop + .cdk-global-overlay-wrapper::-webkit-scrollbar {
  width: 18px;
  height: 18px;
}
.cdk-overlay-backdrop-showing.aim-dialog-backdrop + .cdk-global-overlay-wrapper::-webkit-scrollbar-track {
  background-color: rgba(0, 0, 0, 0);
}
.cdk-overlay-backdrop-showing.aim-dialog-backdrop + .cdk-global-overlay-wrapper::-webkit-scrollbar-thumb {
  background: #333333;
  border-radius: 100px;
  background-clip: padding-box;
  border: 4px solid transparent;
}
.cdk-overlay-backdrop-showing.aim-dialog-backdrop + .cdk-global-overlay-wrapper::-webkit-scrollbar-corner {
  background-color: rgba(0, 0, 0, 0);
}
.aim-dialog.dark .mat-mdc-dialog-container {
  background-color: #222222;
}
.aim-dialog.gray .mat-mdc-dialog-container {
  background-color: #F5F5F5;
}
.aim-dialog .mat-mdc-dialog-container {
  border: none;
  border-radius: 4px;
  padding: 24px;
}
.aim-dialog .mat-mdc-dialog-container .mat-mdc-dialog-surface.mdc-dialog__surface {
  background-color: transparent;
  border-radius: unset;
  box-shadow: unset;
  overflow-y: hidden;
}
.aim-dialog .mat-mdc-dialog-container .mdc-dialog__container {
  min-width: 100%;
}
.aim-cursor-pointer {
  cursor: url("./media/aim-cursor-pointer.svg") 0 0, auto;
}
.aim-cursor-duplicate {
  cursor: url("./media/aim-cursor-duplicate.svg") 0 0, auto;
}
.aim-cursor-pointer-add {
  cursor: url("./media/aim-cursor-pointer-add.svg") 0 0, auto;
}
.aim-cursor-pointer-delete {
  cursor: url("./media/aim-cursor-pointer-delete.svg") 0 0, auto;
}
.aim-cursor-pointer-close {
  cursor: url("./media/aim-cursor-pointer-close.svg") 0 0, auto;
}
.aim-cursor-pointer-move {
  cursor: url("./media/aim-cursor-pointer-move.svg") 0 0, auto;
}
.aim-cursor-positive {
  cursor: url("./media/aim-cursor-positive.svg") 0 0, auto;
}
.aim-cursor-negative {
  cursor: url("./media/aim-cursor-negative.svg") 0 0, auto;
}
.aim-cursor-qa {
  cursor: url("./media/aim-cursor-qa.svg") 0 0, auto;
}
.aim-cursor-fill {
  cursor: url("./media/aim-cursor-fill.svg") 0 0, auto;
}
.aim-cursor-split {
  cursor: url("./media/aim-cursor-split.svg") 0 0, auto;
}
.aim-cursor-crosshair {
  cursor: url("./media/aim-cursor-crosshair.svg") 0 0, auto;
}
.aim-cursor-rotate {
  cursor: url("./media/aim-cursor-rotate.svg") 0 0, auto;
}
.aim-cursor-coner-rotate {
  cursor: url("./media/aim-cursor-coner-rotate.svg") 0 0, auto;
}
.aim-cursor-resize-ew {
  cursor: url("./media/aim-cursor-resize-ew.svg") 0 0, auto;
}
.aim-cursor-resize-ns {
  cursor: url("./media/aim-cursor-resize-ns.svg") 0 0, auto;
}
.aim-cursor-hand {
  cursor: url("./media/aim-cursor-hand.svg") 0 0, auto;
}
.aim-cursor-hand-pointer {
  cursor: url("./media/aim-cursor-hand-pointer.svg") 0 0, auto;
}
.aim-cursor-grabbed {
  cursor: url("./media/aim-cursor-grabbed.svg") 0 0, auto;
}
.aim-cursor-brush {
  cursor: url("./media/aim-cursor-brush.svg") 0 0, auto;
}
.aim-cursor-erase {
  cursor: url("./media/aim-cursor-erase.svg") 0 0, auto;
}
.aim-cursor-move-line-ns {
  cursor: url("./media/aim-cursor-move-line-ns.svg") 0 0, auto;
}
.aim-cursor-move-line-ew {
  cursor: url("./media/aim-cursor-move-line-ew.svg") 0 0, auto;
}
.aim-cursor-comment {
  cursor: url("./media/aim-cursor-comment.svg") 0 0, auto;
}
:root {
  --aim-cursor-pointer: url("./media/aim-cursor-pointer.svg") 0 0, auto;
  --aim-cursor-duplicate: url("./media/aim-cursor-duplicate.svg") 0 0, auto;
  --aim-cursor-pointer-add: url("./media/aim-cursor-pointer-add.svg") 0 0, auto;
  --aim-cursor-pointer-delete: url("./media/aim-cursor-pointer-delete.svg") 0 0, auto;
  --aim-cursor-pointer-close: url("./media/aim-cursor-pointer-close.svg") 0 0, auto;
  --aim-cursor-pointer-move: url("./media/aim-cursor-pointer-move.svg") 0 0, auto;
  --aim-cursor-positive: url("./media/aim-cursor-positive.svg") 0 0, auto;
  --aim-cursor-negative: url("./media/aim-cursor-negative.svg") 0 0, auto;
  --aim-cursor-qa: url("./media/aim-cursor-qa.svg") 0 0, auto;
  --aim-cursor-fill: url("./media/aim-cursor-fill.svg") 0 0, auto;
  --aim-cursor-split: url("./media/aim-cursor-split.svg") 0 0, auto;
  --aim-cursor-crosshair: url("./media/aim-cursor-crosshair.svg") 0 0, auto;
  --aim-cursor-rotate: url("./media/aim-cursor-rotate.svg") 0 0, auto;
  --aim-cursor-coner-rotate: url("./media/aim-cursor-coner-rotate.svg") 0 0, auto;
  --aim-cursor-resize-ew: url("./media/aim-cursor-resize-ew.svg") 0 0, auto;
  --aim-cursor-resize-ns: url("./media/aim-cursor-resize-ns.svg") 0 0, auto;
  --aim-cursor-hand: url("./media/aim-cursor-hand.svg") 0 0, auto;
  --aim-cursor-hand-pointer: url("./media/aim-cursor-hand-pointer.svg") 0 0, auto;
  --aim-cursor-grabbed: url("./media/aim-cursor-grabbed.svg") 0 0, auto;
  --aim-cursor-brush: url("./media/aim-cursor-brush.svg") 0 0, auto;
  --aim-cursor-erase: url("./media/aim-cursor-erase.svg") 0 0, auto;
  --aim-cursor-move-line-ns: url("./media/aim-cursor-move-line-ns.svg") 0 0, auto;
  --aim-cursor-move-line-ew: url("./media/aim-cursor-move-line-ew.svg") 0 0, auto;
  --aim-cursor-comment: url("./media/aim-cursor-comment.svg") 0 0, auto;
}
.aim-tooltip-panel .aim-tooltip .mdc-tooltip__surface {
  font-family:
    Pretendard,
    Silka,
    sans-serif;
  font-weight: 400;
  font-size: 10px;
  line-height: 12px;
  color: var(--aim-tooltip-text-color, #dfdfdf);
  background-color: var(--aim-tooltip-background-color, #333333);
  max-width: var(--aim-tooltip-max-width, 240px);
  border-radius: 4px;
  padding: 8px 12px;
  word-break: var(--aim-tooltip-word-break, break-all);
  white-space: pre-line;
  min-height: auto;
}
.aim-tooltip-panel .aim-tooltip.full-text .mdc-tooltip__surface {
  --aim-tooltip-max-width: 400px;
}
.aim-tooltip-panel .aim-tooltip.medium .mdc-tooltip__surface {
  font-family:
    Pretendard,
    Silka,
    sans-serif;
  font-weight: 400;
  font-size: 10px;
  line-height: 12px;
}
.aim-tooltip-panel .aim-tooltip.large .mdc-tooltip__surface {
  font-family:
    Pretendard,
    Silka,
    sans-serif;
  font-weight: 400;
  font-size: 12px;
  line-height: 14px;
}
.aim-tooltip-panel .aim-tooltip.dark .mdc-tooltip__surface {
  --aim-tooltip-text-color: #dfdfdf;
  --aim-tooltip-background-color: #333333;
}
.aim-tooltip-panel .aim-tooltip.light .mdc-tooltip__surface {
  --aim-tooltip-text-color: #1A1A1A;
  --aim-tooltip-background-color: #dfdfdf;
}
.aim-tooltip-panel .aim-tooltip.word-break-keep-all .mdc-tooltip__surface {
  --aim-tooltip-word-break: keep-all;
}
.aim-tab-nav-bar {
  --mdc-theme-on-surface: #dfdfdf;
}
.aim-tab-nav-bar .mat-mdc-tab-list .mat-mdc-tab-links {
  height: 40px;
  border-bottom: 1px solid #545454;
}
.aim-tab-nav-bar .mat-mdc-tab-list .mat-mdc-tab-links .mdc-tab {
  font-family:
    Pretendard,
    Silka,
    sans-serif;
  font-weight: 400;
  font-size: 14px;
  line-height: 18px;
  border-top: 1px solid transparent;
  border-left: 1px solid transparent;
  border-right: 1px solid transparent;
  border-radius: 4px 4px 0 0;
  color: #dfdfdf;
  transition: border 0.25s ease-in-out, color 0.25s ease-in-out;
  max-width: 214px;
  min-width: 0;
  height: auto;
  padding: 0 16px;
  --mdc-tab-indicator-active-indicator-color: transparent;
  --mdc-secondary-navigation-tab-container-height: auto;
  --mat-tab-header-label-text-tracking: none;
  -webkit-font-smoothing: initial;
}
.aim-tab-nav-bar .mat-mdc-tab-list .mat-mdc-tab-links .mdc-tab:hover:not(.mdc-tab--active) {
  background-color: transparent;
  border-color: #545454;
  opacity: 1;
}
.aim-tab-nav-bar .mat-mdc-tab-list .mat-mdc-tab-links .mdc-tab__content {
  width: 100%;
}
.aim-tab-nav-bar .mat-mdc-tab-list .mat-mdc-tab-links .mdc-tab__text-label {
  display: inline-block;
  color: #ffffff;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap;
}
.aim-tab-nav-bar .mat-mdc-tab-list .mat-mdc-tab-links .mdc-tab--active,
.aim-tab-nav-bar .mat-mdc-tab-list .mat-mdc-tab-links .mdc-tab.active {
  background-color: #8e47ff;
  opacity: 1;
}
.aim-tab-nav-bar .mat-mdc-tab-list .mat-mdc-tab-links .mdc-tab--active .mdc-tab__text-label,
.aim-tab-nav-bar .mat-mdc-tab-list .mat-mdc-tab-links .mdc-tab.active .mdc-tab__text-label {
  color: #ffffff;
}
.aim-tab-nav-bar.sub-tab-group .mat-mdc-tab-list .mat-mdc-tab-links .mdc-tab {
  border: none;
  --mdc-tab-indicator-active-indicator-color: #8e47ff;
  --mat-tab-header-inactive-ripple-color: none;
  --mat-tab-header-active-ripple-color: none;
}
.aim-tab-nav-bar.sub-tab-group .mat-mdc-tab-list .mat-mdc-tab-links .mdc-tab--active,
.aim-tab-nav-bar.sub-tab-group .mat-mdc-tab-list .mat-mdc-tab-links .mdc-tab.active {
  background-color: transparent;
  opacity: 1;
}
.aim-tab-nav-bar.sub-tab-group .mat-mdc-tab-list .mat-mdc-tab-links .mdc-tab--active .mdc-tab__text-label,
.aim-tab-nav-bar.sub-tab-group .mat-mdc-tab-list .mat-mdc-tab-links .mdc-tab.active .mdc-tab__text-label {
  color: #8e47ff;
}
.aim-tab-nav-bar.sub-tab-group .mat-mdc-tab-list .mat-mdc-tab-links .mdc-tab .mdc-tab-indicator__content--underline {
  border-top-width: 1px;
  border-color: #8e47ff;
  position: relative;
  top: 1px;
}
@font-face {
  font-family: "aim-icons";
  src:
    url("./media/aim-icons.ttf?c7612084f4a92a325fbfe83a86e1d38f") format("truetype"),
    url("./media/aim-icons.woff?c7612084f4a92a325fbfe83a86e1d38f") format("woff"),
    url("./media/aim-icons.woff2?c7612084f4a92a325fbfe83a86e1d38f") format("woff2");
}
i[class^=icon-]:before,
i[class*=" icon-"]:before {
  font-family: aim-icons !important;
  font-style: normal;
  font-weight: normal !important;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.icon-aim-icon-bin-16:before {
  content: "\f101";
}
.icon-aim-icon-bin-32:before {
  content: "\f102";
}
.icon-aim-icon-calendar:before {
  content: "\f103";
}
.icon-aim-icon-car-crash:before {
  content: "\f104";
}
.icon-aim-icon-change:before {
  content: "\f105";
}
.icon-aim-icon-check:before {
  content: "\f106";
}
.icon-aim-icon-chevron-down:before {
  content: "\f107";
}
.icon-aim-icon-chevron-left:before {
  content: "\f108";
}
.icon-aim-icon-chevron-right:before {
  content: "\f109";
}
.icon-aim-icon-chevron-up:before {
  content: "\f10a";
}
.icon-aim-icon-chevron-updown:before {
  content: "\f10b";
}
.icon-aim-icon-clear:before {
  content: "\f10c";
}
.icon-aim-icon-close:before {
  content: "\f10d";
}
.icon-aim-icon-communication:before {
  content: "\f10e";
}
.icon-aim-icon-copy:before {
  content: "\f10f";
}
.icon-aim-icon-csv-16:before {
  content: "\f110";
}
.icon-aim-icon-csv-32:before {
  content: "\f111";
}
.icon-aim-icon-dashboard-workspace:before {
  content: "\f112";
}
.icon-aim-icon-dashboard:before {
  content: "\f113";
}
.icon-aim-icon-data-management:before {
  content: "\f114";
}
.icon-aim-icon-dataset:before {
  content: "\f115";
}
.icon-aim-icon-delete:before {
  content: "\f116";
}
.icon-aim-icon-deployment:before {
  content: "\f117";
}
.icon-aim-icon-device-management:before {
  content: "\f118";
}
.icon-aim-icon-download:before {
  content: "\f119";
}
.icon-aim-icon-drag-move:before {
  content: "\f11a";
}
.icon-aim-icon-error-solid:before {
  content: "\f11b";
}
.icon-aim-icon-error:before {
  content: "\f11c";
}
.icon-aim-icon-filter:before {
  content: "\f11d";
}
.icon-aim-icon-folder:before {
  content: "\f11e";
}
.icon-aim-icon-grid:before {
  content: "\f11f";
}
.icon-aim-icon-history:before {
  content: "\f120";
}
.icon-aim-icon-info:before {
  content: "\f121";
}
.icon-aim-icon-json-16:before {
  content: "\f122";
}
.icon-aim-icon-json-32:before {
  content: "\f123";
}
.icon-aim-icon-jump-down:before {
  content: "\f124";
}
.icon-aim-icon-jump-left:before {
  content: "\f125";
}
.icon-aim-icon-jump-right:before {
  content: "\f126";
}
.icon-aim-icon-jump-up:before {
  content: "\f127";
}
.icon-aim-icon-link:before {
  content: "\f128";
}
.icon-aim-icon-list:before {
  content: "\f129";
}
.icon-aim-icon-lock-close:before {
  content: "\f12a";
}
.icon-aim-icon-logout:before {
  content: "\f12b";
}
.icon-aim-icon-menu-left:before {
  content: "\f12c";
}
.icon-aim-icon-menu-right:before {
  content: "\f12d";
}
.icon-aim-icon-menu:before {
  content: "\f12e";
}
.icon-aim-icon-minus:before {
  content: "\f12f";
}
.icon-aim-icon-more-horizontal:before {
  content: "\f130";
}
.icon-aim-icon-more-vertical:before {
  content: "\f131";
}
.icon-aim-icon-move-file:before {
  content: "\f132";
}
.icon-aim-icon-mp4-16:before {
  content: "\f133";
}
.icon-aim-icon-mp4-32:before {
  content: "\f134";
}
.icon-aim-icon-null:before {
  content: "\f135";
}
.icon-aim-icon-platform:before {
  content: "\f136";
}
.icon-aim-icon-play-circle:before {
  content: "\f137";
}
.icon-aim-icon-play-video:before {
  content: "\f138";
}
.icon-aim-icon-play:before {
  content: "\f139";
}
.icon-aim-icon-plus:before {
  content: "\f13a";
}
.icon-aim-icon-popup:before {
  content: "\f13b";
}
.icon-aim-icon-project-list:before {
  content: "\f13c";
}
.icon-aim-icon-question:before {
  content: "\f13d";
}
.icon-aim-icon-refresh:before {
  content: "\f13e";
}
.icon-aim-icon-reject:before {
  content: "\f13f";
}
.icon-aim-icon-reset:before {
  content: "\f140";
}
.icon-aim-icon-save:before {
  content: "\f141";
}
.icon-aim-icon-scene-file:before {
  content: "\f142";
}
.icon-aim-icon-search:before {
  content: "\f143";
}
.icon-aim-icon-setting:before {
  content: "\f144";
}
.icon-aim-icon-settings:before {
  content: "\f145";
}
.icon-aim-icon-sort-down:before {
  content: "\f146";
}
.icon-aim-icon-sort-up:before {
  content: "\f147";
}
.icon-aim-icon-sort:before {
  content: "\f148";
}
.icon-aim-icon-stop:before {
  content: "\f149";
}
.icon-aim-icon-studio:before {
  content: "\f14a";
}
.icon-aim-icon-table:before {
  content: "\f14b";
}
.icon-aim-icon-tag:before {
  content: "\f14c";
}
.icon-aim-icon-target:before {
  content: "\f14d";
}
.icon-aim-icon-trainings:before {
  content: "\f14e";
}
.icon-aim-icon-trip-management:before {
  content: "\f14f";
}
.icon-aim-icon-txt-16:before {
  content: "\f150";
}
.icon-aim-icon-txt-32:before {
  content: "\f151";
}
.icon-aim-icon-unknown-16:before {
  content: "\f152";
}
.icon-aim-icon-unknown-32:before {
  content: "\f153";
}
.icon-aim-icon-upload:before {
  content: "\f154";
}
.icon-aim-icon-user-management:before {
  content: "\f155";
}
.icon-aim-icon-user:before {
  content: "\f156";
}
.icon-aim-icon-view:before {
  content: "\f157";
}
.icon-aim-icon-warning:before {
  content: "\f158";
}
.icon-aim-icon-workflow:before {
  content: "\f159";
}
.icon-aim-icon-workspace:before {
  content: "\f15a";
}
.icon-aim-icon-write:before {
  content: "\f15b";
}
html {
  height: 100%;
  background-color: #1A1A1A;
  color: #DFDFDF;
}
body {
  height: 100%;
  margin: 0;
  padding: 0;
  box-sizing: border-box;
}

/* angular:styles/global:styles */
